CREATE OR REPLACE TRIGGER TRG_MODIFY_EMPLOYMENT
  AFTER UPDATE ON EMPLOYMENT
  FOR EACH ROW
declare
  code_oper              varchar2(64);
  counter                number(16);
begin
  select count(1) into counter from tmp_codoperation;

  if ( counter = 0 ) then
    RAISE_APPLICATION_ERROR ( -20200, 'NO OPERATION CODE FOUND IN TMP_CODOPERATION TABLE');
  elsif ( counter = 1 ) then
    select code into code_oper from tmp_codoperation;
  elsif  ( counter > 1 ) then
    RAISE_APPLICATION_ERROR ( -20201, 'TOO MANY OPERATION CODE FOUND IN TMP_CODOPERATION TABLE');
  end if;

  if ( :old.state = 1 and :new.state = 0 ) then
    --enable
    if ( :new.parent is null ) then
      --normal
      
      --nel caso di assegnazione a tempo, abbiamo la necessità di riportare il cod_operation
      --presente all'interno di employment (qualora esso sia presente)
      if ( :new.cod_operation is not null ) then
        code_oper := :new.cod_operation;
      end if;

      insert into authorizations ( id, person, account_code, entitlement, profile, cod_operation, entitlement_flat_hier, employment )
        select authorizations_seq.nextval, :new.person, pm.code, :new.entitlement, efh.child, code_oper, efh.id, :new.id
        from application a, target t, pwdcfg p, entitlement_flat_hier efh, employment_pwdmanagement ep, pwdmanagement pm 
        where t.id = a.target and a.id = efh.child_application and t.pwdcfg = p.id
        and ep.employment = :new.id and ep.pwdmanagement = pm.id and pm.pwdcfg = p.id
        and efh.parent = :new.entitlement
        and efh.child_int_type = 1
        and ( p.sync is not null and p.sync <> 0 )
        and a.sync_disable = 0
        and efh.ext_fulfillment_limit = 0;
    else
      --delega
      insert into authorizations ( id, person, account_code, entitlement, profile, cod_operation, represented, entitlement_flat_hier, employment )
        select authorizations_seq.nextval, :new.person, pm.code, :new.entitlement, efh.child, code_oper, :new.represented, efh.id, :new.id
        from application a, target t, pwdcfg p, entitlement_flat_hier efh, employment_pwdmanagement ep, pwdmanagement pm 
        where t.id = a.target and a.id = efh.child_application and t.pwdcfg = p.id
        and ep.employment = :new.id and ep.pwdmanagement = pm.id and pm.pwdcfg = p.id
        and efh.parent = :new.entitlement
        and efh.child_int_type = 1
        and ( p.sync is not null and p.sync <> 0 )
        and a.sync_disable = 0
        and efh.ext_fulfillment_limit = 0;
    end if;
  elsif ( :old.state = 0 and :new.state = 1 ) then
    --disable
    if ( :new.parent is null ) then
      --normal
      update authorizations
      set entitlement = null, entitlement_flat_hier = null, cod_operation = code_oper
      where entitlement = :old.entitlement and person = :old.person and represented is null;
    else
      --delegation
      update authorizations
      set entitlement = null, entitlement_flat_hier = null, cod_operation = code_oper
      where entitlement = :old.entitlement and person = :old.person and represented = :old.represented;
    end if;
  end if;

end TRG_MODIFY_EMPLOYMENT;
/
