set define off
declare
  ft_id         numeric(16);
  ft_name       varchar(256) := 'RUN';
  
  im_id         numeric(16);
  im_name       varchar(256) := 'AGC';

  fc_id         numeric(16);
  fc_name       varchar(256) := 'system';
  
  fet_root      numeric(16) := 0;
  fet_rule      numeric(16) := 1;
  fet_group     numeric(16) := 2;
  fet_split     numeric(16) := 3;
  fet_split_con numeric(16) := 4;
  
  fet_par_id    numeric(16);
  fet_par_type  numeric(16);
  
  fevt_id       numeric(16);
  fevt_name     varchar(256) := 'TARGET';
  
  f_id          numeric(16);
  f_name        varchar(256) := 'ACCOUNT_CREATE';

  fr_id         numeric(16);
  fr_name       varchar(256) := 'Update Target Account with Sync Password';
  fr_desc       varchar(512) := '[ V0.1 - 2018-03-23 ]' ;
  
  fr_lob        clob := 'rule "Update Target Account with Sync Password"
'||'when
'||'    event : EventTargetBean(  )
'||'    account : AccountBean(  )
'||'then
'||'
'||'  if (account.getId() != null && account.getPerson_id() != null) {
'||'          logger.info("Update target account with user synchronized password!");
'||'          UserAction.updateAccountWithSyncPassword(sql, account);
'||'   }
'||'
'||'end
';

  counter       numeric(16);
begin
  select count(1) into counter from flow_type t where lower ( t.name ) = lower ( ft_name );
  if ( counter = 1 ) then
    select t.id into ft_id from flow_type t where lower ( t.name ) = lower ( ft_name );
  else
    RAISE_APPLICATION_ERROR ( -20200, 'NO FLOW TYPE FOUND' );
  end if;

  select count(1) into counter from ideas_module t where lower ( t.code ) = lower ( im_name );
  if ( counter = 1 ) then
    select t.id into im_id from ideas_module t where lower ( t.code ) = lower ( im_name );
  else
    RAISE_APPLICATION_ERROR ( -20200, 'NO IDEAS MODULE FOUND' );
  end if;

  select count(1) into counter from flow_context t where lower ( t.name ) = lower ( fc_name );
  if ( counter = 1 ) then
    select t.id into fc_id from flow_context t where lower ( t.name ) = lower ( fc_name );
  else
    RAISE_APPLICATION_ERROR ( -20200, 'NO FLOW CONTEXT FOUND' );
  end if;

  select count(1) into counter from flow_event_type t
  where t.flow_context = fc_id and t.ideas_module = im_id and lower ( t.name ) = lower ( fevt_name );
  if ( counter = 1 ) then
    select t.id into fevt_id from flow_event_type t
    where t.flow_context = fc_id and t.ideas_module = im_id and lower ( t.name ) = lower ( fevt_name );
  else
    RAISE_APPLICATION_ERROR ( -20200, 'NO FLOW EVENT TYPE FOUND' );
  end if;

  select count(1) into counter from flow t
  where t.ideas_module = im_id and t.flow_event_type = fevt_id and lower ( t.name ) = lower ( f_name ); 
  if ( counter = 1 ) then
    select t.id into f_id from flow t
    where t.ideas_module = im_id and t.flow_event_type = fevt_id and lower ( t.name ) = lower ( f_name );
  else
    RAISE_APPLICATION_ERROR ( -20200, 'NO FLOW FOUND' );
  end if;

  select count(1) into counter from flow_rule t where t.flow = f_id and t.ideas_module = im_id and lower ( t.name ) = lower ( fr_name );
  if ( counter = 0 ) then
    select flow_rule_seq.nextval into fr_id from dual;
    insert into flow_rule ( id, flow, name, description, rule_lob, ideas_module )
    values ( fr_id, f_id, fr_name, fr_desc, fr_lob, im_id );
  else
    select t.id into fr_id from flow_rule t where t.flow = f_id and t.ideas_module = im_id and lower ( t.name ) = lower ( fr_name );

    update flow_rule set description = fr_desc where id = fr_id;

    update flow_rule set rule_lob = fr_lob where id = fr_id;
  end if;

end;
/
commit;
set define on
