declare
  counter              number(16);

  -- report type
  rt_id                number(16);
  rt_name              varchar2(256) := 'Export';
  rt_desc              varchar2(512) := '';

  -- report parent
  rp_id                number(16);
  rp_name              varchar2(256) := 'Export';

  -- report
  r_id                 number(16);
  r_name               varchar2(256) := 'Entitlements to Users Bulk Sheet 2';
  r_desc               varchar2(512) := 'This Report format  can show Users and  Entitlements (Business Roles, IT-Roles, Permissions) assigned to them in a format ready for a bulk load. Attention: The import xls must contain two sheets. Be sure to export also sheet 1 to build suitable xls for import purposes.';
  r_code               varchar2(256) := null;
  r_i18n_mess          varchar2(256) := null;
  r_dashboard          number(1) := 0; -- 0: report, 1: dashboard

  -- localization
  r_loc_id             number(16);
  r_loc_code           varchar2(256);

  -- query
  rq_id                number(16);
  rq_name              varchar2(256) := 'Export Entitlement to Users Sheet 2';
  rq_desc              varchar2(512) := 'Query that export data suitable to be imported using batch import function. Entitlements to Users Sheet 2. Attention: The import xls must contain two sheets. Be sure to export also sheet 1 to build suitable xls for import purposes.';
  rqd                  clob;

  rv_name              varchar2(256);
  repv_vis_type        number(2);

  rqf_type_def         varchar2(256) := 'java.lang.String';
  rqf_width_def        number(16) := 300;

  rqf_name_old         varchar2(256);
  rqf_name             varchar2(256);
  rqf_type             varchar2(256);
  rqf_width            number(16);
  rqf_ord_by           number(1);
  rqf_ord_by_clau      varchar2(256);
  loc_code_old         varchar2(256);
  loc_code             varchar2(256);
  loc_rename           boolean;
  i18n_msg             varchar2(256);
  repf_pos_id          number(16);
  repf_pos_id_old      number(16);

  repfr_id             number(16);
  repfr_name_old       varchar2(256);
  repfr_name           varchar2(256);
  repfr_value          varchar2(256);
  repfr_l_id           number(16);
  repfr_l_code_old     varchar2(256);
  repfr_l_code         varchar2(256);
  repfr_i18n_msg       varchar2(256);
  repfr_vis            number(16);
  repfr_mand           number(16);
  repfr_type           number(16);
  repfr_cust_id        number(16);
  repfr_cust_name      varchar2(256);
  repfr_posit_id       number(16);
  repfr_posit_id_old   number(16);

  cur_lan              sys_refcursor;
  lan_id               number(16);

  v_ret                number(16);

begin
  rqd := 'select empwd.employment	 as BATCH_ASSIGNMENT_REF, 
'||'      			pwdm.code        as BATCH_ACCOUNT_ID, 
'||'      			pwdc.name        as BATCH_ACCOUNT_CONF_NAME 
'||'      			from #pmschema#.employment_pwdmanagement empwd 
'||'      			left join #pmschema#.pwdmanagement pwdm 
'||'      			  on empwd.pwdmanagement = pwdm.id 
'||'      			left join #pmschema#.pwdcfg pwdc 
'||'      			  on pwdm.pwdcfg = pwdc.id
'||'      			order by empwd.employment
';

  select count(1) into counter from r_query t where lower ( t.name ) = lower ( rq_name ) and t.product = 1;
  if ( counter = 0 ) then
    select max(id) + 1 into rq_id from r_query t;

    insert into r_query ( id, name, description, product )
    values ( rq_id, rq_name, rq_desc, 1 );

    insert into r_query_data ( r_query, query )
    values ( rq_id, rqd );
  else
    select t.id into rq_id from r_query t where lower ( t.name ) = lower ( rq_name ) and t.product = 1;

    update r_query set description = rq_desc where id = rq_id;

    update r_query_data set query = rqd where r_query = rq_id;
  end if;

  select count(1) into counter from report t where lower ( t.name ) = lower ( r_name ) and t.dashboard = r_dashboard and t.product = 1;
  if ( counter = 0 ) then
    if ( r_loc_code is null ) then
      /*DBALT-BEGIN*/
      select dbms_random.random into r_loc_code from dual;
      /*PG*select trunc(random()*1000) into r_loc_code from generate_series(1,1000) limit 1;*PG*/
      /*DB2*select int((rand()-0.5) * 32768) into r_loc_code from dual;*DB2*/
      /*DBALT-END*/

      select count(1) into counter from localization t where lower ( t.code ) = lower ( r_loc_code );
      if ( counter = 0 ) then
        select localization_seq.nextval into r_loc_id from dual;
        insert into localization ( id, code, code_type )
        values ( r_loc_id, r_loc_code, 0 );
      end if;

    else
      select count(1) into counter from localization t where lower ( t.code ) = lower ( r_loc_code );
      if ( counter = 1 ) then
        select t.id into r_loc_id from localization t where lower ( t.code ) = lower ( r_loc_code );
      end if;
    end if;

    if ( r_loc_id is null ) then
      select t.id into r_loc_id from localization t where lower ( t.code ) = lower ( r_loc_code );
    end if;

    select max(id) + 1 into r_id from report t;

    if ( rt_name is not null or length ( rt_name ) > 0 ) then
      select count(1) into counter from report_type t where lower ( t.name ) = lower ( rt_name );
      if ( counter = 0 ) then
        select ( max(id) +1 ) into rt_id from report_type t;

        insert into report_type ( id, name, description )
        values ( rt_id, rt_name, rt_desc );
      else
        select t.id into rt_id from report_type t where lower ( t.name ) = lower ( rt_name );
      end if;
    end if;

    insert into report ( id, name, description, localization, r_query, status, report_type, code, product, parent, summary_sheet, dashboard )
    values ( r_id, r_name, r_desc, r_loc_id, rq_id, 0, rt_id, r_code, 1, 1, 0, r_dashboard );

    insert into report_attribute ( id, report, name, value )
    values ( report_attribute_seq.nextval, r_id, 'PRIORITY', '0' );
    if ( r_dashboard = 0 ) then
      insert into report_attribute ( id, report, name, value )
      values ( report_attribute_seq.nextval, r_id, 'ORIENTATION', '1' );
      insert into report_attribute ( id, report, name, value )
      values ( report_attribute_seq.nextval, r_id, 'MAX_ROW', null );
      insert into report_attribute ( id, report, name, value )
      values ( report_attribute_seq.nextval, r_id, 'FORMAT', 'xlsx' );
    end if;
  
  else
    select t.id, t.name into r_id, r_name from report t where lower ( t.name ) = lower ( r_name ) and t.dashboard = r_dashboard and t.product = 1;
    select t.localization into r_loc_id from report t where t.id = r_id;
    update report set r_query = rq_id where id = r_id;
  end if;

  if ( r_i18n_mess is null or length ( r_i18n_mess ) = 0 ) then
    r_i18n_mess := r_name;
  end if;

  open cur_lan for select t.id from language t where t.language_status > 0;
  loop
    fetch cur_lan into lan_id;
    exit when cur_lan%NOTFOUND;

    select count(1) into counter from i18n_message t where t.language = lan_id and t.localization = r_loc_id;
    if ( counter = 0 ) then
      insert into i18n_message ( id, localization, language, message )
      values ( i18n_message_seq.nextval, r_loc_id, lan_id, r_i18n_mess );
    else
      update i18n_message set message = r_i18n_mess where language = lan_id and localization = r_loc_id;
    end if;
  end loop;
  close cur_lan;

  -- Report PARENT
  select count(1) into counter from (
    select distinct r.id from report r, localization l, i18n_message i18
    where r.localization = l.id and r.leaf = 0 and l.id = i18.localization
    and i18.message = rp_name and r.dashboard = r_dashboard ) t;
  if ( counter = 1 ) then
    select distinct r.id into rp_id from report r, localization l, i18n_message i18
    where r.localization = l.id and r.leaf = 0 and l.id = i18.localization
    and i18.message = rp_name and r.dashboard = r_dashboard;

    update report set parent = rp_id where id = r_id;
  end if;

  -- Report FIELD 1
  rqf_name_old    := null;
  rqf_name        := 'BATCH_ASSIGNMENT_REF';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'assignment.ref';
  loc_rename      := true;
  i18n_msg        := 'ASSIGNMENT_REF';
  repf_pos_id_old := null;
  repf_pos_id     := null;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );

  -- Report FIELD 2
  rqf_name_old    := null;
  rqf_name        := 'BATCH_ACCOUNT_ID';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'account.id';
  loc_rename      := true;
  i18n_msg        := 'ACCOUNT_ID';
  repf_pos_id_old := null;
  repf_pos_id     := null;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );

  -- Report FIELD 3
  rqf_name_old    := null;
  rqf_name        := 'BATCH_ACCOUNT_CONF_NAME';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'account.configuration_name';
  loc_rename      := true;
  i18n_msg        := 'ACCOUNT_CONFIGURATION_NAME';
  repf_pos_id_old := null;
  repf_pos_id     := null;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );

end;
/
commit;
