declare
  rq_id               numeric(16);
  rq_name         	  varchar(256) := 'Export Entitlement to Users';
  rq_newname      	  varchar(256) := 'Export Entitlement to Users Sheet 1';
  rq_desc     	      varchar(512) := 'Query that export data suitable to be imported using batch import function. Entitlements to Users Sheet 1. Attention: The import xls must contain two sheets. Be sure to export also sheet 2 to build suitable xls for import purposes.';
  rqd                 clob;
  counter             numeric(16);
  
  -- report
  r_id                numeric(16);
  r_name              varchar(256) := 'Entitlements to Users Bulk';
  r_desc              varchar(512) := 'This Report format  can show Users and  Entitlements (Business Roles, IT-Roles, Permissions) assigned to them in a format ready for a bulk load. Attention: The import xls must contain two sheets. Be sure to export also sheet 2 to build suitable xls for import purposes.';

  rqf_type_def        varchar(256) := 'java.lang.String';
  rqf_width_def       numeric(16) := 300;

  rqf_name_old        varchar(256);
  rqf_name            varchar(256);
  rqf_type            varchar(256);
  rqf_width           numeric(16);
  rqf_ord_by          numeric(1);
  rqf_ord_by_clau     varchar(256);
  loc_code_old        varchar(256);
  loc_code            varchar(256);
  loc_rename          boolean;
  i18n_msg            varchar(256);
  repf_pos_id         numeric(16);
  repf_pos_id_old     numeric(16);

  v_ret               numeric(16);

begin
  rqd := 'select distinct emp.MASTER_UID       					 as BATCH_MASTER_UID,
'||'                emp.GROUP_CODE             					 as BATCH_GROUP_CODE,
'||'				emp.HIERARCHY_NAME          				 as BATCH_HIERARCHY_NAME,
'||'                ''FALSE''                  				     as BATCH_IN_HIER,
'||'                emp.ENTITLEMENT_NAME        				 as BATCH_ENTITLEMENT_NAME,
'||'                emp.ENTITLEMENT_CODE       				     as BATCH_ENTITLEMENT_CODE,
'||'                case
'||'                  when emp.entitlement_type = 3 then ''BUSINESS_ROLE''
'||'                  when emp.entitlement_type = 2 then ''ITROLE''
'||'                 when emp.entitlement_ext_type = 3 then ''PERMISSION''
'||'                  when emp.entitlement_ext_type = 4 then ''EXTERNAL_ROLE''
'||'                end                         				 as BATCH_ENTITLEMENT_TYPE,
'||'                emp.ENTITLEMENT_APPLICATION 				 as BATCH_ENTITLEMENT_APPLICATION,
'||'                emp.PERMISSION_TYPE         				 as BATCH_PERMISSION_TYPE,
'||'				emp.ACCOUNT_ID              				 as BATCH_ACCOUNT_ID,
'||'				emp.ACCOUNT_CONF_NAME      					 as BATCH_ACCOUNT_CONF_NAME,
'||'				emp.ASSIGNMENT_REF						     as BATCH_ASSIGNMENT_REF
'||'  from (
'||'        --profiles assigned to users
'||'        select distinct p.code     as MASTER_UID,
'||'                        ou.code    as GROUP_CODE,
'||'						hier.name  as HIERARCHY_NAME,
'||'                        e.name     as ENTITLEMENT_NAME,
'||'                        e.code     as ENTITLEMENT_CODE,
'||'                        e.int_type as ENTITLEMENT_TYPE,
'||'                        e.ext_type as ENTITLEMENT_EXT_TYPE,
'||'                        a.name     as ENTITLEMENT_APPLICATION,
'||'                        ft.name    as PERMISSION_TYPE,
'||'						null       as ACCOUNT_ID,
'||'						null       as ACCOUNT_CONF_NAME,
'||'						emp.id     as ASSIGNMENT_REF
'||'          from #pmschema#.employment emp
'||'					left join #pmschema#.job_unit ju on emp.job_unit = ju.id
'||'					left join #pmschema#.organizational_unit ou on ju.organizational_unit = ou.id
'||'					left join #pmschema#.hierarchy hier on ju.hierarchy = hier.id,
'||'               #pmschema#.person              p,
'||'               #pmschema#.entitlement         e,
'||'               #pmschema#.application         a,
'||'               #pmschema#.profile_type  ft
'||'         where emp.person = p.id
'||'           and emp.entitlement = e.id
'||'           and e.application = a.id
'||'          and a.id = ft.application
'||'           and e.profile_type = ft.id
'||'		   and e.int_type = 1
'||'        union
'||'        --itroles assigned to users
'||'        select distinct p.code     as MASTER_UID,
'||'                        ou.code    as GROUP_CODE,
'||'						hier.name  as HIERARCHY_NAME,
'||'                        e.name     as ENTITLEMENT_NAME,
'||'                        e.code     as ENTITLEMENT_CODE,
'||'                        e.int_type as ENTITLEMENT_TYPE,
'||'                        e.ext_type as ENTITLEMENT_EXT_TYPE,
'||'                        a.name     as ENTITLEMENT_APPLICATION,
'||'                        null       as PERMISSION_TYPE,
'||'						null       as ACCOUNT_ID,
'||'						null       as ACCOUNT_CONF_NAME,
'||'						emp.id     as ASSIGNMENT_REF
'||'          from #pmschema#.employment          emp
'||'		  			left join #pmschema#.job_unit ju on emp.job_unit = ju.id
'||'					left join #pmschema#.organizational_unit ou on ju.organizational_unit = ou.id
'||'					left join #pmschema#.hierarchy hier on ju.hierarchy = hier.id,
'||'              #pmschema#.person              p,
'||'              #pmschema#.entitlement         e,
'||'              #pmschema#.application         a
'||'         where emp.person = p.id
'||'           and emp.entitlement = e.id
'||'           and e.application = a.id
'||'           and e.int_type = 2
'||'        union
'||'        --business roles assigned to users
'||'        select distinct p.code     as MASTER_UID,
'||'                        ou.code    as GROUP_CODE,
'||'						hier.name  as HIERARCHY_NAME,
'||'                        e.name     as ENTITLEMENT_NAME,
'||'                        e.code     as ENTITLEMENT_CODE,
'||'                        e.int_type as ENTITLEMENT_TYPE,
'||'                        e.ext_type as ENTITLEMENT_EXT_TYPE,
'||'                        null       as ENTITLEMENT_APPLICATION,
'||'                        null       as PERMISSION_TYPE,
'||'						null       as ACCOUNT_ID,
'||'						null       as ACCOUNT_CONF_NAME,
'||'						emp.id     as ASSIGNMENT_REF
'||'          from #pmschema#.employment          emp
'||'					left join #pmschema#.job_unit ju on emp.job_unit = ju.id
'||'					left join #pmschema#.organizational_unit ou on ju.organizational_unit = ou.id
'||'					left join #pmschema#.hierarchy hier on ju.hierarchy = hier.id,
'||'               #pmschema#.person              p,
'||'               #pmschema#.entitlement         e
'||'         where emp.person = p.id
'||'           and emp.entitlement = e.id
'||'           and e.int_type = 3) emp order by emp.ASSIGNMENT_REF
';

  select count(1) into counter from r_query t where lower ( t.name ) = lower ( rq_name ) and t.product = 1;
  if ( counter = 1 ) then
	select t.id into rq_id from r_query t where lower ( t.name ) = lower ( rq_name ) and t.product = 1;

    update r_query set name = rq_newname, description = rq_desc where id = rq_id;

    update r_query_data set query = rqd where r_query = rq_id;
  else
	select count(1) into counter from r_query t where lower ( t.name ) = lower ( rq_newname ) and t.product = 1;
	if ( counter = 0 ) then
		select max(id) + 1 into rq_id from r_query t;

		insert into r_query ( id, name, description, product )
		values ( rq_id, rq_newname, rq_desc, 1 );

		insert into r_query_data ( r_query, query )
		values ( rq_id, rqd );
	else
		select t.id into rq_id from r_query t where lower ( t.name ) = lower ( rq_newname ) and t.product = 1;
		
		update r_query set description = rq_desc where id = rq_id;

		update r_query_data set query = rqd where r_query = rq_id;
	end if;
  end if;

  update report set description = r_desc where name = r_name and dashboard = 0 and product = 1;
  
   -- Report FIELD 0
  rqf_name_old    := 'BATCH_USER_CODE';
  rqf_name        := 'BATCH_MASTER_UID';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'master.uid';
  loc_rename      := true;
  i18n_msg        := 'MASTER_UID';
  repf_pos_id_old := null;
  repf_pos_id     := 0;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );

  -- Report FIELD 1
  rqf_name_old    := 'BATCH_USER_OU';
  rqf_name        := 'BATCH_GROUP_CODE';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'group.code';
  loc_rename      := true;
  i18n_msg        := 'GROUP_CODE';
  repf_pos_id_old := null;
  repf_pos_id     := 1;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );

  -- Report FIELD 2
  rqf_name_old    := null;
  rqf_name        := 'BATCH_HIERARCHY_NAME';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'hierarchy.name';
  loc_rename      := true;
  i18n_msg        := 'HIERARCHY_NAME';
  repf_pos_id_old := null;
  repf_pos_id     := 2;
  
  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );
  
  -- Report FIELD 8
  rqf_name_old    := 'BATCH_PROFILE_TYPE';
  rqf_name        := 'BATCH_PERMISSION_TYPE';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'permission.type';
  loc_rename      := true;
  i18n_msg        := 'PERMISSION_TYPE';
  repf_pos_id_old := null;
  repf_pos_id     := null;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );
  
  -- Report FIELD 9
  rqf_name_old    := null;
  rqf_name        := 'BATCH_ACCOUNT_ID';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'account.id';
  loc_rename      := true;
  i18n_msg        := 'ACCOUNT_ID';
  repf_pos_id_old := null;
  repf_pos_id     := 9;
  
  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );
  
  -- Report FIELD 10
  rqf_name_old    := null;
  rqf_name        := 'BATCH_ACCOUNT_CONF_NAME';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'account.configuration_name';
  loc_rename      := true;
  i18n_msg        := 'ACCOUNT_CONFIGURATION_NAME';
  repf_pos_id_old := null;
  repf_pos_id     := 10;
  
  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );

  -- Report FIELD 11
  rqf_name_old    := null;
  rqf_name        := 'BATCH_ASSIGNMENT_REF';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'assignment.ref';
  loc_rename      := true;
  i18n_msg        := 'ASSIGNMENT_REF';
  repf_pos_id_old := null;
  repf_pos_id     := 11;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );

  
end;
/
commit;

