declare
  counter              number(16);

  -- report
  r_id                 number(16);
  r_name               varchar2(256) := 'Account Status';
  r_desc               varchar2(512) := 'These Reports show Accounts associated to Users. For each Account, details and status are provided together with possible locking codes.';
  r_code               varchar2(256) := null;
  r_i18n_mess          varchar2(256) := null;
  r_dashboard          number(1) := 0; -- 0: report, 1: dashboard

  -- localization
  r_loc_id             number(16);
  r_loc_code           varchar2(256);

  -- query
  rq_id                number(16);
  rq_name              varchar2(256) := 'User. Account Status';
  rq_desc              varchar2(512) := 'User accounts status';
  rqd                  clob;

  rv_name              varchar2(256);
  repv_vis_type        number(2);

  rqf_type_def         varchar2(256) := 'java.lang.String';
  rqf_width_def        number(16) := 300;

  rqf_name_old         varchar2(256);
  rqf_name             varchar2(256);
  rqf_type             varchar2(256);
  rqf_width            number(16);
  rqf_ord_by           number(1);
  rqf_ord_by_clau      varchar2(256);
  loc_code_old         varchar2(256);
  loc_code             varchar2(256);
  loc_rename           boolean;
  i18n_msg             varchar2(256);
  repf_pos_id          number(16);
  repf_pos_id_old      number(16);

  repfr_id             number(16);
  repfr_name_old       varchar2(256);
  repfr_name           varchar2(256);
  repfr_value          varchar2(256);
  repfr_l_id           number(16);
  repfr_l_code_old     varchar2(256);
  repfr_l_code         varchar2(256);
  repfr_i18n_msg       varchar2(256);
  repfr_vis            number(16);
  repfr_mand           number(16);
  repfr_type           number(16);
  repfr_cust_id        number(16);
  repfr_cust_name      varchar2(256);
  repfr_posit_id       number(16);
  repfr_posit_id_old   number(16);

  v_ret                number(16);

begin
  rqd := 'select distinct p.code as USER_CODE,
'||'                p.name as USER_NAME,
'||'                p.surname as USER_SURNAME,
'||'                p.email as USER_EMAIL,
'||'                p.dn as USER_DN,
'||'                p.cod_fisc as USER_SSN,
'||'                case
'||'                  when p.sex=''0'' then ''Male''
'||'                  when p.sex=''1'' then ''Female''
'||'                end as USER_GENDER,
'||'                pwdcfg.name as PWDCONFIG_NAME,
'||'                pwdcfg.description as PWDCONFIG_DESC,
'||'                pwdman.code as ACCOUNT_CODE,
'||'				case 
'||'                  when pwdman.is_default = 0 then '''' 
'||'                  when pwdman.is_default = 1 then ''Default''  
'||'                end as ACCOUNT_IS_DEFAULT,
'||'				pwdmType.name as ACCOUNT_TYPE,
'||'                pwdman.expire as ACCOUNT_EXPIRY_DATE,
'||'                case
'||'                  when pwdman.disabled = 0 then ''Active''
'||'                  when pwdman.disabled = 1 then ''Disabled''
'||'                end as ACCOUNT_STATUS,
'||'                trim((case
'||'                       when cast(substr(pwdman.attr2, 1, 1) as numeric) > 0 then
'||'                        ''Technical ''
'||'                       else
'||'                        ''''
'||'                     end) || (case
'||'                       when cast(substr(pwdman.attr2, 2, 1) as numeric) > 0 then
'||'                        ''Security ''
'||'                       else
'||'                        ''''
'||'                     end) || (case
'||'                       when cast(substr(pwdman.attr2, 3, 1) as numeric) > 0 then
'||'                        ''Terminated ''
'||'                       else
'||'                        ''''
'||'                     end) || (case
'||'                       when cast(substr(pwdman.attr2, 4, 1) as numeric) > 0 then
'||'                        ''Authoritative ''
'||'                       else
'||'                        ''''
'||'                     end) || (case
'||'                       when cast(substr(pwdman.attr2, 5, 1) as numeric) > 0 then
'||'                        ''Expire ''
'||'                       else
'||'                        ''''
'||'                     end) || (case
'||'                       when cast(substr(pwdman.attr2, 6, 1) as numeric) > 0 then
'||'                        ''Maintenance ''
'||'                       else
'||'                        ''''
'||'                     end)) as ACCOUNT_LOCK_REASON
'||'  from #pmschema#.person                p,
'||'       #pmschema#.pwdmanagement         pwdman
'||'			left join #pmschema#.pwdmanagement_type pwdmType
'||'				on pwdman.pwdmanagement_type = pwdmType.id,
'||'       #pmschema#.pwdcfg                pwdcfg,
'||'       #pmschema#.organizational_unit   org,
'||'       #schema_tmp#.tmp_rep_organizational_unit tmpou,
'||'       #schema_tmp#.tmp_rep_pwdcfg              tmppwd
'||' where tmpou.id = org.id
'||'   and p.organizational_unit = org.id
'||'   and p.id = pwdman.person
'||'   and pwdman.pwdcfg = pwdcfg.id
'||'   and tmppwd.id = pwdcfg.id
'||'   and upper(org.code) like upper(''#ou_code#'')
'||'   and upper(p.name) like upper(''#user_name#'')
'||'   and upper(p.surname) like upper(''#user_surname#'')
'||'   and upper(p.code) like upper(''#user_code#'')
'||'   and upper(pwdcfg.name) like upper(''#pwdcfg_name#'')
'||'   and upper(pwdman.code) like upper(''#account_code#'')
'||'   and upper(pwdmType.name) like upper(''#account_type_name#'')
'||'   and upper(pwdcfg.name) like upper(''#pwdcfg_name#'')
'||'   and org.hierarchy = 1
';

  select count(1) into counter from r_query t where lower ( t.name ) = lower ( rq_name ) and t.product = 1;
  if ( counter = 0 ) then
    select max(id) + 1 into rq_id from r_query t;

    insert into r_query ( id, name, description, product )
    values ( rq_id, rq_name, rq_desc, 1 );

    insert into r_query_data ( r_query, query )
    values ( rq_id, rqd );
  else
    select t.id into rq_id from r_query t where lower ( t.name ) = lower ( rq_name ) and t.product = 1;

    update r_query_data set query = rqd where r_query = rq_id;
  end if;

  -- Report FIELD 1
  rqf_name_old    := null;
  rqf_name        := 'ACCOUNT_IS_DEFAULT';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'account.is_default';
  loc_rename      := true;
  i18n_msg        := 'Is Default';
  repf_pos_id_old := null;
  repf_pos_id     := 5;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );
							  
   -- Report FIELD 2
  rqf_name_old    := null;
  rqf_name        := 'ACCOUNT_TYPE';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'account.type';
  loc_rename      := true;
  i18n_msg        := 'Account Type';
  repf_pos_id_old := null;
  repf_pos_id     := 6;


  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );
							  
  -- REPORT FILTERS
  
  repfr_name_old     := null;
  repfr_name         := 'account_code';
  repfr_value        := null;
  repfr_l_code_old   := null;
  repfr_l_code       := 'account.code';
  repfr_i18n_msg     := 'Account Code';
  repfr_vis          := 1;
  repfr_mand         := 0;
  repfr_type         := 0;
  repfr_cust_id      := null;
  repfr_cust_name    := null;
  repfr_posit_id_old := null;
  repfr_posit_id     := null;

  v_ret := inst_rep_add_fil ( rq_id, repfr_name, repfr_value, repfr_l_code_old, repfr_l_code, repfr_i18n_msg, repfr_vis,
                              repfr_mand, repfr_type, repfr_cust_name, repfr_posit_id_old, repfr_posit_id );

  repfr_name_old     := null;
  repfr_name         := 'account_type_name';
  repfr_value        := null;
  repfr_l_code_old   := null;
  repfr_l_code       := 'account.type';
  repfr_i18n_msg     := 'Account Type';
  repfr_vis          := 1;
  repfr_mand         := 0;
  repfr_type         := 0;
  repfr_cust_id      := null;
  repfr_cust_name    := null;
  repfr_posit_id_old := null;
  repfr_posit_id     := null;

  v_ret := inst_rep_add_fil ( rq_id, repfr_name, repfr_value, repfr_l_code_old, repfr_l_code, repfr_i18n_msg, repfr_vis,
                              repfr_mand, repfr_type, repfr_cust_name, repfr_posit_id_old, repfr_posit_id );
							  
end;
/
commit;

