declare
  counter              numeric(16);

  -- report
  r_id                 numeric(16);
  r_name               varchar(256) := 'Delegation assignments';
  r_desc               varchar(512) := 'This Report documents who is really delegated and for what Entitlements  in the system.  In particular it details on delegation assignments with information on delegated and represented Users (together with their details such as belonging OUs, email, ...), and delegated Entitlements (including  validity start-end dates).';
  r_code               varchar(256) := null;
  r_i18n_mess          varchar(256) := null;
  r_dashboard          numeric(1) := 0; -- 0: report, 1: dashboard

  -- localization
  r_loc_id             numeric(16);
  r_loc_code           varchar(256);

  -- query
  rq_id                numeric(16);
  rq_name              varchar(256) := 'User. Entitlement assignment by delegation';
  rq_desc              varchar(512) := 'User with entitlement assigned by delegation';
  rqd                  clob;

  rqf_type_def         varchar(256) := 'java.lang.String';
  rqf_width_def        numeric(16) := 300;

  rqf_name_old         varchar(256);
  rqf_name             varchar(256);
  rqf_type             varchar(256);
  rqf_width            numeric(16);
  rqf_ord_by           numeric(1);
  rqf_ord_by_clau      varchar(256);
  loc_code_old         varchar(256);
  loc_code             varchar(256);
  loc_rename           boolean;
  i18n_msg             varchar(256);
  repf_pos_id          numeric(16);
  repf_pos_id_old      numeric(16);

  repfr_id             numeric(16);
  repfr_name_old       varchar(256);
  repfr_name           varchar(256);
  repfr_value          varchar(256);
  repfr_l_id           numeric(16);
  repfr_l_code_old     varchar(256);
  repfr_l_code         varchar(256);
  repfr_i18n_msg       varchar(256);
  repfr_vis            numeric(16);
  repfr_mand           numeric(16);
  repfr_type           numeric(16);
  repfr_cust_id        numeric(16);
  repfr_cust_name      varchar(256);
  repfr_posit_id       numeric(16);
  repfr_posit_id_old   numeric(16);

  v_ret                numeric(16);

begin
  rqd := 'select distinct p1.code as USER_CODE,
'||'                p1.name as USER_NAME,
'||'                p1.surname as USER_SURNAME,
'||'                p1.email as USER_EMAIL,
'||'                p1.dn as USER_DN,
'||'                p1.cod_fisc as USER_SSN,
'||'                case
'||'                  when p1.sex=''0'' then ''Male''
'||'                  when p1.sex=''1'' then ''Female''
'||'                end as USER_GENDER,
'||'                ou1.code as OU_CODE,
'||'                ou1.name as OU_NAME,
'||'                ou1.description as OU_DESC,
'||'                pwdmdel.code as ACCOUNT_CODE,
'||'                a.name as APPLICATION_NAME,
'||'                a.description as APPLICATION_DESC,
'||'                e.name as ENTITLEMENT_NAME,
'||'                e.description as ENTITLEMENT_DESC,
'||'                case
'||'                  when e.ext_type = 3 then ''Permission''
'||'                  when e.ext_type = 4 then ''External Role''
'||'                  when e.int_type = 2 then ''IT Role''
'||'                  when e.int_type = 3 then ''Business Role''
'||'                end as ENTITLEMENT_TYPE,
'||'                d.start_date as DELEGATION_START_DATE,
'||'                d.end_date as DELEGATION_END_DATE,
'||'                p2.code as REPRESENTED_CODE,
'||'                p2.name as REPRESENTED_NAME,
'||'                p2.surname as REPRESENTED_SURNAME,
'||'                pwdmrep.code as REPRESENTED_ACCOUNT_CODE,
'||'                p2.email as REPRESENTED_EMAIL,
'||'                p2.dn as REPRESENTED_DN,
'||'                p2.cod_fisc as REPRESENTED_SSN,
'||'                case
'||'                  when p2.sex=''0'' then ''Male''
'||'                  when p2.sex=''1'' then ''Female''
'||'                end as REPRESENTED_GENDER,
'||'                ou2.code as REPRESENTED_OU_CODE,
'||'                ou2.name as REPRESENTED_OU_NAME,
'||'                ou2.description as REPRESENTED_OU_DESC
'||'  from #pmschema#.application              a
'||'		 left join #pmschema#.target tar on tar.id = a.target,
'||'       #pmschema#.entitlement_flat_hier    efh,
'||'       #pmschema#.entitlement              e,
'||'       #pmschema#.employment               d
'||'         left join #pmschema#.employment_pwdmanagement empwd on d.id = empwd.employment
'||'         left join #pmschema#.pwdmanagement pwdmdel on empwd.pwdmanagement = pwdmdel.id,
'||'       #pmschema#.employment               rep
'||'         left join #pmschema#.employment_pwdmanagement empwrep on rep.id = empwrep.employment
'||'         left join #pmschema#.pwdmanagement pwdmrep on empwrep.pwdmanagement = pwdmrep.id,
'||'       #pmschema#.person                   p1,
'||'       #pmschema#.organizational_unit      ou1,
'||'       #pmschema#.person                   p2,
'||'       #pmschema#.organizational_unit      ou2
'||' where  a.id = efh.child_application
'||'   and efh.child_int_type = 1
'||'   and efh.parent = d.entitlement
'||'   and d.entitlement = e.id
'||'   and d.person = p1.id
'||'   and d.parent is not null
'||'   and p1.organizational_unit = ou1.id
'||'   and d.represented = p2.id
'||'   and rep.id = d.parent
'||'   and p2.organizational_unit = ou2.id
'||'   and d.hierarchy = 1
'||'   and d.hierarchy = ou1.hierarchy
'||'   and ou1.hierarchy = ou2.hierarchy
'||'   and pwdmdel.pwdcfg = tar.pwdcfg
'||'   and pwdmrep.pwdcfg = tar.pwdcfg
'||' order by p1.code, a.name, e.name
';

  select count(1) into counter from r_query t where lower ( t.name ) = lower ( rq_name ) and t.product = 1;
  if ( counter = 0 ) then
    select max(id) + 1 into rq_id from r_query t;

    insert into r_query ( id, name, description, product )
    values ( rq_id, rq_name, rq_desc, 1 );

    insert into r_query_data ( r_query, query )
    values ( rq_id, rqd );
  else
    select t.id into rq_id from r_query t where lower ( t.name ) = lower ( rq_name ) and t.product = 1;

    update r_query set description = rq_desc where id = rq_id;
    update r_query_data set query = rqd where r_query = rq_id;
  end if;

  -- Report FIELD 1
  rqf_name_old    := null;
  rqf_name        := 'ACCOUNT_CODE';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'account.code';
  loc_rename      := true;
  i18n_msg        := 'Account Code';
  repf_pos_id_old := null;
  repf_pos_id     := 6;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );
							  
  -- Report FIELD 2
  rqf_name_old    := null;
  rqf_name        := 'REPRESENTED_ACCOUNT_CODE';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'represented.account.code';
  loc_rename      := true;
  i18n_msg        := 'Delegant Account Code';
  repf_pos_id_old := null;
  repf_pos_id     := 13;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );

end;
/
commit;
