declare
  counter              numeric(16);

  -- report
  r_id                 numeric(16);
  r_name               varchar(256) := 'User Assignments Changes';
  r_code               varchar(256) := null;
  r_i18n_mess          varchar(256) := null;
  r_dashboard          numeric(1) := 0; -- 0: report, 1: dashboard

  -- localization
  r_loc_id             numeric(16);
  r_loc_code           varchar(256);

  -- query
  rq_id                numeric(16);
  rq_name              varchar(256) := 'User. Authorization Changed in the period';
  rq_desc              varchar(512) := 'Users that has been changed on authorization in the week before';
  rqd                  clob;

  rqf_type_def         varchar(256) := 'java.lang.String';
  rqf_width_def        numeric(16) := 300;

  rqf_name_old         varchar(256);
  rqf_name             varchar(256);
  rqf_type             varchar(256);
  rqf_width            numeric(16);
  rqf_ord_by           numeric(1);
  rqf_ord_by_clau      varchar(256);
  loc_code_old         varchar(256);
  loc_code             varchar(256);
  loc_rename           boolean;
  i18n_msg             varchar(256);
  repf_pos_id          numeric(16);
  repf_pos_id_old      numeric(16);

  v_ret                numeric(16);

begin
  rqd := 'select distinct p.code                                                             as USER_CODE,
'||'                p.surname                                                                as USER_SURNAME,
'||'                p.name                                                                   as USER_NAME,
'||'                ou.code                                                                  as OU_CODE,
'||'                ou.name                                                                  as OU_NAME,
'||'                ou.description                                                           as OU_DESC,
'||'				pwdm.code																 as ACCOUNT_CODE,
'||'                e.name                                                                   as ENTITLEMENT_NAME,
'||'                case
'||'                  when e.ext_type = 3 then ''Permission''
'||'                  when e.ext_type = 4 then ''External Role''
'||'                  when e.int_type = 2 then ''IT Role''
'||'                  when e.int_type = 3 then ''Business Role''
'||'                end                                                                      as ENTITLEMENT_TYPE,
'||'                a.name                                                                   as APPLICATION_NAME,
'||'                emp.last_mod_time                                                        as LAST_MOD_TIME
'||'  from   #pmschema#.employment               emp
'||'         left join  #pmschema#.employment_pwdmanagement empwd on emp.id = empwd.employment
'||'         left join  #pmschema#.pwdmanagement pwdm on empwd.pwdmanagement = pwdm.id,
'||'        #pmschema#.person                   p,
'||'        #pmschema#.organizational_unit      ou,
'||'        #pmschema#.entitlement              e,
'||'        #pmschema#.entitlement_flat_hier    efh,
'||'        #pmschema#.application              a
'||'        left join #pmschema#.target tar on tar.id = a.target
'||' where emp.person = p.id
'||'   and emp.entitlement = e.id
'||'   and p.organizational_unit = ou.id
'||'   and e.id = efh.parent
'||'   and efh.child_application = a.id
'||'   and efh.child_int_type = 1
'||'   and emp.last_mod_time >=
'||'       to_date(extract(year from current_date - 7) || ''/'' ||
'||'               extract(month from current_date - 7) || ''/'' ||
'||'               extract(day from current_date - 7) || '' 00:00:01'', ''yyyy/mm/dd hh24:mi:ss'')
'||'   and emp.hierarchy = 1
'||'   and emp.hierarchy = ou.hierarchy
'||'   and pwdm.pwdcfg = tar.pwdcfg
';

  select count(1) into counter from r_query t where lower ( t.name ) = lower ( rq_name ) and t.product = 1;
  if ( counter = 0 ) then
    select max(id) + 1 into rq_id from r_query t;

    insert into r_query ( id, name, description, product )
    values ( rq_id, rq_name, rq_desc, 1 );

    insert into r_query_data ( r_query, query )
    values ( rq_id, rqd );
  else
    select t.id into rq_id from r_query t where lower ( t.name ) = lower ( rq_name ) and t.product = 1;

    update r_query_data set query = rqd where r_query = rq_id;
  end if;

  -- Report FIELD 1
  rqf_name_old    := null;
  rqf_name        := 'ACCOUNT_CODE';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'account.code';
  loc_rename      := true;
  i18n_msg        := 'Account Code';
  repf_pos_id_old := null;
  repf_pos_id     := 5;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );

end;
/
commit;

