declare
  counter              number(16);

  -- report
  r_id                 number(16);
  r_name               varchar2(256) := 'User Assignments';
  r_desc               varchar2(512) := 'This Report format provides a user-centric view of access rights. Users are selected depending on your visibility settings.    For each of the selected Users, the report shows the Entitlements (Permissions, IT-roles, Business Roles) that are directly assigned  to the User.';
  r_code               varchar2(256) := null;
  r_i18n_mess          varchar2(256) := null;
  r_dashboard          number(1) := 0; -- 0: report, 1: dashboard

  -- localization
  r_loc_id             number(16);
  r_loc_code           varchar2(256);

  -- query
  rq_id                number(16);
  rq_name              varchar2(256) := 'User. Entitlement assignment';
  rq_desc              varchar2(512) := 'Users with assigned entitlements';
  rqd                  clob;

  rqf_type_def         varchar2(256) := 'java.lang.String';
  rqf_width_def        number(16) := 300;

  rqf_name_old         varchar2(256);
  rqf_name             varchar2(256);
  rqf_type             varchar2(256);
  rqf_width            number(16);
  rqf_ord_by           number(1);
  rqf_ord_by_clau      varchar2(256);
  loc_code_old         varchar2(256);
  loc_code             varchar2(256);
  loc_rename           boolean;
  i18n_msg             varchar2(256);
  repf_pos_id          number(16);
  repf_pos_id_old      number(16);

  repfr_id             number(16);
  repfr_name_old       varchar2(256);
  repfr_name           varchar2(256);
  repfr_value          varchar2(256);
  repfr_l_id           number(16);
  repfr_l_code_old     varchar2(256);
  repfr_l_code         varchar2(256);
  repfr_i18n_msg       varchar2(256);
  repfr_vis            number(16);
  repfr_mand           number(16);
  repfr_type           number(16);
  repfr_cust_id        number(16);
  repfr_cust_name      varchar2(256);
  repfr_posit_id       number(16);
  repfr_posit_id_old   number(16);

  v_ret                number(16);

begin
  rqd := 'select distinct p.code as USER_CODE,
'||'                p.name as USER_NAME,
'||'                p.surname as USER_SURNAME,
'||'                p.email as USER_EMAIL,
'||'                e.name as ENTITLEMENT_NAME,
'||'                e.description as ENTITLEMENT_DESC,
'||'                case
'||'                  when e.ext_type = 3 then ''Permission''
'||'                  when e.ext_type = 4 then ''External Role''
'||'                  when e.int_type = 2 then ''IT Role''
'||'                  when e.int_type = 3 then ''Business Role''
'||'                end as ENTITLEMENT_TYPE,
'||'                emp.start_date as EMPLOYMENT_START_DATE,
'||'                emp.end_date as EMPLOYMENT_END_DATE,
'||'                a.name as APPLICATION_NAME,
'||'				pwdm.code as ACCOUNT_CODE,
'||'                pt.name as PROFILE_TYPE,
'||'                ou.code as OU_CODE,
'||'                ou.name as OU_NAME,
'||'                ou.description as OU_DESC
'||'  from #pmschema#.person                        p,
'||'       #pmschema#.organizational_unit           ou,
'||'       #pmschema#.employment                    emp
'||'         left join  #pmschema#.employment_pwdmanagement empwd on emp.id = empwd.employment
'||'         left join  #pmschema#.pwdmanagement pwdm on empwd.pwdmanagement = pwdm.id,
'||'       #pmschema#.entitlement_flat_hier         efh,
'||'       #schema_tmp#.tmp_rep_organizational_unit tmp1,
'||'       #schema_tmp#.tmp_rep_application         tmp2,
'||'       #schema_tmp#.tmp_rep_entitlement         tmp3,
'||'       #pmschema#.application                   a
'||'	      left join #pmschema#.target tar on tar.id = a.target,
'||'       #pmschema#.entitlement                   e
'||'       left outer join #pmschema#.profile_type pt on pt.id = e.profile_type and e.int_type = 1
'||' where p.organizational_unit = tmp1.id
'||'   and p.id = emp.person
'||'   and emp.entitlement = efh.parent
'||'   and efh.parent = e.id
'||'   and efh.child_application = a.id
'||'   and efh.child_int_type = 1
'||'   and p.organizational_unit = ou.id
'||'   and ou.id = tmp1.id
'||'   and tmp2.id = a.id
'||'   and tmp3.id = e.id
'||'   and upper(p.name) like upper(''#user_name#'')
'||'   and upper(p.surname) like upper(''#user_surname#'')
'||'   and upper(p.code) like upper(''#user_code#'')
'||'   and upper(e.name) like upper(''#entitlement_name#'')
'||'   and upper(pwdm.code) like upper(''#account_code#'')
'||'   and ou.hierarchy = 1
'||'   and ou.hierarchy = emp.hierarchy
'||'   and pwdm.pwdcfg = tar.pwdcfg
';

  select count(1) into counter from r_query t where lower ( t.name ) = lower ( rq_name ) and t.product = 1;
  if ( counter = 0 ) then
    select max(id) + 1 into rq_id from r_query t;

    insert into r_query ( id, name, description, product )
    values ( rq_id, rq_name, rq_desc, 1 );

    insert into r_query_data ( r_query, query )
    values ( rq_id, rqd );
  else
    select t.id into rq_id from r_query t where lower ( t.name ) = lower ( rq_name ) and t.product = 1;

    update r_query_data set query = rqd where r_query = rq_id;
  end if;

  -- Report FIELD 1
  rqf_name_old    := null;
  rqf_name        := 'ACCOUNT_CODE';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'account.code';
  loc_rename      := true;
  i18n_msg        := 'Account Code';
  repf_pos_id_old := null;
  repf_pos_id     := 4;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );
							  
  -- REPORT FILTERS
  
  repfr_name_old     := null;
  repfr_name         := 'account_code';
  repfr_value        := null;
  repfr_l_code_old   := null;
  repfr_l_code       := 'account.code';
  repfr_i18n_msg     := 'Account Code';
  repfr_vis          := 1;
  repfr_mand         := 0;
  repfr_type         := 0;
  repfr_cust_id      := null;
  repfr_cust_name    := null;
  repfr_posit_id_old := null;
  repfr_posit_id     := null;

  v_ret := inst_rep_add_fil ( rq_id, repfr_name, repfr_value, repfr_l_code_old, repfr_l_code, repfr_i18n_msg, repfr_vis,
                              repfr_mand, repfr_type, repfr_cust_name, repfr_posit_id_old, repfr_posit_id );

end;
/
commit;

