declare
  counter              numeric(16);
  
  -- report
  r_id                 numeric(16);
  r_name               varchar(256) := 'Accounts created in last x days';
  r_desc               varchar(512) := null;
  r_code               varchar(256) := null;
  r_i18n_mess          varchar(256) := null;
  r_dashboard          numeric(1) := 0; -- 0: report, 1: dashboard

  -- localization
  r_loc_id             numeric(16);
  r_loc_code           varchar(256);

  -- query
  rq_id                numeric(16);
  rq_name              varchar(256) := 'Accounts created in last x days';
  rq_desc              varchar(512) := null;
  rqd                  clob;

  rqf_type_def         varchar(256) := 'java.lang.String';
  rqf_width_def        numeric(16) := 300;

  rqf_name_old         varchar(256);
  rqf_name             varchar(256);
  rqf_type             varchar(256);
  rqf_width            numeric(16);
  rqf_ord_by           numeric(1);
  rqf_ord_by_clau      varchar(256);
  loc_code_old         varchar(256);
  loc_code             varchar(256);
  loc_rename           boolean;
  i18n_msg             varchar(256);
  repf_pos_id          numeric(16);
  repf_pos_id_old      numeric(16);

  repfr_id             numeric(16);
  repfr_name_old       varchar(256);
  repfr_name           varchar(256);
  repfr_value          varchar(256);
  repfr_l_id           numeric(16);
  repfr_l_code_old     varchar(256);
  repfr_l_code         varchar(256);
  repfr_i18n_msg       varchar(256);
  repfr_vis            numeric(16);
  repfr_mand           numeric(16);
  repfr_type           numeric(16);
  repfr_cust_id        numeric(16);
  repfr_cust_name      varchar(256);
  repfr_posit_id       numeric(16);
  repfr_posit_id_old   numeric(16);

  v_ret                numeric(16);

begin
  rqd := 'select distinct
'||'  t.name as target_name,
'||'   a.name as application_name,
'||'   pwdm.code as account_code,
'||'   case
'||'     when pwdm.is_default = 0 then ''''
'||'     when pwdm.is_default = 1 then ''Default''
'||' 	end as ACCOUNT_IS_DEFAULT,
'||'   pwdmType.name as ACCOUNT_TYPE,
'||'   case
'||'     when pwdm.name is null then p.name else pwdm.name
'||'   end as user_name,
'||'   case
'||'     when pwdm.surname is null then p.surname else pwdm.surname
'||'   end as user_surname,
'||'   case
'||'     when pwdm.email is null then p.email else pwdm.email
'||'   end as user_email,
'||'   pwdm.creation_date as account_creation_date
'||' from
'||'   #pmschema#.application a,
'||'   #pmschema#.target t,
'||'   #pmschema#.pwdcfg pwdc,
'||'   #pmschema#.pwdmanagement pwdm
'||' 		left outer join #pmschema#.person p on pwdm.person = p.id
'||'		left join #pmschema#.pwdmanagement_type pwdmType
'||'     on pwdm.pwdmanagement_type = pwdmType.id
'||' where
'||'   a.target = t.id
'||'   and t.pwdcfg = pwdc.id
'||'   and pwdc.id = pwdm.pwdcfg
'||'   and a.administrative = 0
'||'   and pwdm.creation_date >=
'||'       to_date(extract(year from sysdate - #day_number#) || ''/'' ||
'||'               extract(month from sysdate - #day_number#) || ''/'' ||
'||'               extract(day from sysdate - #day_number#) || '' 00:00:01'',  ''yyyy/mm/dd hh24:mi:ss'')
';

  select count(1) into counter from r_query t where lower ( t.name ) = lower ( rq_name ) and t.product = 1;
  if ( counter = 0 ) then
    select max(id) + 1 into rq_id from r_query t;

    insert into r_query ( id, name, description, product )
    values ( rq_id, rq_name, rq_desc, 1 );

    insert into r_query_data ( r_query, query )
    values ( rq_id, rqd );
  else
    select t.id into rq_id from r_query t where lower ( t.name ) = lower ( rq_name ) and t.product = 1;

    update r_query_data set query = rqd where r_query = rq_id;
  end if;
							  
  -- Report FIELD 1
  rqf_name_old    := null;
  rqf_name        := 'ACCOUNT_IS_DEFAULT';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'account.is_default';
  loc_rename      := true;
  i18n_msg        := 'Is Default';
  repf_pos_id_old := null;
  repf_pos_id     := 3;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );
							  
   -- Report FIELD 2
  rqf_name_old    := null;
  rqf_name        := 'ACCOUNT_TYPE';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'account.type';
  loc_rename      := true;
  i18n_msg        := 'Account Type';
  repf_pos_id_old := null;
  repf_pos_id     := 4;			

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );  
							  
  -- REPORT FILTERS
  
  repfr_name_old     := null;
  repfr_name         := 'day_number';
  repfr_value        := 7;
  repfr_l_code_old   := null;
  repfr_l_code       := 'day.number';
  repfr_i18n_msg     := '# days from today';
  repfr_vis          := 1;
  repfr_mand         := 1;
  repfr_type         := 3;
  repfr_cust_id      := null;
  repfr_cust_name    := null;
  repfr_posit_id_old := null;
  repfr_posit_id     := null;

  v_ret := inst_rep_add_fil ( rq_id, repfr_name, repfr_value, repfr_l_code_old, repfr_l_code, repfr_i18n_msg, repfr_vis,
                              repfr_mand, repfr_type, repfr_cust_name, repfr_posit_id_old, repfr_posit_id );

end;
/
commit;

