declare
  counter              number(16);

  -- report
  r_id                 number(16);
  r_name               varchar2(256) := 'Fulfillment status for managed Users';
  r_desc               varchar2(512) := 'Fulfillment status for all the Assignments related to Automatic Account Configurations only for matched Accounts to Identities (the scopes are set to view all the managed users and all the Applications)';
  r_code               varchar2(256) := null;
  r_i18n_mess          varchar2(256) := null;
  r_dashboard          number(1) := 0; -- 0: report, 1: dashboard
  
    -- dashboard
  d_id                 number(16);
  d_name               varchar2(256) := 'Fulfillment status for managed Users';
  d_desc               varchar2(512) := 'Available to any user with an Admin Role that is associated to the dashboard. The dashboard shows the fulfillment status for all the assignments that are related to Automatic Account Configurations, only for matched accounts to identities (users). The scopes are set to view all the managed users and all the applications.';
  d_code               varchar2(256) := null;
  d_i18n_mess          varchar2(256) := null;
  d_dashboard          number(1) := 1; -- 0: report, 1: dashboard

  -- localization
  r_loc_id             number(16);
  r_loc_code           varchar2(256);

  -- query
  rq_id                number(16);
  rq_name              varchar2(256) := 'Fulfillment status for managed Users';
  rq_desc              varchar2(512) := 'Fulfillment status for all the Assignments related to Automatic Account Configurations only for matched Accounts to Identities';
  rqd                  clob;

  rqf_type_def         varchar2(256) := 'java.lang.String';
  rqf_width_def        number(16) := 300;

  rqf_name_old         varchar2(256);
  rqf_name             varchar2(256);
  rqf_type             varchar2(256);
  rqf_width            number(16);
  rqf_ord_by           number(1);
  rqf_ord_by_clau      varchar2(256);
  loc_code_old         varchar2(256);
  loc_code             varchar2(256);
  loc_rename           boolean;
  i18n_msg             varchar2(256);
  repf_pos_id          number(16);
  repf_pos_id_old      number(16);

  v_ret                number(16);

begin
  rqd := 'select distinct pp.account_code as ACCOUNT_CODE,
'||'				case
'||'   				  when pwdm.is_default = 0 then ''''
'||'   				  when pwdm.is_default = 1 then ''Default''
'||'				end as ACCOUNT_IS_DEFAULT,
'||'				pwdmType.name as ACCOUNT_TYPE,
'||'                p.name as USER_NAME,
'||'                p.surname as USER_SURNAME,
'||'                p.code as USER_CODE,
'||'                p.email as USER_EMAIL,
'||'                p.dn as USER_DN,
'||'                p.cod_fisc as USER_SSN,
'||'                ou.name as GROUP_NAME,
'||'                ou.code as GROUP_CODE,
'||'                ou.description as GROUP_DESC,
'||'                pp.target as TARGET,
'||'                pp.permission_code as EXTERNAL_REF,
'||'                pp.permission_type as PERMISSION_TYPE,
'||'                e.name as ENTITLEMENT_NAME,
'||'                e.code as ENTITLEMENT_CODE,
'||'                e.description as ENTITLEMENT_DESC,
'||'                a.name as APPLICATION_NAME,
'||'                case
'||'                  when pp.status = 0 then
'||'                   ''Pending''
'||'                  when pp.status = 1 then
'||'                   ''Assignment - Pending Fulfillment''
'||'                  when pp.status = 2 then
'||'                   ''Assignment - Aligned''
'||'                  when pp.status = 3 then
'||'                   ''Assignment - Failed Fulfillment''
'||'                  when pp.status = 4 then
'||'                   ''Assignment - Target Originated''
'||'                  when pp.status = 11 then
'||'                   ''Removal - Pending Fulfillment''
'||'                  when pp.status = 12 then
'||'                   ''Removal - Aligned''
'||'                  when pp.status = 13 then
'||'                   ''Removal - Failed Fulfillment''
'||'                  when pp.status = 14 then
'||'                   ''Removal - Target Originated''
'||'                  else
'||'                   ''Unknown''
'||'                end as STATUS,
'||'                pp.verify_date as VERIFY_DATE
'||'  from #pmschema#.person_profile pp
'||'  left join #pmschema#.entitlement e
'||'    on pp.profile = e.id
'||'  left join #pmschema#.application a
'||'    on e.application = a.id,
'||'       #pmschema#.person p,
'||'       #pmschema#.organizational_unit ou,
'||'       #pmschema#.Target t,
'||'       #pmschema#.Pwdcfg pc,
'||'	   #pmschema#.Pwdmanagement pwdm 
'||'  left join #pmschema#.pwdmanagement_type pwdmType
'||'    on pwdm.pwdmanagement_type = pwdmType.id,
'||'       #schema_tmp#.tmp_rep_application tmpa,
'||'       #schema_tmp#.tmp_rep_organizational_unit tmpou
'||' where pp.person = p.id
'||'   and p.organizational_unit = ou.id
'||'   and pp.target = t.value
'||'   and t.pwdcfg = pc.id
'||'   and pwdm.pwdcfg = pc.id
'||'   and pwdm.code = pp.account_code
'||'   and pwdm.person = p.id
'||'   and pc.sync = 2
'||'   and a.id = tmpa.id
'||'   and ou.id = tmpou.id
'||'   and pp.status = #fulfillment_status#
';

  select count(1) into counter from r_query t where lower ( t.name ) = lower ( rq_name ) and t.product = 1;
  if ( counter = 0 ) then
    select max(id) + 1 into rq_id from r_query t;

    insert into r_query ( id, name, description, product )
    values ( rq_id, rq_name, rq_desc, 1 );

    insert into r_query_data ( r_query, query )
    values ( rq_id, rqd );
  else
    select t.id into rq_id from r_query t where lower ( t.name ) = lower ( rq_name ) and t.product = 1;

    update r_query_data set query = rqd where r_query = rq_id;

  end if;
							  
  -- Report FIELD 1
  rqf_name_old    := null;
  rqf_name        := 'ACCOUNT_IS_DEFAULT';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'account.is_default';
  loc_rename      := true;
  i18n_msg        := 'Is Default';
  repf_pos_id_old := null;
  repf_pos_id     := 1;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );
							  
   -- Report FIELD 2
  rqf_name_old    := null;
  rqf_name        := 'ACCOUNT_TYPE';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'account.type';
  loc_rename      := true;
  i18n_msg        := 'Account Type';
  repf_pos_id_old := null;
  repf_pos_id     := 2;	

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );  

end;
/
commit;

