declare
  stat        varchar(2048);
  exception1  EXCEPTION;
  PRAGMA DB2_EXCEPTION_INIT(exception1,'42710'); -- The name of the object to be created is identical to the existing name

begin
  stat := '
  CREATE TABLE SURVEY_CONFIG
  (
    ID                             NUMERIC(16)          NOT NULL,
    ICN                            VARCHAR(32)          NOT NULL,
    OFFERING_ID                    VARCHAR(16)          NOT NULL,
    PRODUCT_TYPE                   CHAR(2)              NOT NULL,
    FIRST_SURVEY_INTERVAL          NUMERIC(8)           DEFAULT 30 NOT NULL,
    CUSTOMER_SIZE                  VARCHAR(6),
    NEXT_SURVEY_INTERVAL           NUMERIC(8)           DEFAULT 90 NOT NULL,
    CUSTOMER_NAME                  VARCHAR(256),
    COUNTRY                        CHAR(2),
    GBGNAME                        VARCHAR(64),
    TEST_FLAG                      NUMERIC(1)           NOT NULL,
    GBGID                          VARCHAR(32),
    BASE_URL                       VARCHAR(512)         DEFAULT ''https://survey.medallia.eu/?ibm-onprem-offering'' NOT NULL
  )
  IN &DATA_TABLESPACE
  INDEX IN &INDEX_TABLESPACE
  LONG IN &LOB_TABLESPACE
  ';

  execute immediate (stat);

exception
  when exception1 then null;

end;
/

COMMENT ON COLUMN SURVEY_CONFIG.PRODUCT_TYPE IS
'Type of Offering (whether SaaS, On Premises Software, On Premises Hardware, or Services).';

COMMENT ON COLUMN SURVEY_CONFIG.TEST_FLAG IS
'This is a flag to let the system know if this is test data and thus should not be included in reporting of NPS scores.Should be set to "1" (Yes) for test data in live production environments. Should be set to "2" (No) or null/blank everywhere else.';

declare
  stat        varchar(256);
  exception1  EXCEPTION;
  PRAGMA DB2_EXCEPTION_INIT(exception1,'42889'); -- PK already defined

begin
  stat := '
  ALTER TABLE SURVEY_CONFIG
    ADD CONSTRAINT SURVEY_CONFIG_PK
    PRIMARY KEY (ID)
  ';

  execute immediate (stat);

exception
  when exception1 then null;

end;
/

CALL SYSPROC.ADMIN_CMD ( 'REORG TABLE SURVEY_CONFIG' );

GRANT ALL ON SURVEY_CONFIG TO IGA;
GRANT ALL ON SURVEY_CONFIG TO IGACONN;
GRANT ALL ON SURVEY_CONFIG TO REP;
GRANT ALL ON SURVEY_CONFIG TO AA;

declare
  stat        varchar(256);
  exception1  EXCEPTION;
  PRAGMA DB2_EXCEPTION_INIT(exception1,'42710'); -- The name of the object to be created is identical to the existing name

begin
  stat := '
  CREATE SEQUENCE SURVEY_CONFIG_SEQ
    AS NUMERIC(18)
    START WITH 100
    INCREMENT BY 1
    MINVALUE 100
    MAXVALUE 999999999999999999
    NO CACHE
    NO CYCLE
    NO ORDER
  ';

  execute immediate (stat);

exception
  when exception1 then null;

end;
/

GRANT USAGE ON SEQUENCE SURVEY_CONFIG_SEQ TO IGA;
GRANT USAGE ON SEQUENCE SURVEY_CONFIG_SEQ TO IGACONN;
GRANT USAGE ON SEQUENCE SURVEY_CONFIG_SEQ TO REP;
GRANT USAGE ON SEQUENCE SURVEY_CONFIG_SEQ TO AA;

declare
  counter  numeric(16);
begin
  select count(1) into counter from survey_config where id = 1;
  if ( counter = 0 ) then
    insert into survey_config (ID, ICN, OFFERING_ID, PRODUCT_TYPE, FIRST_SURVEY_INTERVAL, NEXT_SURVEY_INTERVAL, TEST_FLAG, BASE_URL, CUSTOMER_NAME, CUSTOMER_SIZE, COUNTRY)
    values (1, 'XXX', '5725T18', '2', 30, 90, 0, 'https://survey.medallia.eu?ibm-onprem-offering', 'IBM', 'Large', 'US');
  end if;
  commit;
end;
/