declare
  stat        varchar2(2048);
  exception1  EXCEPTION;
  PRAGMA EXCEPTION_INIT(exception1,-00955); -- name is already used by an existing object

begin
  stat := '
  CREATE TABLE SURVEY_CONFIG
  (
    ID                             NUMBER(16)           NOT NULL,
    ICN                            VARCHAR2(32)         NOT NULL,
    OFFERING_ID                    VARCHAR2(16)         NOT NULL,
    PRODUCT_TYPE                   CHAR(2)              NOT NULL,
    FIRST_SURVEY_INTERVAL          NUMBER(8)            DEFAULT 30 NOT NULL,
    CUSTOMER_SIZE                  VARCHAR(6),
    NEXT_SURVEY_INTERVAL           NUMBER(8)            DEFAULT 90 NOT NULL,
    CUSTOMER_NAME                  VARCHAR2(256),
    COUNTRY                        CHAR(2),
    GBGNAME                        VARCHAR2(64),
    TEST_FLAG                      NUMBER(1)            NOT NULL,
    GBGID                          VARCHAR2(32),
    BASE_URL                       VARCHAR2(512)        DEFAULT ''https://survey.medallia.eu/?ibm-onprem-offering'' NOT NULL
  )
  TABLESPACE &DATA_TABLESPACE
  ';

  execute immediate (stat);

exception
  when exception1 then null;

end;
/

COMMENT ON COLUMN SURVEY_CONFIG.PRODUCT_TYPE IS
'Type of Offering (whether SaaS, On Premises Software, On Premises Hardware, or Services).';

COMMENT ON COLUMN SURVEY_CONFIG.TEST_FLAG IS
'This is a flag to let the system know if this is test data and therefore should not be included in reporting of NPS scores, etc. Should be set statically to "1" (for Yes) for all testing environments, as well as for test (non-live customer) data in live production environments. Should be set to "2" (for No) or null/blank everywhere else.';

declare
  stat        varchar2(256);
  exception1  EXCEPTION;
  PRAGMA EXCEPTION_INIT(exception1,-02260); -- PK already defined

begin
  stat := '
  ALTER TABLE SURVEY_CONFIG
    ADD CONSTRAINT SURVEY_CONFIG_PK PRIMARY KEY (ID)
    USING INDEX TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ';

  execute immediate (stat);

exception
  when exception1 then null;

end;
/

GRANT ALL ON SURVEY_CONFIG TO IDEAS;
GRANT ALL ON SURVEY_CONFIG TO IDEAS_CONNECTOR;
GRANT ALL ON SURVEY_CONFIG TO IDEAS_REPORT;
GRANT ALL ON SURVEY_CONFIG TO AA;

declare
  stat        varchar2(256);
  exception1  EXCEPTION;
  PRAGMA EXCEPTION_INIT(exception1,-00955); -- name is already used by an existing object

begin
  stat := '
  CREATE SEQUENCE SURVEY_CONFIG_SEQ
    START WITH 100
    INCREMENT BY 1
    MINVALUE 100
    MAXVALUE 999999999999999999999999999
    NOCACHE
    NOCYCLE
    NOORDER
  ';

  execute immediate (stat);

exception
  when exception1 then null;

end;
/

GRANT ALL ON SURVEY_CONFIG_SEQ TO IDEAS;
GRANT ALL ON SURVEY_CONFIG_SEQ TO IDEAS_CONNECTOR;
GRANT ALL ON SURVEY_CONFIG_SEQ TO IDEAS_REPORT;
GRANT ALL ON SURVEY_CONFIG_SEQ TO AA;

declare
  counter  number(16);
begin
  select count(1) into counter from survey_config where id = 1;
  if ( counter = 0 ) then
    insert into survey_config (ID, ICN, OFFERING_ID, PRODUCT_TYPE, FIRST_SURVEY_INTERVAL, NEXT_SURVEY_INTERVAL, TEST_FLAG, BASE_URL, CUSTOMER_NAME, CUSTOMER_SIZE, COUNTRY)
    values (1, 'XXX', '5725T18', '2', 30, 90, 0, 'https://survey.medallia.eu?ibm-onprem-offering', 'IBM', 'Large', 'US');
  end if;
  commit;
end;
/
