--CREATE A TABLE AND ITS CONSTRAINTS
set verify off
set serveroutput on
declare
  curr_user         varchar(30);
  
  tab_name          varchar(30) := 'EMPLOYMENT_REVIEW_RIGHT';
  dml_def           varchar(4000);
  
  counter           numeric(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from sysibm.tables t where ( t.table_type = 'BASE TABLE' or t.table_type is null ) and lower ( t.table_schema ) = lower ( curr_user ) and t.table_name = tab_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'CREATE TABLE EMPLOYMENT_REVIEW_RIGHT
(
  ID                             NUMERIC(16)         NOT NULL,
  EMPLOYMENT_REVIEW              NUMERIC(16)         NOT NULL,
  PERMISSION                     NUMERIC(16)         NOT NULL,
  RIGHT_NAME                     VARCHAR(256)        NOT NULL,
  RIGHT_VALUE                    VARCHAR(256),
  STATE                          NUMERIC(16)         DEFAULT 0,
  ATTR1                          VARCHAR(256),
  ATTR2                          VARCHAR(256),
  ATTR3                          VARCHAR(256),
  ATTR4                          VARCHAR(256),
  ATTR5                          VARCHAR(256),
  LAST_MOD_USER                  VARCHAR(128),
  LAST_MOD_TIME                  DATE                DEFAULT CURRENT_DATE,
  REVIEW_STATE                   NUMERIC(1)          DEFAULT 0,
  REVIEW_DATE                    DATE,
  REVIEWED_BY_INFO               VARCHAR(256),
  REVIEWED_BY                    NUMERIC(16),
  NOTE                           VARCHAR(2048),
  SIGNED_OFF                     NUMERIC(1)          DEFAULT 0,
  CREATION_DATE                  DATE,
  RIGHT_ISREQUIRED               NUMERIC(1),
  PERSON_SERVICE                 NUMERIC(16)
)
IN &DATA_TABLESPACE
INDEX IN &INDEX_TABLESPACE
LONG IN &LOB_TABLESPACE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE EMPLOYMENT_REVIEW_RIGHT ADD
  CONSTRAINT EMPLOYMENT_REVIEW_R_PK
 PRIMARY KEY (ID)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE EMPLOYMENT_REVIEW_RIGHT ADD
  CONSTRAINT EMPREVR_EMPREV_FK
 FOREIGN KEY (EMPLOYMENT_REVIEW)
 REFERENCES EMPLOYMENT_REVIEW (ID)
    ON DELETE CASCADE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE EMPLOYMENT_REVIEW_RIGHT ADD
  CONSTRAINT EMPREVR_PERMISSION_FK
 FOREIGN KEY (PERMISSION)
 REFERENCES ENTITLEMENT (ID)
    ON DELETE CASCADE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE EMPLOYMENT_REVIEW_RIGHT ADD
  CONSTRAINT EMPREVR_PERSON_SERVICE_FK
 FOREIGN KEY (PERSON_SERVICE)
 REFERENCES PERSON_SERVICE (ID)
    ON DELETE SET NULL
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE EMPLOYMENT_REVIEW_RIGHT ADD
  CONSTRAINT EMPREVR_REVIEWED_BY_FK
 FOREIGN KEY (REVIEWED_BY)
 REFERENCES PERSON (ID)
    ON DELETE SET NULL
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
commit;
set serveroutput off
set verify on


--REORGANIZE A TABLE
set verify off
set serveroutput on
declare
  curr_user         varchar(30);
  
  tab_name          varchar(30) := 'EMPLOYMENT_REVIEW_RIGHT';
  dml_def           varchar(4000);
  
  counter           numeric(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from sysibm.tables t where ( t.table_type = 'BASE TABLE' or t.table_type is null ) and lower ( t.table_schema ) = lower ( curr_user ) and t.table_name = tab_name;
  if ( counter = 0 ) then
    return;
  end if;

  dml_def :=
'CALL SYSPROC.ADMIN_CMD( ''REORG TABLE EMPLOYMENT_REVIEW_RIGHT'' )
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
commit;
set serveroutput off
set verify on

grant select on EMPLOYMENT_REVIEW_RIGHT to &AA_SUPER_ADMIN_USER;
grant select, insert, update, delete, references on EMPLOYMENT_REVIEW_RIGHT to &IDEAS_SUPER_ADMIN_USER;
grant select, insert, update, delete, references on EMPLOYMENT_REVIEW_RIGHT to &IDEAS_CONN_SUPER_ADMIN_USER;
grant select on EMPLOYMENT_REVIEW_RIGHT to &IDEAS_REPORT_SUPER_ADMIN_USER;


--CREATE A SEQUENCE
set verify off
set serveroutput on
declare
  curr_user         varchar(30);
  
  seq_name          varchar(30) := 'EMPLOYMENT_REVIEW_RIGHT_SEQ';
  dml_def           varchar(4000);
  
  counter           numeric(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from syscat.sequences t where lower ( t.seqschema ) = lower ( curr_user ) and t.seqtype <> 'I' and lower ( t.seqname ) = lower ( seq_name );
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'CREATE SEQUENCE EMPLOYMENT_REVIEW_RIGHT_SEQ
  AS NUMERIC(18)
  START WITH 100
  INCREMENT BY 1
  MINVALUE 100
  MAXVALUE 999999999999999999
  NO CACHE
  NO CYCLE
  NO ORDER
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
commit;
set serveroutput off
set verify on

grant usage on sequence EMPLOYMENT_REVIEW_RIGHT_SEQ to &AA_SUPER_ADMIN_USER;
grant usage, alter on sequence EMPLOYMENT_REVIEW_RIGHT_SEQ to &IDEAS_SUPER_ADMIN_USER;
grant usage, alter on sequence EMPLOYMENT_REVIEW_RIGHT_SEQ to &IDEAS_CONN_SUPER_ADMIN_USER;
grant usage on sequence EMPLOYMENT_REVIEW_RIGHT_SEQ to &IDEAS_REPORT_SUPER_ADMIN_USER;
