--CREATE A TABLE AND ITS CONSTRAINTS
set verify off
set serveroutput on
declare
  curr_user         varchar2(30);
  
  tab_name          varchar2(30) := 'EMPLOYMENT_REVIEW_RIGHT';
  dml_def           varchar2(4000);
  
  counter           number(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from all_tables t where t.owner = curr_user and t.table_name = tab_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'CREATE TABLE EMPLOYMENT_REVIEW_RIGHT
(
  ID                             NUMBER(16)          NOT NULL,
  EMPLOYMENT_REVIEW              NUMBER(16)          NOT NULL,
  PERMISSION                     NUMBER(16)          NOT NULL,
  RIGHT_NAME                     VARCHAR2(256 BYTE)  NOT NULL,
  RIGHT_VALUE                    VARCHAR2(256 BYTE),
  STATE                          NUMBER(16)          DEFAULT 0,
  ATTR1                          VARCHAR2(256 CHAR),
  ATTR2                          VARCHAR2(256 CHAR),
  ATTR3                          VARCHAR2(256 CHAR),
  ATTR4                          VARCHAR2(256 CHAR),
  ATTR5                          VARCHAR2(256 CHAR),
  LAST_MOD_USER                  VARCHAR2(128 CHAR),
  LAST_MOD_TIME                  DATE                DEFAULT SYSDATE,
  REVIEW_STATE                   NUMBER(1)           DEFAULT 0,
  REVIEW_DATE                    DATE,
  REVIEWED_BY_INFO               VARCHAR2(256 CHAR),
  REVIEWED_BY                    NUMBER(16),
  NOTE                           VARCHAR2(2048 CHAR),
  SIGNED_OFF                     NUMBER(1)           DEFAULT 0,
  CREATION_DATE                  DATE,
  RIGHT_ISREQUIRED               NUMBER(1),
  PERSON_SERVICE                 NUMBER(16)
)
TABLESPACE &DATA_TABLESPACE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE EMPLOYMENT_REVIEW_RIGHT ADD (
  CONSTRAINT EMPLOYMENT_REVIEW_R_PK
 PRIMARY KEY
 (ID)
  USING INDEX TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE EMPLOYMENT_REVIEW_RIGHT ADD (
  CONSTRAINT EMPREVR_EMPREV_FK
 FOREIGN KEY (EMPLOYMENT_REVIEW)
 REFERENCES EMPLOYMENT_REVIEW (ID)
    ON DELETE CASCADE)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE EMPLOYMENT_REVIEW_RIGHT ADD (
  CONSTRAINT EMPREVR_PERMISSION_FK
 FOREIGN KEY (PERMISSION)
 REFERENCES ENTITLEMENT (ID)
    ON DELETE CASCADE)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE EMPLOYMENT_REVIEW_RIGHT ADD (
  CONSTRAINT EMPREVR_PERSON_SERVICE_FK
 FOREIGN KEY (PERSON_SERVICE)
 REFERENCES PERSON_SERVICE (ID)
    ON DELETE SET NULL)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE EMPLOYMENT_REVIEW_RIGHT ADD (
  CONSTRAINT EMPREVR_REVIEWED_BY_FK
 FOREIGN KEY (REVIEWED_BY)
 REFERENCES PERSON (ID)
    ON DELETE SET NULL)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
set serveroutput off
set verify on

grant select, insert, update, delete, references on EMPLOYMENT_REVIEW_RIGHT to IDEAS;
grant select, insert, update, delete, references on EMPLOYMENT_REVIEW_RIGHT to IDEAS_CONNECTOR;
grant select on EMPLOYMENT_REVIEW_RIGHT to IDEAS_REPORT;


--CREATE A SEQUENCE
set verify off
set serveroutput on
declare
  curr_user         varchar2(30);
  
  seq_name          varchar2(30) := 'EMPLOYMENT_REVIEW_RIGHT_SEQ';
  dml_def           varchar2(4000);
  
  counter           number(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from all_sequences t where t.sequence_owner = curr_user and t.sequence_name = seq_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'CREATE SEQUENCE EMPLOYMENT_REVIEW_RIGHT_SEQ
  START WITH 100
  INCREMENT BY 1
  MINVALUE 100
  MAXVALUE 999999999999999999999999999
  NOCACHE
  NOCYCLE
  NOORDER
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
set serveroutput off
set verify on

grant select on EMPLOYMENT_REVIEW_RIGHT_SEQ to AA;
grant select, alter on EMPLOYMENT_REVIEW_RIGHT_SEQ to IDEAS;
grant select on EMPLOYMENT_REVIEW_RIGHT_SEQ to IDEAS_CONNECTOR;
grant select on EMPLOYMENT_REVIEW_RIGHT_SEQ to IDEAS_REPORT;
