CREATE TABLE EMPLOYMENT_REVIEW_RIGHT_H
(
  ID                             NUMERIC(16)         NOT NULL,
  ATTESTATION_NAME               VARCHAR(256),
  PERSON                         NUMERIC(16),
  ENTITLEMENT                    NUMERIC(16),
  ENTITLEMENT_TYPE               NUMERIC(1),
  ENTITLEMENT_NAME               VARCHAR(256),
  ENTITLEMENT_CODE               VARCHAR(256),
  ENTITLEMENT_DESCRIPTION        VARCHAR(512),
  PROFILE_TYPE_NAME              VARCHAR(256),
  APPLICATION_NAME               VARCHAR(256),
  PERSON_SERVICE                 NUMERIC(16),
  RIGHT_NAME                     VARCHAR(256)        NOT NULL,
  RIGHT_VALUE_OLD                VARCHAR(256),
  RIGHT_VALUE_NEW                VARCHAR(256),
  CERT_FIRST_OWNER               NUMERIC(16),
  CERT_FIRST_OWNER_CODE          VARCHAR(256),
  CERT_FIRST_OWNER_NAME          VARCHAR(256),
  CERT_FIRST_OWNER_SURNAME       VARCHAR(256),
  REVIEW_STATE                   NUMERIC(1)          DEFAULT 0,
  REVIEW_DATE                    DATE,
  NOTE                           VARCHAR(2048),
  STATE                          NUMERIC(1)          DEFAULT 0,
  ATTR1                          VARCHAR(256),
  ATTR2                          VARCHAR(256),
  ATTR3                          VARCHAR(256),
  ATTR4                          VARCHAR(256),
  ATTR5                          VARCHAR(256),
  LAST_MOD_USER                  VARCHAR(128),
  LAST_MOD_TIME                  DATE                DEFAULT CURRENT_DATE
)
IN &DATA_TABLESPACE
INDEX IN &INDEX_TABLESPACE
LONG IN &LOB_TABLESPACE
;

ALTER TABLE EMPLOYMENT_REVIEW_RIGHT_H ADD
  CONSTRAINT EMPLOYMENT_REVIEW_RIGHT_H_PK
 PRIMARY KEY (ID);

ALTER TABLE EMPLOYMENT_REVIEW_RIGHT_H ADD
  CONSTRAINT EMP_REV_R_H_ENTITLEMENT_FK
 FOREIGN KEY (ENTITLEMENT)
 REFERENCES ENTITLEMENT (ID)
    ON DELETE SET NULL;
ALTER TABLE EMPLOYMENT_REVIEW_RIGHT_H ADD
  CONSTRAINT EMP_REV_R_H_PER_SERV_FK
 FOREIGN KEY (PERSON_SERVICE)
 REFERENCES PERSON (ID)
    ON DELETE SET NULL;
ALTER TABLE EMPLOYMENT_REVIEW_RIGHT_H ADD
  CONSTRAINT EMP_REV_R_H_PERSON_FK
 FOREIGN KEY (PERSON)
 REFERENCES PERSON (ID)
    ON DELETE CASCADE;
ALTER TABLE EMPLOYMENT_REVIEW_RIGHT_H ADD
  CONSTRAINT EMP_REV_R_H_REVIEWED_BY_FK
 FOREIGN KEY (CERT_FIRST_OWNER)
 REFERENCES PERSON (ID)
    ON DELETE SET NULL;
CALL SYSPROC.ADMIN_CMD ( 'REORG TABLE EMPLOYMENT_REVIEW_RIGHT_H' );


grant select on EMPLOYMENT_REVIEW_RIGHT_H to &AA_SUPER_ADMIN_USER;
grant select, insert, update, delete, references on EMPLOYMENT_REVIEW_RIGHT_H to &IDEAS_SUPER_ADMIN_USER;
grant select, insert, update, delete, references on EMPLOYMENT_REVIEW_RIGHT_H to &IDEAS_CONN_SUPER_ADMIN_USER;
grant select on EMPLOYMENT_REVIEW_RIGHT_H to &IDEAS_REPORT_SUPER_ADMIN_USER;

CREATE SEQUENCE EMPLOYMENT_REVIEW_RIGHT_H_SEQ
  AS NUMERIC(18)
  START WITH 100
  INCREMENT BY 1
  MINVALUE 100
  MAXVALUE 999999999999999999
  NO CACHE
  NO CYCLE
  NO ORDER;

grant usage on sequence EMPLOYMENT_REVIEW_RIGHT_H_SEQ to &AA_SUPER_ADMIN_USER;
grant usage, alter on sequence EMPLOYMENT_REVIEW_RIGHT_H_SEQ to &IDEAS_SUPER_ADMIN_USER;
grant usage, alter on sequence EMPLOYMENT_REVIEW_RIGHT_H_SEQ to &IDEAS_CONN_SUPER_ADMIN_USER;
grant usage on sequence EMPLOYMENT_REVIEW_RIGHT_H_SEQ to &IDEAS_REPORT_SUPER_ADMIN_USER;
