--CREATE A TABLE AND ITS CONSTRAINTS
set verify off
set serveroutput on
declare
  curr_user         varchar2(30);
  
  tab_name          varchar2(30) := 'EMPLOYMENT_REVIEW_RIGHT_H';
  dml_def           varchar2(4000);
  
  counter           number(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from all_tables t where t.owner = curr_user and t.table_name = tab_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'CREATE TABLE EMPLOYMENT_REVIEW_RIGHT_H
(
  ID                             NUMBER(16)          NOT NULL,
  ATTESTATION_NAME               VARCHAR2(256 CHAR),
  PERSON                         NUMBER(16),
  ENTITLEMENT                    NUMBER(16),
  ENTITLEMENT_TYPE               NUMBER(1),
  ENTITLEMENT_NAME               VARCHAR2(256 CHAR),
  ENTITLEMENT_CODE               VARCHAR2(256 CHAR),
  ENTITLEMENT_DESCRIPTION        VARCHAR2(512 CHAR),
  PROFILE_TYPE_NAME              VARCHAR2(256 CHAR),
  APPLICATION_NAME               VARCHAR2(256 CHAR),
  PERSON_SERVICE                 NUMBER(16),
  RIGHT_NAME                     VARCHAR2(256 BYTE)  NOT NULL,
  RIGHT_VALUE_OLD                VARCHAR2(256 BYTE),
  RIGHT_VALUE_NEW                VARCHAR2(256 BYTE),
  CERT_FIRST_OWNER               NUMBER(16),
  CERT_FIRST_OWNER_CODE          VARCHAR2(256 CHAR),
  CERT_FIRST_OWNER_NAME          VARCHAR2(256 CHAR),
  CERT_FIRST_OWNER_SURNAME       VARCHAR2(256 CHAR),
  REVIEW_STATE                   NUMBER(1)           DEFAULT 0,
  REVIEW_DATE                    DATE,
  NOTE                           VARCHAR2(2048 CHAR),
  STATE                          NUMBER(1)           DEFAULT 0,
  ATTR1                          VARCHAR2(256 CHAR),
  ATTR2                          VARCHAR2(256 CHAR),
  ATTR3                          VARCHAR2(256 CHAR),
  ATTR4                          VARCHAR2(256 CHAR),
  ATTR5                          VARCHAR2(256 CHAR),
  LAST_MOD_USER                  VARCHAR2(128 CHAR),
  LAST_MOD_TIME                  DATE                DEFAULT SYSDATE
)
TABLESPACE &DATA_TABLESPACE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE EMPLOYMENT_REVIEW_RIGHT_H ADD (
  CONSTRAINT EMPLOYMENT_REVIEW_RIGHT_H_PK
 PRIMARY KEY
 (ID)
  USING INDEX TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE EMPLOYMENT_REVIEW_RIGHT_H ADD (
  CONSTRAINT EMP_REV_R_H_ENTITLEMENT_FK
 FOREIGN KEY (ENTITLEMENT)
 REFERENCES ENTITLEMENT (ID)
    ON DELETE SET NULL)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE EMPLOYMENT_REVIEW_RIGHT_H ADD (
  CONSTRAINT EMP_REV_R_H_PER_SERV_FK
 FOREIGN KEY (PERSON_SERVICE)
 REFERENCES PERSON (ID)
    ON DELETE SET NULL)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE EMPLOYMENT_REVIEW_RIGHT_H ADD (
  CONSTRAINT EMP_REV_R_H_PERSON_FK
 FOREIGN KEY (PERSON)
 REFERENCES PERSON (ID)
    ON DELETE CASCADE)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE EMPLOYMENT_REVIEW_RIGHT_H ADD (
  CONSTRAINT EMP_REV_R_H_REVIEWED_BY_FK
 FOREIGN KEY (CERT_FIRST_OWNER)
 REFERENCES PERSON (ID)
    ON DELETE SET NULL)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
set serveroutput off
set verify on

grant select, insert, update, delete, references on EMPLOYMENT_REVIEW_RIGHT_H to IDEAS;
grant select, insert, update, delete, references on EMPLOYMENT_REVIEW_RIGHT_H to IDEAS_CONNECTOR;
grant select on EMPLOYMENT_REVIEW_RIGHT_H to IDEAS_REPORT;


--CREATE A SEQUENCE
set verify off
set serveroutput on
declare
  curr_user         varchar2(30);
  
  seq_name          varchar2(30) := 'EMPLOYMENT_REVIEW_RIGHT_H_SEQ';
  dml_def           varchar2(4000);
  
  counter           number(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from all_sequences t where t.sequence_owner = curr_user and t.sequence_name = seq_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'CREATE SEQUENCE EMPLOYMENT_REVIEW_RIGHT_H_SEQ
  START WITH 100
  INCREMENT BY 1
  MINVALUE 100
  MAXVALUE 999999999999999999999999999
  NOCACHE
  NOCYCLE
  NOORDER
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
set serveroutput off
set verify on

grant select on EMPLOYMENT_REVIEW_RIGHT_H_SEQ to AA;
grant select, alter on EMPLOYMENT_REVIEW_RIGHT_H_SEQ to IDEAS;
grant select on EMPLOYMENT_REVIEW_RIGHT_H_SEQ to IDEAS_CONNECTOR;
grant select on EMPLOYMENT_REVIEW_RIGHT_H_SEQ to IDEAS_REPORT;
