CREATE OR REPLACE TRIGGER TRG_ENTITLEMENT_HISTORY
  AFTER INSERT OR UPDATE OR DELETE ON ENTITLEMENT
  FOR EACH ROW
declare
  counter               number(16);
  code_oper             varchar2(256);
  var_revision          number(16);
begin
  --HISTORY WITH MULTI LANGUAGE NOT SUPPORTED
  select count(1) into counter from agc_language t where t.status > 0;

  if ( counter > 0 ) then
    return;
  end if;

  select count(1) into counter from tmp_codoperation;

  if ( counter = 0 ) then
    RAISE_APPLICATION_ERROR ( -20200, 'NO OPERATION CODE FOUND IN TMP_CODOPERATION TABLE');
  elsif ( counter = 1 ) then
    select code into code_oper from tmp_codoperation;
  elsif  ( counter > 1 ) then
    RAISE_APPLICATION_ERROR ( -20201, 'TOO MANY OPERATION CODE FOUND IN TMP_CODOPERATION TABLE');
  end if;

  if ( upper ( code_oper ) = 'REVERTING'  ) then
    return;
  elsif ( inserting or updating ) then
    if ( :new.int_type = 0 ) then
      return;
    end if;
  elsif ( deleting ) then
    if ( :old.int_type = 0 ) then
      return;
    end if;
  end if;

  if ( inserting or updating ) then
    var_revision := :new.revision;
  elsif ( deleting ) then
    var_revision := :old.revision;
  end if;

  if ( inserting ) then
    insert into history
     ( id, operation, ent_type, ent_id, ent_name, ent_desc,
       old_val, new_val, field, revision, note )
    values
     ( history_seq.nextval, 2, 1, :new.id, :new.name, :new.description,
       null, null, null, var_revision, code_oper );
  end if;

  if ( updating ) then
    if ( ( :old.revision is null and :new.revision is not null ) or ( :old.revision is not null and :new.revision is null ) or ( :old.revision <> :new.revision ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 10, 1, :new.id, :new.name, :new.description,
           :old.revision, :new.revision, 'REVISION', var_revision, code_oper );
    end if;
    if ( ( :old.id is null and :new.id is not null ) or ( :old.id is not null and :new.id is null ) or ( :old.id <> :new.id ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.id, :new.id, 'ID', var_revision, code_oper );
    end if;
    if ( ( :old.name is null and :new.name is not null ) or ( :old.name is not null and :new.name is null ) or ( :old.name <> :new.name ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.name, :new.name, 'NAME', var_revision, code_oper );
    end if;
    if ( ( :old.description is null and :new.description is not null ) or ( :old.description is not null and :new.description is null ) or ( :old.description <> :new.description ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.description, :new.description, 'DESCRIPTION', var_revision, code_oper );
    end if;
    if ( ( :old.int_type is null and :new.int_type is not null ) or ( :old.int_type is not null and :new.int_type is null ) or ( :old.int_type <> :new.int_type ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.int_type, :new.int_type, 'INT_TYPE', var_revision, code_oper );
    end if;
    if ( ( :old.family is null and :new.family is not null ) or ( :old.family is not null and :new.family is null ) or ( :old.family <> :new.family ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.family, :new.family, 'FAMILY', var_revision, code_oper );
    end if;
    if ( ( :old.state is null and :new.state is not null ) or ( :old.state is not null and :new.state is null ) or ( :old.state <> :new.state ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.state, :new.state, 'STATE', var_revision, code_oper );
    end if;
    if ( ( :old.attr1 is null and :new.attr1 is not null ) or ( :old.attr1 is not null and :new.attr1 is null ) or ( :old.attr1 <> :new.attr1 ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.attr1, :new.attr1, 'ATTR1', var_revision, code_oper );
    end if;
    if ( ( :old.attr2 is null and :new.attr2 is not null ) or ( :old.attr2 is not null and :new.attr2 is null ) or ( :old.attr2 <> :new.attr2 ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.attr2, :new.attr2, 'ATTR2', var_revision, code_oper );
    end if;
    if ( ( :old.attr3 is null and :new.attr3 is not null ) or ( :old.attr3 is not null and :new.attr3 is null ) or ( :old.attr3 <> :new.attr3 ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.attr3, :new.attr3, 'ATTR3', var_revision, code_oper );
    end if;
    if ( ( :old.attr4 is null and :new.attr4 is not null ) or ( :old.attr4 is not null and :new.attr4 is null ) or ( :old.attr4 <> :new.attr4 ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.attr4, :new.attr4, 'ATTR4', var_revision, code_oper );
    end if;
    if ( ( :old.attr5 is null and :new.attr5 is not null ) or ( :old.attr5 is not null and :new.attr5 is null ) or ( :old.attr5 <> :new.attr5 ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.attr5, :new.attr5, 'ATTR5', var_revision, code_oper );
    end if;
    if ( ( :old.application is null and :new.application is not null ) or ( :old.application is not null and :new.application is null ) or ( :old.application <> :new.application ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.application, :new.application, 'APPLICATION', var_revision, code_oper );
    end if;
    if ( ( :old.value is null and :new.value is not null ) or ( :old.value is not null and :new.value is null ) or ( :old.value <> :new.value ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.value, :new.value, 'VALUE', var_revision, code_oper );
    end if;
    if ( ( :old.type is null and :new.type is not null ) or ( :old.type is not null and :new.type is null ) or ( :old.type <> :new.type ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.type, :new.type, 'TYPE', var_revision, code_oper );
    end if;
    if ( ( :old.auth is null and :new.auth is not null ) or ( :old.auth is not null and :new.auth is null ) or ( :old.auth <> :new.auth ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.auth, :new.auth, 'AUTH', var_revision, code_oper );
    end if;
    if ( ( :old.profile_type is null and :new.profile_type is not null ) or ( :old.profile_type is not null and :new.profile_type is null ) or ( :old.profile_type <> :new.profile_type ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.profile_type, :new.profile_type, 'PROFILE_TYPE', var_revision, code_oper );
    end if;
    if ( ( :old.sod is null and :new.sod is not null ) or ( :old.sod is not null and :new.sod is null ) or ( :old.sod <> :new.sod ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.sod, :new.sod, 'SOD', var_revision, code_oper );
    end if;
    if ( ( :old.dn is null and :new.dn is not null ) or ( :old.dn is not null and :new.dn is null ) or ( :old.dn <> :new.dn ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.dn, :new.dn, 'DN', var_revision, code_oper );
    end if;
    if ( ( :old.business_name is null and :new.business_name is not null ) or ( :old.business_name is not null and :new.business_name is null ) or ( :old.business_name <> :new.business_name ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.business_name, :new.business_name, 'BUSINESS_NAME', var_revision, code_oper );
    end if;
    if ( ( :old.it_resource_name is null and :new.it_resource_name is not null ) or ( :old.it_resource_name is not null and :new.it_resource_name is null ) or ( :old.it_resource_name <> :new.it_resource_name ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.it_resource_name, :new.it_resource_name, 'IT_RESOURCE_NAME', var_revision, code_oper );
    end if;
    if ( ( :old.owner is null and :new.owner is not null ) or ( :old.owner is not null and :new.owner is null ) or ( :old.owner <> :new.owner ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.owner, :new.owner, 'OWNER', var_revision, code_oper );
    end if;
    if ( ( :old.organization is null and :new.organization is not null ) or ( :old.organization is not null and :new.organization is null ) or ( :old.organization <> :new.organization ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.organization, :new.organization, 'ORGANIZATION', var_revision, code_oper );
    end if;
    if ( ( :old.user_membership is null and :new.user_membership is not null ) or ( :old.user_membership is not null and :new.user_membership is null ) or ( :old.user_membership <> :new.user_membership ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.user_membership, :new.user_membership, 'USER_MEMBERSHIP', var_revision, code_oper );
    end if;
    if ( ( :old.expiration is null and :new.expiration is not null ) or ( :old.expiration is not null and :new.expiration is null ) or ( :old.expiration <> :new.expiration ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           to_char ( :old.expiration, 'DD/MM/YYYY HH24:MI:SS' ) , to_char ( :new.expiration, 'DD/MM/YYYY HH24:MI:SS' ) , 'EXPIRATION', var_revision, code_oper );
    end if;
    if ( ( :old.last_date_reviewed is null and :new.last_date_reviewed is not null ) or ( :old.last_date_reviewed is not null and :new.last_date_reviewed is null ) or ( :old.last_date_reviewed <> :new.last_date_reviewed ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           to_char ( :old.last_date_reviewed, 'DD/MM/YYYY HH24:MI:SS' ) , to_char ( :new.last_date_reviewed, 'DD/MM/YYYY HH24:MI:SS' ) , 'LAST_DATE_REVIEWED', var_revision, code_oper );
    end if;
    if ( ( :old.business_policy is null and :new.business_policy is not null ) or ( :old.business_policy is not null and :new.business_policy is null ) or ( :old.business_policy <> :new.business_policy ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.business_policy, :new.business_policy, 'BUSINESS_POLICY', var_revision, code_oper );
    end if;
    if ( ( :old.privilege is null and :new.privilege is not null ) or ( :old.privilege is not null and :new.privilege is null ) or ( :old.privilege <> :new.privilege ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.privilege, :new.privilege, 'PRIVILEGE', var_revision, code_oper );
    end if;
    if ( ( :old.sod_policy is null and :new.sod_policy is not null ) or ( :old.sod_policy is not null and :new.sod_policy is null ) or ( :old.sod_policy <> :new.sod_policy ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.sod_policy, :new.sod_policy, 'SOD_POLICY', var_revision, code_oper );
    end if;
    if ( ( :old.jr_constraint is null and :new.jr_constraint is not null ) or ( :old.jr_constraint is not null and :new.jr_constraint is null ) or ( :old.jr_constraint <> :new.jr_constraint ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.jr_constraint, :new.jr_constraint, 'JR_CONSTRAINT', var_revision, code_oper );
    end if;
    /*PG-BEGIN*/
    if ( ( :old.exception is null and :new.exception is not null ) or ( :old.exception is not null and :new.exception is null ) or ( :old.exception <> :new.exception ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.exception, :new.exception, 'EXCEPTION', var_revision, code_oper );
    end if;
    /*if ( ( :old."exception" is null and :new."exception" is not null ) or ( :old."exception" is not null and :new."exception" is null ) or ( :old."exception" <> :new."exception" ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old."exception", :new."exception", 'EXCEPTION', var_revision, code_oper );
    end if;*/
    /*PG-END*/
    if ( ( :old.delegation is null and :new.delegation is not null ) or ( :old.delegation is not null and :new.delegation is null ) or ( :old.delegation <> :new.delegation ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.delegation, :new.delegation, 'DELEGATION', var_revision, code_oper );
    end if;
    if ( ( :old.workflow_auth is null and :new.workflow_auth is not null ) or ( :old.workflow_auth is not null and :new.workflow_auth is null ) or ( :old.workflow_auth <> :new.workflow_auth ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.workflow_auth, :new.workflow_auth, 'WORKFLOW_AUTH', var_revision, code_oper );
    end if;
    if ( ( :old.workflow_auth_state is null and :new.workflow_auth_state is not null ) or ( :old.workflow_auth_state is not null and :new.workflow_auth_state is null ) or ( :old.workflow_auth_state <> :new.workflow_auth_state ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.workflow_auth_state, :new.workflow_auth_state, 'WORKFLOW_AUTH_STATE', var_revision, code_oper );
    end if;
    if ( ( :old.workflow_check is null and :new.workflow_check is not null ) or ( :old.workflow_check is not null and :new.workflow_check is null ) or ( :old.workflow_check <> :new.workflow_check ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.workflow_check, :new.workflow_check, 'WORKFLOW_CHECK', var_revision, code_oper );
    end if;
    if ( ( :old.workflow_check_state is null and :new.workflow_check_state is not null ) or ( :old.workflow_check_state is not null and :new.workflow_check_state is null ) or ( :old.workflow_check_state <> :new.workflow_check_state ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.workflow_check_state, :new.workflow_check_state, 'WORKFLOW_CHECK_STATE', var_revision, code_oper );
    end if;
    if ( ( :old.jobrole_family is null and :new.jobrole_family is not null ) or ( :old.jobrole_family is not null and :new.jobrole_family is null ) or ( :old.jobrole_family <> :new.jobrole_family ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.jobrole_family, :new.jobrole_family, 'JOBROLE_FAMILY', var_revision, code_oper );
    end if;
    if ( ( :old.to_review is null and :new.to_review is not null ) or ( :old.to_review is not null and :new.to_review is null ) or ( :old.to_review <> :new.to_review ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.to_review, :new.to_review, 'TO_REVIEW', var_revision, code_oper );
    end if;
    if ( ( :old.last_review is null and :new.last_review is not null ) or ( :old.last_review is not null and :new.last_review is null ) or ( :old.last_review <> :new.last_review ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           to_char ( :old.last_review, 'DD/MM/YYYY HH24:MI:SS' ) , to_char ( :new.last_review, 'DD/MM/YYYY HH24:MI:SS' ) , 'LAST_REVIEW', var_revision, code_oper );
    end if;
    if ( ( :old.authorized is null and :new.authorized is not null ) or ( :old.authorized is not null and :new.authorized is null ) or ( :old.authorized <> :new.authorized ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.authorized, :new.authorized, 'AUTHORIZED', var_revision, code_oper );
    end if;
    if ( ( :old.modified is null and :new.modified is not null ) or ( :old.modified is not null and :new.modified is null ) or ( :old.modified <> :new.modified ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.modified, :new.modified, 'MODIFIED', var_revision, code_oper );
    end if;
    if ( ( :old.creation_user is null and :new.creation_user is not null ) or ( :old.creation_user is not null and :new.creation_user is null ) or ( :old.creation_user <> :new.creation_user ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.creation_user, :new.creation_user, 'CREATION_USER', var_revision, code_oper );
    end if;
    if ( ( :old.creation_date is null and :new.creation_date is not null ) or ( :old.creation_date is not null and :new.creation_date is null ) or ( :old.creation_date <> :new.creation_date ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           to_char ( :old.creation_date, 'DD/MM/YYYY HH24:MI:SS' ) , to_char ( :new.creation_date, 'DD/MM/YYYY HH24:MI:SS' ) , 'CREATION_DATE', var_revision, code_oper );
    end if;
    if ( ( :old.ownercode is null and :new.ownercode is not null ) or ( :old.ownercode is not null and :new.ownercode is null ) or ( :old.ownercode <> :new.ownercode ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.ownercode, :new.ownercode, 'OWNERCODE', var_revision, code_oper );
    end if;
    if ( ( :old.scope_visibility is null and :new.scope_visibility is not null ) or ( :old.scope_visibility is not null and :new.scope_visibility is null ) or ( :old.scope_visibility <> :new.scope_visibility ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.scope_visibility, :new.scope_visibility, 'SCOPE_VISIBILITY', var_revision, code_oper );
    end if;
    if ( ( :old.administrative is null and :new.administrative is not null ) or ( :old.administrative is not null and :new.administrative is null ) or ( :old.administrative <> :new.administrative ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.administrative, :new.administrative, 'ADMINISTRATIVE', var_revision, code_oper );
    end if;
    if ( ( :old.required_resource is null and :new.required_resource is not null ) or ( :old.required_resource is not null and :new.required_resource is null ) or ( :old.required_resource <> :new.required_resource ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.required_resource, :new.required_resource, 'REQUIRED_RESOURCE', var_revision, code_oper );
    end if;
    if ( ( :old.code is null and :new.code is not null ) or ( :old.code is not null and :new.code is null ) or ( :old.code <> :new.code ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.code, :new.code, 'CODE', var_revision, code_oper );
    end if;
    if ( ( :old.flow_auth is null and :new.flow_auth is not null ) or ( :old.flow_auth is not null and :new.flow_auth is null ) or ( :old.flow_auth <> :new.flow_auth ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.flow_auth, :new.flow_auth, 'FLOW_AUTH', var_revision, code_oper );
    end if;
    if ( ( :old.flow_auth_state is null and :new.flow_auth_state is not null ) or ( :old.flow_auth_state is not null and :new.flow_auth_state is null ) or ( :old.flow_auth_state <> :new.flow_auth_state ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.flow_auth_state, :new.flow_auth_state, 'FLOW_AUTH_STATE', var_revision, code_oper );
    end if;
    if ( ( :old.flow_check is null and :new.flow_check is not null ) or ( :old.flow_check is not null and :new.flow_check is null ) or ( :old.flow_check <> :new.flow_check ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.flow_check, :new.flow_check, 'FLOW_CHECK', var_revision, code_oper );
    end if;
    if ( ( :old.flow_check_state is null and :new.flow_check_state is not null ) or ( :old.flow_check_state is not null and :new.flow_check_state is null ) or ( :old.flow_check_state <> :new.flow_check_state ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.flow_check_state, :new.flow_check_state, 'FLOW_CHECK_STATE', var_revision, code_oper );
    end if;
    if ( ( :old.profile_ext_type is null and :new.profile_ext_type is not null ) or ( :old.profile_ext_type is not null and :new.profile_ext_type is null ) or ( :old.profile_ext_type <> :new.profile_ext_type ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.profile_ext_type, :new.profile_ext_type, 'PROFILE_EXT_TYPE', var_revision, code_oper );
    end if;
    if ( ( :old.ext_type is null and :new.ext_type is not null ) or ( :old.ext_type is not null and :new.ext_type is null ) or ( :old.ext_type <> :new.ext_type ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.ext_type, :new.ext_type, 'EXT_TYPE', var_revision, code_oper );
    end if;
    if ( ( :old.ext_ref is null and :new.ext_ref is not null ) or ( :old.ext_ref is not null and :new.ext_ref is null ) or ( :old.ext_ref <> :new.ext_ref ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.ext_ref, :new.ext_ref, 'EXT_REF', var_revision, code_oper );
    end if;
    if ( ( :old.attribute_based is null and :new.attribute_based is not null ) or ( :old.attribute_based is not null and :new.attribute_based is null ) or ( :old.attribute_based <> :new.attribute_based ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.attribute_based, :new.attribute_based, 'ATTRIBUTE_BASED', var_revision, code_oper );
    end if;
    if ( ( :old.required is null and :new.required is not null ) or ( :old.required is not null and :new.required is null ) or ( :old.required <> :new.required ) ) then
      insert into history
         ( id, operation, ent_type, ent_id, ent_name, ent_desc,
           old_val, new_val, field, revision, note )
      values
         ( history_seq.nextval, 1, 1, :new.id, :new.name, :new.description,
           :old.required, :new.required, 'REQUIRED', var_revision, code_oper );
    end if;
  end if;

  if ( deleting ) then
    insert into history
     ( id, operation, ent_type, ent_id, ent_name, ent_desc,
       old_val, new_val, field, revision, note )
    values
     ( history_seq.nextval, 3, 1, :old.id, :old.name, :old.description,
       null, null, null, var_revision, code_oper );
  end if;

end TRG_ENTITLEMENT_HISTORY;
/
