--CREATE A TABLE AND ITS CONSTRAINTS
set verify off
set serveroutput on
declare
  curr_user         varchar2(30);
  
  tab_name          varchar2(30) := 'ATTR_PERMISSION_MAPPING';
  dml_def           varchar2(4000);
  
  counter           number(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from all_tables t where t.owner = curr_user and t.table_name = tab_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'CREATE TABLE ATTR_PERMISSION_MAPPING
(
  ID                             NUMBER(16)         NOT NULL,
  NAME                           VARCHAR2(256 CHAR) NOT NULL,
  DESCRIPTION                    VARCHAR2(512 CHAR),
  DISABLED                       NUMBER(1)          DEFAULT 0 NOT NULL,
  TYPE                           VARCHAR2(128)      NOT NULL,
  REQUIRED                       NUMBER(1)          DEFAULT 0 NOT NULL,
  SINGLE_VALUE                   NUMBER(1)          DEFAULT 0 NOT NULL,
  TARGET                         VARCHAR2(256 CHAR) NOT NULL,
  APPLICATION_NAME               VARCHAR2(256 CHAR),
  PERMISSION_TYPE                VARCHAR2(256 CHAR),
  PERMISSION_NAME                VARCHAR2(256 CHAR),
  ATTR1                          VARCHAR2(256 CHAR),
  ATTR2                          VARCHAR2(256 CHAR),
  ATTR3                          VARCHAR2(256 CHAR),
  ATTR4                          VARCHAR2(256 CHAR),
  ATTR5                          VARCHAR2(256 CHAR),
  CREATION_USER                  VARCHAR2(128 CHAR),
  CREATION_DATE                  DATE                DEFAULT SYSDATE,
  LAST_MOD_USER                  VARCHAR2(128 CHAR),
  LAST_MOD_TIME                  DATE                DEFAULT SYSDATE
)
tablespace &DATA_TABLESPACE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'alter table ATTR_PERMISSION_MAPPING
  add constraint ATTR_PERMISSION_MAPPING_PK primary key (ID)
  using index 
  tablespace &INDEX_TABLESPACE compute statistics
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'CREATE UNIQUE INDEX ATTR_PERMISSION_MAPPING_IDX ON ATTR_PERMISSION_MAPPING (NAME, TARGET)
tablespace &INDEX_TABLESPACE compute statistics
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
set serveroutput off
set verify on

--COMMENT ON COLUMN ATTR_PERMISSION_MAPPING.DISABLED IS
--'0: FALSE 1: TRUE';

COMMENT ON COLUMN ATTR_PERMISSION_MAPPING.REQUIRED IS
'0: FALSE 1: TRUE';

COMMENT ON COLUMN ATTR_PERMISSION_MAPPING.SINGLE_VALUE IS
'0: FALSE 1: TRUE';

grant select on ATTR_PERMISSION_MAPPING to AA;
grant select, insert, update, delete, references on ATTR_PERMISSION_MAPPING to IDEAS;
grant select, insert, update, delete, references on ATTR_PERMISSION_MAPPING to IDEAS_CONNECTOR;
grant select on ATTR_PERMISSION_MAPPING to IDEAS_REPORT;


--CREATE A SEQUENCE
set verify off
set serveroutput on
declare
  curr_user         varchar2(30);
  
  seq_name          varchar2(30) := 'ATTR_PERMISSION_MAPPING_SEQ';
  dml_def           varchar2(4000);
  
  counter           number(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from all_sequences t where t.sequence_owner = curr_user and t.sequence_name = seq_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'create sequence ATTR_PERMISSION_MAPPING_SEQ
  START WITH 100
  INCREMENT BY 1
  MINVALUE 100
  MAXVALUE 999999999999999999999999999
  NOCACHE
  NOCYCLE
  NOORDER
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
set serveroutput off
set verify on

grant select on ATTR_PERMISSION_MAPPING_SEQ to AA;
grant select, alter on ATTR_PERMISSION_MAPPING_SEQ to IDEAS;
grant select on ATTR_PERMISSION_MAPPING_SEQ to IDEAS_CONNECTOR;
grant select on ATTR_PERMISSION_MAPPING_SEQ to IDEAS_REPORT;
