--CREATE A TABLE AND ITS CONSTRAINTS
set verify off
set serveroutput on
declare
  curr_user         varchar(30);
  
  tab_name          varchar(30) := 'ATTR_PERMISSION_MAPPING';
  dml_def           varchar(4000);
  
  counter           numeric(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from sysibm.tables t where ( t.table_type = 'BASE TABLE' or t.table_type is null ) and lower ( t.table_schema ) = lower ( curr_user ) and t.table_name = tab_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'CREATE TABLE ATTR_PERMISSION_MAPPING
(
  ID                             NUMERIC(16)         NOT NULL,
  NAME                           VARCHAR(256)        NOT NULL,
  DESCRIPTION                    VARCHAR(512),
  DISABLED                       NUMERIC(1)          DEFAULT 0 NOT NULL,
  TYPE                           VARCHAR(128)        NOT NULL,
  REQUIRED                       NUMERIC(1)          DEFAULT 0 NOT NULL,
  SINGLE_VALUE                   NUMERIC(1)          DEFAULT 0 NOT NULL,
  TARGET                         VARCHAR(256)        NOT NULL,
  APPLICATION_NAME               VARCHAR(256),
  PERMISSION_TYPE                VARCHAR(256),
  PERMISSION_NAME                VARCHAR(256),
  ATTR1                          VARCHAR(256),
  ATTR2                          VARCHAR(256),
  ATTR3                          VARCHAR(256),
  ATTR4                          VARCHAR(256),
  ATTR5                          VARCHAR(256),
  CREATION_USER                  VARCHAR(128),
  CREATION_DATE                  DATE                DEFAULT CURRENT_DATE,
  LAST_MOD_USER                  VARCHAR(128),
  LAST_MOD_TIME                  DATE                DEFAULT CURRENT_DATE
)
IN &DATA_TABLESPACE
INDEX IN &INDEX_TABLESPACE
LONG IN &LOB_TABLESPACE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE ATTR_PERMISSION_MAPPING ADD
  CONSTRAINT ATTR_PERMISSION_MAPPING_PK
 PRIMARY KEY (ID)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'CREATE UNIQUE INDEX ATTR_PERMISSION_MAPPING_IDX ON ATTR_PERMISSION_MAPPING (NAME, TARGET)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
commit;
set serveroutput off
set verify on

--REORGANIZE A TABLE
set verify off
set serveroutput on
declare
  curr_user         varchar(30);
  
  tab_name          varchar(30) := 'ATTR_PERMISSION_MAPPING';
  dml_def           varchar(4000);
  
  counter           numeric(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from sysibm.tables t where ( t.table_type = 'BASE TABLE' or t.table_type is null ) and lower ( t.table_schema ) = lower ( curr_user ) and t.table_name = tab_name;
  if ( counter = 0 ) then
    return;
  end if;

  dml_def :=
'CALL SYSPROC.ADMIN_CMD( ''REORG TABLE ATTR_PERMISSION_MAPPING'' )
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
commit;
set serveroutput off
set verify on

--COMMENT ON COLUMN ATTR_PERMISSION_MAPPING.DISABLED IS
--'0: FALSE 1: TRUE';

COMMENT ON COLUMN ATTR_PERMISSION_MAPPING.REQUIRED IS
'0: FALSE 1: TRUE';

COMMENT ON COLUMN ATTR_PERMISSION_MAPPING.SINGLE_VALUE IS
'0: FALSE 1: TRUE';

grant select on ATTR_PERMISSION_MAPPING to &AA_SUPER_ADMIN_USER;
grant select, insert, update, delete, references on ATTR_PERMISSION_MAPPING to &IDEAS_SUPER_ADMIN_USER;
grant select, insert, update, delete, references on ATTR_PERMISSION_MAPPING to &IDEAS_CONN_SUPER_ADMIN_USER;
grant select on ATTR_PERMISSION_MAPPING to &IDEAS_REPORT_SUPER_ADMIN_USER;


--CREATE A SEQUENCE
set verify off
set serveroutput on
declare
  curr_user         varchar(30);
  
  seq_name          varchar(30) := 'ATTR_PERMISSION_MAPPING_SEQ';
  dml_def           varchar(4000);
  
  counter           numeric(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from syscat.sequences t where lower ( t.seqschema ) = lower ( curr_user ) and t.seqtype <> 'I' and lower ( t.seqname ) = lower ( seq_name );
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'create sequence ATTR_PERMISSION_MAPPING_SEQ
  AS NUMERIC(18)
  START WITH 100
  INCREMENT BY 1
  MINVALUE 100
  MAXVALUE 999999999999999999
  NO CACHE
  NO CYCLE
  NO ORDER
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
commit;
set serveroutput off
set verify on

grant usage on sequence ATTR_PERMISSION_MAPPING_SEQ to &AA_SUPER_ADMIN_USER;
grant usage, alter on sequence ATTR_PERMISSION_MAPPING_SEQ to &IDEAS_SUPER_ADMIN_USER;
grant usage, alter on sequence ATTR_PERMISSION_MAPPING_SEQ to &IDEAS_CONN_SUPER_ADMIN_USER;
grant usage on sequence ATTR_PERMISSION_MAPPING_SEQ to &IDEAS_REPORT_SUPER_ADMIN_USER;
