CREATE OR REPLACE function ent_20_ent_parents
(
  entitlement_id in numeric(31),
  only_published in numeric(31)
)
return sys_refcursor is
/*
  Procedura che restituisce i padri gerarchici pubblicati e non cancellati logicamente di un Entitlement.
  Tale procedura si pu utilizzare per ottenere una lista di entitlement pubblicati di cui aggiornare la
  gerarchia nella tabella ENTITLEMENT_AUTH_PROFILE.
  L'ambito tipico di utilizzo  l'aggiornamento della gerachia di un ENTITLEMENT pubblicato.
  Se viene aggiornata la gerarchia di un ENTITLEMENT pubblicato c' bisogno di aggiornare la propria gerarchia
  pubblicata, ma anche quella di tutti i padri a cui  stato associato gerarchicamente

  2013-08-29 - Procedura estesa alla ricerca dei padri gerarchici anche non pubblicati.
*/
  NUMERIC_TRUE              constant numeric(1) := 1;
  PUBLISHED_STATE           constant numeric(1) := 1;
  ENTITLEMENT_DELETED       constant numeric(1) := 2;
  entitlement_parent_cur    sys_refcursor;
begin
  if ( only_published = NUMERIC_TRUE ) then
    open entitlement_parent_cur for
      select e.id as ENTITLEMENT from entitlement e,
      (
        select entitlement_id as parent from entitlement e where e.authorized = PUBLISHED_STATE
        union
        select t.parent from
        /*PG-BEGIN*/
        entitlement_hier t
        connect by prior t.parent = t.child
        start with t.child = entitlement_id
        /*(
          select * from connectby ( 'entitlement_hier', 'parent', 'child', cast (entitlement_id as varchar), 0 )
          as t ( parent numeric(16), child numeric(16), level int )
        ) t, entitlement e where t.parent = e.id*/
        /*PG-END*/
      ) par
      where
        par.parent = e.id
        and e.authorized = PUBLISHED_STATE
        and e.modified <> ENTITLEMENT_DELETED;
   else
    open entitlement_parent_cur for
      select e.id as ENTITLEMENT from entitlement e,
      (
        select entitlement_id as parent from entitlement e
        union
        select t.parent from
        /*PG-BEGIN*/
        entitlement_hier t
        connect by prior t.parent = t.child
        start with t.child = entitlement_id
        /*(
          select * from connectby ( 'entitlement_hier', 'parent', 'child', cast (entitlement_id as varchar), 0 )
          as t ( parent numeric(16), child numeric(16), level int )
        ) t, entitlement e where t.parent = e.id*/
        /*PG-END*/
      ) par
      where
        par.parent = e.id
        and e.modified <> ENTITLEMENT_DELETED;
   end if;

  return entitlement_parent_cur;
end ent_20_ent_parents;
/
