CREATE OR REPLACE function ent_21_check_hier
(
  parent_id in number,
  child_id in number
)
return sys_refcursor is
/*
  Procedura che restituisce i padri gerarchici pubblicati e non cancellati logicamente di un Entitlement.
  Tale procedura si pu utilizzare per ottenere una lista di entitlement pubblicati di cui aggiornare la
  gerarchia nella tabella ENTITLEMENT_AUTH_PROFILE.
  L'ambito tipico di utilizzo  l'aggiornamento della gerachia di un ENTITLEMENT pubblicato.
  Se viene aggiornata la gerarchia di un ENTITLEMENT pubblicato c' bisogno di aggiornare la propria gerarchia
  pubblicata, ma anche quella di tutti i padri a cui  stato associato gerarchicamente
*/
  HIER_PARENT_LOOP          constant number(1) := -1;
  HIER_CHILD_LOOP           constant number(1) := -2;
  HIER_SAME_PARENT_CHILD    constant number(1) := -3;
  HIER_OK                   constant number(1) := 0;
  HIER_NO                   constant number(1) := 1;

  /*PG-BEGIN*/
  closed_loop               EXCEPTION;
  -- ORA-01436: CONNECT BY loop in user data
  PRAGMA                    EXCEPTION_INIT (closed_loop, -1436);
  /**/
  /*PG-END*/

  count_cur                 sys_refcursor;

  return_code               number(16) := 0;
  counter                   number(16);
begin
  --controlliamo se (per qualche motivo) non vi sia GIA'
  --un loop nella gerarchia del padre
  return_code := HIER_PARENT_LOOP; --se dovesse andare in eccezione il return_code  gi settato
  select count(1) into counter from
  (
    select t.child from
    /*PG-BEGIN*/
    entitlement_hier t start with t.parent = parent_id
    connect by prior t.child = t.parent
    /*(
      select * from connectby ( 'entitlement_hier', 'child', 'parent', cast (parent_id as varchar), 0 )
      as t ( child numeric(16), parent numeric(16), level int )
    ) t, entitlement e where t.child = e.id*/
    /*PG-END*/
  ) par_hier where par_hier.child = parent_id;

  --controlliamo se (per qualche motivo) non vi sia GIA'
  --un loop nella gerarchia del figlio
  return_code := HIER_CHILD_LOOP; --se dovesse andare in eccezione il return_code  gi settato
  select count(1) into return_code from
  (
    select t.child from
    /*PG-BEGIN*/
    entitlement_hier t start with t.parent = child_id
    connect by prior t.child = t.parent
    /*(
      select * from connectby ( 'entitlement_hier',  'child', 'parent', cast (child_id as varchar), 0 )
      as t ( child numeric(16), parent numeric(16), level int )
    ) t, entitlement e where t.child = e.id*/
    /*PG-END*/
  ) par_hier where par_hier.child = parent_id;

  if ( parent_id = child_id ) then
    open count_cur for select HIER_SAME_PARENT_CHILD as COUNTER from dual;
    return count_cur;
  else
    --il figlio non deve avere il padre cui si vuole aggiungere come figlio
    --se non ci sono eccezioni (quindi non ci sono loop nella query gerarchica)
    --la query deve tornare 0
    return_code := HIER_NO; --se dovesse andare in eccezione il return_code  gi settato
    select count(1) into counter from
    (
      select t.child from
      /*PG-BEGIN*/
      entitlement_hier t start with t.parent = child_id
      connect by prior t.child = t.parent
      /*(
        select * from connectby ( 'entitlement_hier',  'child', 'parent', cast (child_id as varchar), 0 )
        as t ( child numeric(16), parent numeric(16), level int )
      ) t, entitlement e where t.child = e.id*/
      /*PG-END*/
    ) par_hier where par_hier.child = parent_id;

    return_code := counter;
    open count_cur for select return_code as COUNTER from dual;
    return count_cur;
  end if;

  open count_cur for select 0 as COUNTER from dual;
  return count_cur;
exception
  --Si  verificata una eccezione ORA-1436 (loop nella gerarchia dei dati)
  --dovuto ad un loop GIA' presente (la query gerarchica ha dato eccezione)
  --in Oracle 9 o in Oracle 10 non specificando la clausola NOCYCLE
  /*PG-BEGIN*/
  when closed_loop then
  /*when others then*/
  /*PG-END*/
  open count_cur for select return_code as COUNTER from dual;
  return count_cur;
end ent_21_check_hier;
/
