CREATE TABLE PWDCFG_ATTR_KEY
(
  ID                             NUMBER(16)          NOT NULL,
  PWDCFG                         NUMBER(16)          NOT NULL,
  NAME                           VARCHAR2(64 CHAR)   NOT NULL,
  DESCRIPTION                    VARCHAR2(512 CHAR),
  STATE                          NUMBER(16)          DEFAULT 0,
  COLUMN_TYPE                    NUMBER(3),
  VISIBLE                        NUMBER(16),
  LOCALIZATION                   NUMBER(16),
  UI_RENDERING                   NUMBER(2),
  REQUIRED                       NUMBER(1),
  ATTR1                          VARCHAR2(256 CHAR),
  ATTR2                          VARCHAR2(256 CHAR),
  ATTR3                          VARCHAR2(256 CHAR),
  ATTR4                          VARCHAR2(256 CHAR),
  ATTR5                          VARCHAR2(256 CHAR),
  CREATION_DATE                  DATE                DEFAULT SYSDATE,
  CREATION_USER                  VARCHAR2(128 CHAR),
  LAST_MOD_USER                  VARCHAR2(128 CHAR),
  LAST_MOD_TIME                  DATE                DEFAULT SYSDATE
)
TABLESPACE &DATA_TABLESPACE
;

ALTER TABLE PWDCFG_ATTR_KEY ADD (
  CONSTRAINT PWDCFG_ATTR_KEY_PK
 PRIMARY KEY
 (ID)
  USING INDEX TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS);

ALTER TABLE PWDCFG_ATTR_KEY ADD (
  CONSTRAINT PWDCFG_AK_LOCALIZATION_FK
 FOREIGN KEY (LOCALIZATION)
 REFERENCES LOCALIZATION (ID)
    ON DELETE SET NULL);

ALTER TABLE PWDCFG_ATTR_KEY ADD (
  CONSTRAINT PWDCFG_AK_PWDCFG_FK
 FOREIGN KEY (PWDCFG)
 REFERENCES PWDCFG (ID)
    ON DELETE CASCADE);

CREATE UNIQUE INDEX PWDCFG_AK_PWDCFG_LNAME_IDX ON PWDCFG_ATTR_KEY
(PWDCFG, LOWER(NAME))
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS;

CREATE INDEX PWDCFG_ATTR_KEY_REPOSITORY_IDX ON PWDCFG_ATTR_KEY
(PWDCFG)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS;

COMMENT ON COLUMN PWDCFG_ATTR_KEY.REQUIRED IS
'0: NOT REQUIRED - 1: REQUIRED NOT NULL ON DB - 2: REQUIRED ON UI';

COMMENT ON COLUMN PWDCFG_ATTR_KEY.VISIBLE IS
'Specifies the order in which the data will be displayed. If null or zero shoud not be shown';

grant select on PWDCFG_ATTR_KEY to AA;
grant select, insert, update, delete, references on PWDCFG_ATTR_KEY to IDEAS;
grant select, insert, update, delete, references on PWDCFG_ATTR_KEY to IDEAS_CONNECTOR;
grant select on PWDCFG_ATTR_KEY to IDEAS_REPORT;

CREATE SEQUENCE PWDCFG_ATTR_KEY_SEQ
  START WITH 100
  INCREMENT BY 1
  MINVALUE 100
  MAXVALUE 999999999999999999999999999
  NOCACHE
  NOCYCLE
  NOORDER;

grant select on PWDCFG_ATTR_KEY_SEQ to AA;
grant select, alter on PWDCFG_ATTR_KEY_SEQ to IDEAS;
grant select on PWDCFG_ATTR_KEY_SEQ to IDEAS_CONNECTOR;
grant select on PWDCFG_ATTR_KEY_SEQ to IDEAS_REPORT;
