--CREATE A TABLE AND ITS CONSTRAINTS
set verify off
set serveroutput on
declare
  curr_user         varchar2(30);
  
  tab_name          varchar2(30) := 'PWDCFG_ATTR_KEY';
  dml_def           varchar2(4000);
  
  counter           number(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from all_tables t where t.owner = curr_user and t.table_name = tab_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'CREATE TABLE PWDCFG_ATTR_KEY
(
  ID                             NUMBER(16)          NOT NULL,
  PWDCFG                         NUMBER(16)          NOT NULL,
  NAME                           VARCHAR2(64 CHAR)   NOT NULL,
  DESCRIPTION                    VARCHAR2(512 CHAR),
  STATE                          NUMBER(16)          DEFAULT 0,
  COLUMN_TYPE                    NUMBER(3),
  VISIBLE                        NUMBER(16),
  LOCALIZATION                   NUMBER(16),
  UI_RENDERING                   NUMBER(2),
  REQUIRED                       NUMBER(1),
  ATTR1                          VARCHAR2(256 CHAR),
  ATTR2                          VARCHAR2(256 CHAR),
  ATTR3                          VARCHAR2(256 CHAR),
  ATTR4                          VARCHAR2(256 CHAR),
  ATTR5                          VARCHAR2(256 CHAR),
  CREATION_DATE                  DATE                DEFAULT SYSDATE,
  CREATION_USER                  VARCHAR2(128 CHAR),
  LAST_MOD_USER                  VARCHAR2(128 CHAR),
  LAST_MOD_TIME                  DATE                DEFAULT SYSDATE
)
TABLESPACE &DATA_TABLESPACE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE PWDCFG_ATTR_KEY ADD (
  CONSTRAINT PWDCFG_ATTR_KEY_PK
 PRIMARY KEY
 (ID)
  USING INDEX TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE PWDCFG_ATTR_KEY ADD (
  CONSTRAINT PWDCFG_AK_LOCALIZATION_FK
 FOREIGN KEY (LOCALIZATION)
 REFERENCES LOCALIZATION (ID)
    ON DELETE SET NULL)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE PWDCFG_ATTR_KEY ADD (
  CONSTRAINT PWDCFG_AK_PWDCFG_FK
 FOREIGN KEY (PWDCFG)
 REFERENCES PWDCFG (ID)
    ON DELETE CASCADE)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'CREATE UNIQUE INDEX PWDCFG_AK_PWDCFG_LNAME_IDX ON PWDCFG_ATTR_KEY
(PWDCFG, LOWER(NAME))
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'CREATE INDEX PWDCFG_ATTR_KEY_REPOSITORY_IDX ON PWDCFG_ATTR_KEY
(PWDCFG)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
set serveroutput off
set verify on

COMMENT ON COLUMN PWDCFG_ATTR_KEY.REQUIRED IS
'0: NOT REQUIRED - 1: REQUIRED NOT NULL ON DB - 2: REQUIRED ON UI';

COMMENT ON COLUMN PWDCFG_ATTR_KEY.VISIBLE IS
'Specifies the order in which the data will be displayed. If null or zero shoud not be shown';

grant select on PWDCFG_ATTR_KEY to AA;
grant select, insert, update, delete, references on PWDCFG_ATTR_KEY to IDEAS;
grant select, insert, update, delete, references on PWDCFG_ATTR_KEY to IDEAS_CONNECTOR;
grant select on PWDCFG_ATTR_KEY to IDEAS_REPORT;


--CREATE A SEQUENCE
set verify off
set serveroutput on
declare
  curr_user         varchar2(30);
  
  seq_name          varchar2(30) := 'PWDCFG_ATTR_KEY_SEQ';
  dml_def           varchar2(4000);
  
  counter           number(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from all_sequences t where t.sequence_owner = curr_user and t.sequence_name = seq_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'CREATE SEQUENCE PWDCFG_ATTR_KEY_SEQ
  START WITH 100
  INCREMENT BY 1
  MINVALUE 100
  MAXVALUE 999999999999999999999999999
  NOCACHE
  NOCYCLE
  NOORDER
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
set serveroutput off
set verify on

grant select on PWDCFG_ATTR_KEY_SEQ to AA;
grant select, alter on PWDCFG_ATTR_KEY_SEQ to IDEAS;
grant select on PWDCFG_ATTR_KEY_SEQ to IDEAS_CONNECTOR;
grant select on PWDCFG_ATTR_KEY_SEQ to IDEAS_REPORT;
