--CREATE A TABLE AND ITS CONSTRAINTS
set verify off
set serveroutput on
declare
  curr_user         varchar(30);
  
  tab_name          varchar(30) := 'PWDCFG_ATTR_KEY';
  dml_def           varchar(4000);
  
  counter           numeric(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from sysibm.tables t where ( t.table_type = 'BASE TABLE' or t.table_type is null ) and lower ( t.table_schema ) = lower ( curr_user ) and t.table_name = tab_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'CREATE TABLE PWDCFG_ATTR_KEY
(
  ID                             NUMERIC(16)         NOT NULL,
  PWDCFG                         NUMERIC(16)         NOT NULL,
  NAME                           VARCHAR(64)         NOT NULL,
  DESCRIPTION                    VARCHAR(512),
  STATE                          NUMERIC(16)         DEFAULT 0,
  COLUMN_TYPE                    NUMERIC(3),
  VISIBLE                        NUMERIC(16),
  LOCALIZATION                   NUMERIC(16),
  UI_RENDERING                   NUMERIC(2),
  REQUIRED                       NUMERIC(1),
  ATTR1                          VARCHAR(256),
  ATTR2                          VARCHAR(256),
  ATTR3                          VARCHAR(256),
  ATTR4                          VARCHAR(256),
  ATTR5                          VARCHAR(256),
  CREATION_DATE                  DATE                DEFAULT CURRENT_DATE,
  CREATION_USER                  VARCHAR(128),
  LAST_MOD_USER                  VARCHAR(128),
  LAST_MOD_TIME                  DATE                DEFAULT CURRENT_DATE
)
IN &DATA_TABLESPACE
INDEX IN &INDEX_TABLESPACE
LONG IN &LOB_TABLESPACE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE PWDCFG_ATTR_KEY ADD
  CONSTRAINT PWDCFG_ATTR_KEY_PK
 PRIMARY KEY (ID)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE PWDCFG_ATTR_KEY ADD
  CONSTRAINT PWDCFG_AK_LOCALIZATION_FK
 FOREIGN KEY (LOCALIZATION)
 REFERENCES LOCALIZATION (ID)
    ON DELETE SET NULL
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE PWDCFG_ATTR_KEY ADD
  CONSTRAINT PWDCFG_AK_PWDCFG_FK
 FOREIGN KEY (PWDCFG)
 REFERENCES PWDCFG (ID)
    ON DELETE CASCADE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'CREATE UNIQUE INDEX PWDCFG_AK_PWDCFG_LNAME_IDX ON PWDCFG_ATTR_KEY
(PWDCFG, LOWER(NAME))
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'CREATE INDEX PWDCFG_ATTR_KEY_REPOSITORY_IDX ON PWDCFG_ATTR_KEY
(PWDCFG)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
commit;
set serveroutput off
set verify on

--REORGANIZE A TABLE
set verify off
set serveroutput on
declare
  curr_user         varchar(30);
  
  tab_name          varchar(30) := 'PWDCFG_ATTR_KEY';
  dml_def           varchar(4000);
  
  counter           numeric(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from sysibm.tables t where ( t.table_type = 'BASE TABLE' or t.table_type is null ) and lower ( t.table_schema ) = lower ( curr_user ) and t.table_name = tab_name;
  if ( counter = 0 ) then
    return;
  end if;

  dml_def :=
'CALL SYSPROC.ADMIN_CMD( ''REORG TABLE PWDCFG_ATTR_KEY'' )
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
commit;
set serveroutput off
set verify on

COMMENT ON COLUMN PWDCFG_ATTR_KEY.REQUIRED IS
'0: NOT REQUIRED - 1: REQUIRED NOT NULL ON DB - 2: REQUIRED ON UI';

COMMENT ON COLUMN PWDCFG_ATTR_KEY.VISIBLE IS
'Specifies the order in which the data will be displayed. If null or zero shoud not be shown';

grant select on PWDCFG_ATTR_KEY to &AA_SUPER_ADMIN_USER;
grant select, insert, update, delete, references on PWDCFG_ATTR_KEY to &IDEAS_SUPER_ADMIN_USER;
grant select, insert, update, delete, references on PWDCFG_ATTR_KEY to &IDEAS_CONN_SUPER_ADMIN_USER;
grant select on PWDCFG_ATTR_KEY to &IDEAS_REPORT_SUPER_ADMIN_USER;


--CREATE A SEQUENCE
set verify off
set serveroutput on
declare
  curr_user         varchar(30);
  
  seq_name          varchar(30) := 'PWDCFG_ATTR_KEY_SEQ';
  dml_def           varchar(4000);
  
  counter           numeric(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from syscat.sequences t where lower ( t.seqschema ) = lower ( curr_user ) and t.seqtype <> 'I' and lower ( t.seqname ) = lower ( seq_name );
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'CREATE SEQUENCE PWDCFG_ATTR_KEY_SEQ
  AS NUMERIC(18)
  START WITH 100
  INCREMENT BY 1
  MINVALUE 100
  MAXVALUE 999999999999999999
  NO CACHE
  NO CYCLE
  NO ORDER
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
commit;
set serveroutput off
set verify on

grant usage on sequence PWDCFG_ATTR_KEY_SEQ to &AA_SUPER_ADMIN_USER;
grant usage, alter on sequence PWDCFG_ATTR_KEY_SEQ to &IDEAS_SUPER_ADMIN_USER;
grant usage, alter on sequence PWDCFG_ATTR_KEY_SEQ to &IDEAS_CONN_SUPER_ADMIN_USER;
grant usage on sequence PWDCFG_ATTR_KEY_SEQ to &IDEAS_REPORT_SUPER_ADMIN_USER;
