--CREATE A TABLE AND ITS CONSTRAINTS
set verify off
set serveroutput on
declare
  curr_user         varchar(30);
  
  tab_name          varchar(30) := 'PWDMANAGEMENT_ATTR_VAL';
  dml_def           varchar(4000);
  
  counter           numeric(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from sysibm.tables t where ( t.table_type = 'BASE TABLE' or t.table_type is null ) and lower ( t.table_schema ) = lower ( curr_user ) and t.table_name = tab_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'CREATE TABLE PWDMANAGEMENT_ATTR_VAL
(
  ID                             NUMERIC(16)         NOT NULL,
  PWDMANAGEMENT                  NUMERIC(16)         NOT NULL,
  PWDCFG_ATTR_KEY                NUMERIC(16)         NOT NULL,
  VALUE                          VARCHAR(512),
  STATE                          NUMERIC(16)         DEFAULT 0,
  ATTR1                          VARCHAR(256),
  ATTR2                          VARCHAR(256),
  ATTR3                          VARCHAR(256),
  ATTR4                          VARCHAR(256),
  ATTR5                          VARCHAR(256),
  CREATION_DATE                  DATE                DEFAULT CURRENT_DATE,
  CREATION_USER                  VARCHAR(128),
  LAST_MOD_USER                  VARCHAR(128),
  LAST_MOD_TIME                  DATE                DEFAULT CURRENT_DATE
)
IN &DATA_TABLESPACE
INDEX IN &INDEX_TABLESPACE
LONG IN &LOB_TABLESPACE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE PWDMANAGEMENT_ATTR_VAL ADD
  CONSTRAINT PWDMANAGEMENT_ATTR_VAL_PK
 PRIMARY KEY (ID)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE PWDMANAGEMENT_ATTR_VAL ADD
  CONSTRAINT PWDMAN_ATTR_VAL_PWDCFG_AK_FK
 FOREIGN KEY (PWDCFG_ATTR_KEY)
 REFERENCES PWDMANAGEMENT_ATTR_VAL (ID)
    ON DELETE CASCADE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE PWDMANAGEMENT_ATTR_VAL ADD
  CONSTRAINT PWDMAN_ATTR_VAL_PWDMAN_FK
 FOREIGN KEY (PWDMANAGEMENT)
 REFERENCES PWDMANAGEMENT (ID)
    ON DELETE CASCADE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'CREATE INDEX PWDMAN_ATTR_VAL_PWDCFG_AK_IDX ON PWDMANAGEMENT_ATTR_VAL
(PWDCFG_ATTR_KEY)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'CREATE INDEX PWDMAN_ATTR_VAL_PWDMAN_IDX ON PWDMANAGEMENT_ATTR_VAL
(PWDMANAGEMENT)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'CREATE INDEX PWDMAN_ATTR_VAL_UNIQUE_IDX ON PWDMANAGEMENT_ATTR_VAL
(PWDMANAGEMENT, PWDCFG_ATTR_KEY, LOWER(VALUE))
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
commit;
set serveroutput off
set verify on

--REORGANIZE A TABLE
set verify off
set serveroutput on
declare
  curr_user         varchar(30);
  
  tab_name          varchar(30) := 'PWDMANAGEMENT_ATTR_VAL';
  dml_def           varchar(4000);
  
  counter           numeric(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from sysibm.tables t where ( t.table_type = 'BASE TABLE' or t.table_type is null ) and lower ( t.table_schema ) = lower ( curr_user ) and t.table_name = tab_name;
  if ( counter = 0 ) then
    return;
  end if;

  dml_def :=
'CALL SYSPROC.ADMIN_CMD( ''REORG TABLE PWDMANAGEMENT_ATTR_VAL'' )
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
commit;
set serveroutput off
set verify on

grant select on PWDMANAGEMENT_ATTR_VAL to &AA_SUPER_ADMIN_USER;
grant select, insert, update, delete, references on PWDMANAGEMENT_ATTR_VAL to &IDEAS_SUPER_ADMIN_USER;
grant select, insert, update, delete, references on PWDMANAGEMENT_ATTR_VAL to &IDEAS_CONN_SUPER_ADMIN_USER;
grant select on PWDMANAGEMENT_ATTR_VAL to &IDEAS_REPORT_SUPER_ADMIN_USER;


--CREATE A SEQUENCE
set verify off
set serveroutput on
declare
  curr_user         varchar(30);
  
  seq_name          varchar(30) := 'PWDMANAGEMENT_ATTR_VAL_SEQ';
  dml_def           varchar(4000);
  
  counter           numeric(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from syscat.sequences t where lower ( t.seqschema ) = lower ( curr_user ) and t.seqtype <> 'I' and lower ( t.seqname ) = lower ( seq_name );
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'CREATE SEQUENCE PWDMANAGEMENT_ATTR_VAL_SEQ
  AS NUMERIC(18)
  START WITH 100
  INCREMENT BY 1
  MINVALUE 100
  MAXVALUE 999999999999999999
  NO CACHE
  NO CYCLE
  NO ORDER
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
commit;
set serveroutput off
set verify on

grant usage on sequence PWDMANAGEMENT_ATTR_VAL_SEQ to &AA_SUPER_ADMIN_USER;
grant usage, alter on sequence PWDMANAGEMENT_ATTR_VAL_SEQ to &IDEAS_SUPER_ADMIN_USER;
grant usage, alter on sequence PWDMANAGEMENT_ATTR_VAL_SEQ to &IDEAS_CONN_SUPER_ADMIN_USER;
grant usage on sequence PWDMANAGEMENT_ATTR_VAL_SEQ to &IDEAS_REPORT_SUPER_ADMIN_USER;
