--CREATE A TABLE AND ITS CONSTRAINTS
set verify off
set serveroutput on
declare
  curr_user         varchar2(30);
  
  tab_name          varchar2(30) := 'PWDMANAGEMENT_ATTR_VAL';
  dml_def           varchar2(4000);
  
  counter           number(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from all_tables t where t.owner = curr_user and t.table_name = tab_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'CREATE TABLE PWDMANAGEMENT_ATTR_VAL
(
  ID                             NUMBER(16)          NOT NULL,
  PWDMANAGEMENT                  NUMBER(16)          NOT NULL,
  PWDCFG_ATTR_KEY                NUMBER(16)          NOT NULL,
  VALUE                          VARCHAR2(512 CHAR),
  STATE                          NUMBER(16)          DEFAULT 0,
  ATTR1                          VARCHAR2(256 CHAR),
  ATTR2                          VARCHAR2(256 CHAR),
  ATTR3                          VARCHAR2(256 CHAR),
  ATTR4                          VARCHAR2(256 CHAR),
  ATTR5                          VARCHAR2(256 CHAR),
  CREATION_DATE                  DATE                DEFAULT SYSDATE,
  CREATION_USER                  VARCHAR2(128 CHAR),
  LAST_MOD_USER                  VARCHAR2(128 CHAR),
  LAST_MOD_TIME                  DATE                DEFAULT SYSDATE
)
TABLESPACE &DATA_TABLESPACE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE PWDMANAGEMENT_ATTR_VAL ADD (
  CONSTRAINT PWDMANAGEMENT_ATTR_VAL_PK
 PRIMARY KEY
 (ID)
  USING INDEX TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE PWDMANAGEMENT_ATTR_VAL ADD (
  CONSTRAINT PWDMAN_ATTR_VAL_PWDCFG_AK_FK
 FOREIGN KEY (PWDCFG_ATTR_KEY)
 REFERENCES PWDMANAGEMENT_ATTR_VAL (ID)
    ON DELETE CASCADE)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE PWDMANAGEMENT_ATTR_VAL ADD (
  CONSTRAINT PWDMAN_ATTR_VAL_PWDMAN_FK
 FOREIGN KEY (PWDMANAGEMENT)
 REFERENCES PWDMANAGEMENT (ID)
    ON DELETE CASCADE)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'CREATE INDEX PWDMAN_ATTR_VAL_PWDCFG_AK_IDX ON PWDMANAGEMENT_ATTR_VAL
(PWDCFG_ATTR_KEY)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'CREATE INDEX PWDMAN_ATTR_VAL_PWDMAN_IDX ON PWDMANAGEMENT_ATTR_VAL
(PWDMANAGEMENT)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'CREATE INDEX PWDMAN_ATTR_VAL_UNIQUE_IDX ON PWDMANAGEMENT_ATTR_VAL
(PWDMANAGEMENT, PWDCFG_ATTR_KEY, LOWER(VALUE))
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
set serveroutput off
set verify on

grant select on PWDMANAGEMENT_ATTR_VAL to AA;
grant select, insert, update, delete, references on PWDMANAGEMENT_ATTR_VAL to IDEAS;
grant select, insert, update, delete, references on PWDMANAGEMENT_ATTR_VAL to IDEAS_CONNECTOR;
grant select on PWDMANAGEMENT_ATTR_VAL to IDEAS_REPORT;


--CREATE A SEQUENCE
set verify off
set serveroutput on
declare
  curr_user         varchar2(30);
  
  seq_name          varchar2(30) := 'PWDMANAGEMENT_ATTR_VAL_SEQ';
  dml_def           varchar2(4000);
  
  counter           number(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from all_sequences t where t.sequence_owner = curr_user and t.sequence_name = seq_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'CREATE SEQUENCE PWDMANAGEMENT_ATTR_VAL_SEQ
  START WITH 100
  INCREMENT BY 1
  MINVALUE 100
  MAXVALUE 999999999999999999999999999
  NOCACHE
  NOCYCLE
  NOORDER
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
set serveroutput off
set verify on

grant select on PWDMANAGEMENT_ATTR_VAL_SEQ to AA;
grant select, alter on PWDMANAGEMENT_ATTR_VAL_SEQ to IDEAS;
grant select on PWDMANAGEMENT_ATTR_VAL_SEQ to IDEAS_CONNECTOR;
grant select on PWDMANAGEMENT_ATTR_VAL_SEQ to IDEAS_REPORT;
