create or replace function event_11_funct_add
(
  v_eventpm in eventpm%rowtype,
  v_user_erc_id in number,
  v_state in number,
  v_trace in varchar2,
  v_cod_operation in varchar2,
  v_priority in number
)
return number is
  -- **** OPERATION 1 - ADD FUNCTIONALITY **** --

  -- cursore temporaneo
  cur_tmp           sys_refcursor;

  v_operation       number(2);
  v_functionality   varchar2(256);
  v_prof_type       varchar2(256);
  v_target          varchar2(256);
  v_application     varchar2(256);
  v_tar_sync        number(1);
  v_app_sync_dis    number(1);

  v_id_profile      number(16);
  v_id_represented  number(16);
  v_counter         number(16);
  --delegato
  v_user_erc_repres number(16);

  v_pwdcfg_id       number(16);
  v_acc_user_code   varchar2(256);

  v_funct_ext_type  varchar2(256);
  v_funct_code      varchar2(256);

  counter           number(16);

  v_event_out       number(16);
  v_attr_perm       varchar2(256);
begin
  v_operation := 1;

  open cur_tmp for
    select t.profile, t.represented
      from authorizations t
     where t.id = v_eventpm.authorizations;

  fetch cur_tmp into v_id_profile, v_id_represented;
  close cur_tmp;

  open cur_tmp for
    select
      ent.name, pt.name, p.sync, a.sync_disable, t.value, a.name, p.id,
      case
        when ent.ext_type = 3 then 'PERMISSION'
        when ent.ext_type = 4 then 'EXTERNAL_ROLE'
        else 'N/A'
      end ext_type,
      case
        when ent.ext_ref is not null then ent.ext_ref
        else ent.name
      end ext_ref,
      case
        when ent.attribute_based = 1 then '1'
        else null
      end attr_based
    from
      entitlement ent, profile_type pt, application a, target t, pwdcfg p
    where ent.id = v_id_profile
      and ent.profile_type = pt.id
      and ent.application = a.id
      and a.target = t.id
      and t.pwdcfg = p.id;

    fetch cur_tmp into
      v_functionality, v_prof_type, v_tar_sync, v_app_sync_dis,
      v_target, v_application, v_pwdcfg_id, v_funct_ext_type, v_funct_code, v_attr_perm;
  close cur_tmp;

  v_acc_user_code := event_02_user_acc_code ( v_pwdcfg_id, v_eventpm.person );

  if ( v_functionality is null or v_application is null or v_tar_sync is null or v_target is null ) then
    return event_01_del_fb_auth ( v_eventpm.authorizations, v_operation );
  end if;

  -- butto via le righe che appartengono alle applicazioni non connettorizzate
   -- e quelle connettorizzate manualmente
  if ( v_tar_sync <> 1 and v_tar_sync <> 2 ) then
    return event_01_del_fb_auth ( v_eventpm.authorizations, v_operation );
  end if;

  -- la propagazione dell'applicazione e' disabilitata, ma quella del target e' abilitata
  if ( v_app_sync_dis = 1 ) then
    return 0;
  end if;

  -- valorizzo su authorizations i campi functName, e applName
  update authorizations
    set functionality          = v_functionality,
        profile_type           = v_prof_type,
        application            = v_application,
        target                 = v_target,
        account_code           = v_acc_user_code,
        functionality_ext_type = v_funct_ext_type,
        functionality_code     = v_funct_code,
        attribute_based        = cast ( v_attr_perm as number(1) )
  where id = v_eventpm.authorizations;

  -- controlliamo nuova funz.
  open cur_tmp for
    select count(1)
      from authorizations t
     where t.person = v_eventpm.person
       and t.profile = v_id_profile
       and t.id < v_eventpm.authorizations;

    fetch cur_tmp into v_counter;
  close cur_tmp;

  if ( v_counter = 0 ) then
    -- va notifica l'aggiunta di una nuova funzionalita
    update feedback
       set user_erc          = v_user_erc_id,
           application       = v_target,
           funct             = v_functionality,
           funct_type        = v_prof_type,
           funct_application = v_application
     where authorizations = v_eventpm.authorizations
       and operation = v_operation;

    --assegnazione gia avvenuta da target, non e necessario generare un event_out
    select count(1) into counter from person_profile t where t.person = v_eventpm.person and t.profile = v_id_profile and t.status = 4;
    if ( counter = 0 ) then
      select event_out_seq.nextval into v_event_out from dual;
      -- inserimento nella tabella event_out
      insert into event_out
        (id, user_erc, person, state, trace, target, cod_operation, operation,
         attr1, attr2, application, last_mod_time, last_mod_user, priority, user_id,
         attr3, attr4, attr5)
      values
        (v_event_out, v_user_erc_id, v_eventpm.person, v_state, v_trace, v_target, v_cod_operation, '1',
         v_functionality, v_prof_type, v_application, sysdate, user, v_priority, v_acc_user_code,
         v_funct_code, v_attr_perm, v_funct_ext_type);

      if ( v_user_erc_id is not null ) then
        --l'associazione person profile esiste ma non viene da target
        select count(1) into counter from person_profile t where t.person = v_eventpm.person and t.profile = v_id_profile and t.status <> 4;
        if ( counter = 0 ) then
          insert into person_profile ( id, person, profile, status, verify_date, verified_by, account_code, permission_code, permission_type, target, ext_id )
          values ( person_profile_seq.nextval, v_eventpm.person, v_id_profile, 0, sysdate, v_cod_operation, v_acc_user_code, v_funct_code, v_prof_type, v_target, v_event_out );
        else
          update person_profile set status = 0, ext_id = v_event_out where person = v_eventpm.person and profile = v_id_profile and status <> 4;
        end if;
      end if;
    elsif ( counter = 1 ) then
      update person_profile set status = 2 where person = v_eventpm.person and profile = v_id_profile and status = 4;
    end if;
  else
    delete from feedback t where t.authorizations = v_eventpm.authorizations and t.operation = v_operation;
  end if;

  -- verifico presenza delega
  if ( v_id_represented is not null ) then

    open cur_tmp for
      select p.user_erc
        from person p, user_erc ue
       where p.user_erc = ue.id
         and p.id = v_id_represented;

    fetch cur_tmp into v_user_erc_repres;
    close cur_tmp;

    if ( v_user_erc_repres is null ) then
      return 1;
    end if;

    open cur_tmp for
      select count(1)
        from authorizations t
       where t.person = v_eventpm.person
         and t.represented = v_id_represented
         and t.id < v_eventpm.authorizations;

    fetch cur_tmp into v_counter;
    close cur_tmp;

    -- inserimento nuova delega nella tabella user_event_erc
    if ( v_counter = 0 ) then
      select event_out_seq.nextval into v_event_out from dual;
      insert into event_out
        (id, user_erc, person, state, trace, target, cod_operation, operation,
         attr1, attr2, application, last_mod_time, last_mod_user, priority, user_id,
         attr3, attr4, attr5)
      values
        (v_event_out, v_user_erc_id, v_eventpm.person, v_state, v_trace, v_target, v_cod_operation, '4',
         v_functionality, v_prof_type, v_application, sysdate, user, v_priority, v_acc_user_code,
         v_funct_code, v_attr_perm, v_funct_ext_type);

      if ( v_user_erc_id is not null ) then
        select count(1) into counter from person_profile t where t.person = v_eventpm.person and t.profile = v_id_profile;
        if ( counter = 0 ) then
          insert into person_profile ( id, person, profile, status, verify_date, verified_by, account_code, permission_code, permission_type, target, ext_id  )
          values ( person_profile_seq.nextval, v_eventpm.person, v_id_profile, 0, sysdate, v_cod_operation, v_acc_user_code, v_funct_code, v_prof_type, v_target, v_event_out );
        end if;
      end if;
    end if;
    -- fine inserimento delega nella tabella user_event_erc

  end if;

  --quando si fa una aggiunta ruolo o delega a tempo viene inserito un record all'interno di feedback
  --per evitare che lo scheduler chiuda le richieste automaticamente.
  --una volta che il ruolo/delega viene aggiunto effettivamente si deve cancellare il record presente
  --in feedback ed il nome per ritrovarlo e' con lo stesso COD_OPERATION dell'evento di assegnazione
  --e il campo authorizations uguale a zero (perche' al momento dell'assegnazione post datata non e'
  --stato scritto EFFETTIVAMENTE in authorizations)
  delete from feedback t where t.authorizations = 0 and t.cod_operation = v_eventpm.cod_operation;

  return v_operation;
end event_11_funct_add;
/
