set define off
declare
  ft_id         number(16);
  ft_name       varchar2(256) := 'RUN';
  
  im_id         number(16);
  im_name       varchar2(256) := 'AGC';

  fc_id         number(16);
  fc_name       varchar2(256) := 'system';
  
  fet_root      number(16) := 0;
  fet_rule      number(16) := 1;
  fet_group     number(16) := 2;
  fet_split     number(16) := 3;
  fet_split_con number(16) := 4;
  
  fet_par_id    number(16);
  fet_par_type  number(16);
  
  fevt_id       number(16);
  fevt_name     varchar2(256) := 'TARGET';
  
  f_id          number(16);
  f_name        varchar2(256) := 'RIGHT_ADD';
  
  fer_id        number(16);
  feg_id        number(16);
  feg_name      varchar2(256) := 'Add User Right Default Group';
  
  fe_id         number(16);
  fe_pos        number(16) := 0;
  
  fr_id         number(16);
  fr_name       varchar2(256) := 'Add Right To Permission';

  counter       number(16);
begin
  select count(1) into counter from flow_type t where lower ( t.name ) = lower ( ft_name );
  if ( counter = 1 ) then
    select t.id into ft_id from flow_type t where lower ( t.name ) = lower ( ft_name );
  else
    RAISE_APPLICATION_ERROR ( -20200, 'NO FLOW TYPE FOUND' );
  end if;

  select count(1) into counter from ideas_module t where lower ( t.code ) = lower ( im_name );
  if ( counter = 1 ) then
    select t.id into im_id from ideas_module t where lower ( t.code ) = lower ( im_name );
  else
    RAISE_APPLICATION_ERROR ( -20200, 'NO IDEAS MODULE FOUND' );
  end if;

  select count(1) into counter from flow_context t where lower ( t.name ) = lower ( fc_name );
  if ( counter = 1 ) then
    select t.id into fc_id from flow_context t where lower ( t.name ) = lower ( fc_name );
  else
    RAISE_APPLICATION_ERROR ( -20200, 'NO FLOW CONTEXT FOUND' );
  end if;

  select count(1) into counter from flow_event_type t
  where t.flow_context = fc_id and t.ideas_module = im_id and lower ( t.name ) = lower ( fevt_name );
  if ( counter = 1 ) then
    select t.id into fevt_id from flow_event_type t
    where t.flow_context = fc_id and t.ideas_module = im_id and lower ( t.name ) = lower ( fevt_name );
  else
    RAISE_APPLICATION_ERROR ( -20200, 'NO FLOW EVENT TYPE FOUND' );
  end if;
  
  select count(1) into counter from flow t
  where t.ideas_module = im_id and t.flow_event_type = fevt_id and lower ( t.name ) = lower ( f_name ); 
  if ( counter = 1 ) then
    select t.id into f_id from flow t
    where t.ideas_module = im_id and t.flow_event_type = fevt_id and lower ( t.name ) = lower ( f_name ); 
  end if;

  select count(1) into counter from flow_rule t where t.flow = f_id and t.ideas_module = im_id and lower ( t.name ) = lower ( fr_name );
  if ( counter = 1 ) then
    select t.id into fr_id from flow_rule t where t.flow = f_id and t.ideas_module = im_id and lower ( t.name ) = lower ( fr_name );
  end if;

  select count(1) into counter from flow_entity t
  where t.ideas_module = im_id and t.flow = f_id and t.flow_type = ft_id and t.flow_entity_type = fet_root and t.parent is null; 
  if ( counter = 1 ) then
    select t.id into fer_id from flow_entity t
    where t.ideas_module = im_id and t.flow = f_id and t.flow_type = ft_id and t.flow_entity_type = fet_root and t.parent is null; 
  end if;

  if ( feg_name is not null and length ( trim ( feg_name )  ) > 0 ) then
    select count(1) into counter from flow_entity t
    where t.ideas_module = im_id and t.flow = f_id and flow_type = ft_id and t.flow_entity_type = fet_group and t.root = fer_id;
    if ( counter = 1 ) then
      select t.id, t.flow_type into feg_id, fet_par_type from flow_entity t
      where t.ideas_module = im_id and t.flow = f_id and flow_type = ft_id and t.flow_entity_type = fet_group and t.root = fer_id;
    end if;
  end if;
  
  if ( feg_id is null ) then
    fet_par_id   := fer_id;
  else
    fet_par_id   := feg_id;
  end if;
  fet_par_type := fet_rule;
  
  select count(1) into counter from flow_entity t
  where t.ideas_module = im_id and t.flow = f_id and flow_type = ft_id
  and t.flow_entity_type = fet_par_type and t.root = fer_id and t.flow_rule = fr_id;
  if ( counter = 1 ) then
    select t.id into fe_id from flow_entity t
    where t.ideas_module = im_id and t.flow = f_id and flow_type = ft_id
    and t.flow_entity_type = fet_par_type and t.root = fer_id and t.flow_rule = fr_id;

    if ( fe_pos = 0 ) then
      delete from flow_entity where id = fe_id;
    else
      update flow_entity set position = fe_pos where id = fe_id;
    end if;
  end if;

end;
/
commit;
set define on
