CREATE TABLE TARGET_RESOURCE_SCHEMA
(
  ID                             NUMBER(16)          NOT NULL,
  TARGET_ID                      NUMBER(16)          DEFAULT 1 NOT NULL,
  RESOURCE_TYPE                  VARCHAR2(256 CHAR)  NOT NULL,
  TARGET_NAME                    VARCHAR2(256 CHAR),
  EVENT_MARKER                   VARCHAR2(256 CHAR),
  DEFINITION                     CLOB,
  ATTR1                          VARCHAR2(256 CHAR),
  ATTR2                          VARCHAR2(256 CHAR),
  ATTR3                          VARCHAR2(256 CHAR),
  ATTR4                          VARCHAR2(256 CHAR),
  ATTR5                          VARCHAR2(256 CHAR),
  CREATION_USER                  VARCHAR2(128 CHAR),
  CREATION_DATE                  DATE                DEFAULT SYSDATE,
  LAST_MOD_USER                  VARCHAR2(128 CHAR),
  LAST_MOD_TIME                  DATE                DEFAULT SYSDATE
)
  LOB (DEFINITION) STORE AS
  (
    TABLESPACE   &LOB_TABLESPACE
    ENABLE       STORAGE IN ROW
    CHUNK        8192
    NOCACHE
    INDEX TARGET_RES_SCHEMA_DEF_IDX
    (
      TABLESPACE &LOB_TABLESPACE
    )
  )
TABLESPACE &DATA_TABLESPACE
;

ALTER TABLE TARGET_RESOURCE_SCHEMA ADD (
  CONSTRAINT TARGET_RESOURCE_SCHEMA_PK
 PRIMARY KEY
 (ID)
  USING INDEX TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS);

ALTER TABLE TARGET_RESOURCE_SCHEMA ADD (
  CONSTRAINT TARGET_RES_SCHEMA_TARGETID_FK
 FOREIGN KEY (TARGET_ID)
 REFERENCES TARGET (ID)
    ON DELETE CASCADE);

CREATE UNIQUE INDEX TARGET_RESOURCE_SCHEMA_IDX ON TARGET_RESOURCE_SCHEMA
(TARGET_ID, RESOURCE_TYPE)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS;

grant select on TARGET_RESOURCE_SCHEMA to AA;
grant select, insert, update, delete, references on TARGET_RESOURCE_SCHEMA to IDEAS;
grant select, insert, update, delete, references on TARGET_RESOURCE_SCHEMA to IDEAS_CONNECTOR;
grant select on TARGET_RESOURCE_SCHEMA to IDEAS_REPORT;


create sequence TARGET_RESOURCE_SCHEMA_SEQ
  START WITH 100
  INCREMENT BY 1
  MINVALUE 100
  MAXVALUE 999999999999999999999999999
  NOCACHE
  NOCYCLE
  NOORDER
;

grant select on TARGET_RESOURCE_SCHEMA_SEQ to AA;
grant select, alter on TARGET_RESOURCE_SCHEMA_SEQ to IDEAS;
grant select on TARGET_RESOURCE_SCHEMA_SEQ to IDEAS_CONNECTOR;
grant select on TARGET_RESOURCE_SCHEMA_SEQ to IDEAS_REPORT;
