--CREATE A TABLE AND ITS CONSTRAINTS
set verify off
set serveroutput on
declare
  curr_user         varchar2(30);
  
  tab_name          varchar2(30) := 'TARGET_RESOURCE_SCHEMA';
  dml_def           varchar2(4000);
  
  counter           number(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from all_tables t where t.owner = curr_user and t.table_name = tab_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'CREATE TABLE TARGET_RESOURCE_SCHEMA
(
  ID                             NUMBER(16)          NOT NULL,
  TARGET_ID                      NUMBER(16)          DEFAULT 1 NOT NULL,
  RESOURCE_TYPE                  VARCHAR2(256 CHAR)  NOT NULL,
  TARGET_NAME                    VARCHAR2(256 CHAR),
  EVENT_MARKER                   VARCHAR2(256 CHAR),
  DEFINITION                     CLOB,
  ATTR1                          VARCHAR2(256 CHAR),
  ATTR2                          VARCHAR2(256 CHAR),
  ATTR3                          VARCHAR2(256 CHAR),
  ATTR4                          VARCHAR2(256 CHAR),
  ATTR5                          VARCHAR2(256 CHAR),
  CREATION_USER                  VARCHAR2(128 CHAR),
  CREATION_DATE                  DATE                DEFAULT SYSDATE,
  LAST_MOD_USER                  VARCHAR2(128 CHAR),
  LAST_MOD_TIME                  DATE                DEFAULT SYSDATE
)
  LOB (DEFINITION) STORE AS
  (
    TABLESPACE   &LOB_TABLESPACE
    ENABLE       STORAGE IN ROW
    CHUNK        8192
    NOCACHE
    INDEX TARGET_RES_SCHEMA_DEF_IDX
    (
      TABLESPACE &LOB_TABLESPACE
    )
  )
TABLESPACE &DATA_TABLESPACE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE TARGET_RESOURCE_SCHEMA ADD (
  CONSTRAINT TARGET_RESOURCE_SCHEMA_PK
 PRIMARY KEY
 (ID)
  USING INDEX TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE TARGET_RESOURCE_SCHEMA ADD (
  CONSTRAINT TARGET_RES_SCHEMA_TARGETID_FK
 FOREIGN KEY (TARGET_ID)
 REFERENCES TARGET (ID)
    ON DELETE CASCADE)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'CREATE UNIQUE INDEX TARGET_RESOURCE_SCHEMA_IDX ON TARGET_RESOURCE_SCHEMA
(TARGET_ID, RESOURCE_TYPE)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
set serveroutput off
set verify on

grant select on TARGET_RESOURCE_SCHEMA to AA;
grant select, insert, update, delete, references on TARGET_RESOURCE_SCHEMA to IDEAS;
grant select, insert, update, delete, references on TARGET_RESOURCE_SCHEMA to IDEAS_CONNECTOR;
grant select on TARGET_RESOURCE_SCHEMA to IDEAS_REPORT;


--CREATE A SEQUENCE
set verify off
set serveroutput on
declare
  curr_user         varchar2(30);
  
  seq_name          varchar2(30) := 'TARGET_RESOURCE_SCHEMA_SEQ';
  dml_def           varchar2(4000);
  
  counter           number(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from all_sequences t where t.sequence_owner = curr_user and t.sequence_name = seq_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'create sequence TARGET_RESOURCE_SCHEMA_SEQ
  START WITH 100
  INCREMENT BY 1
  MINVALUE 100
  MAXVALUE 999999999999999999999999999
  NOCACHE
  NOCYCLE
  NOORDER
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
set serveroutput off
set verify on

grant select on TARGET_RESOURCE_SCHEMA_SEQ to AA;
grant select, alter on TARGET_RESOURCE_SCHEMA_SEQ to IDEAS;
grant select on TARGET_RESOURCE_SCHEMA_SEQ to IDEAS_CONNECTOR;
grant select on TARGET_RESOURCE_SCHEMA_SEQ to IDEAS_REPORT;
