--CREATE A TABLE AND ITS CONSTRAINTS
set verify off
set serveroutput on
declare
  curr_user         varchar(30);
  
  tab_name          varchar(30) := 'TARGET_RESOURCE_SCHEMA';
  dml_def           varchar(4000);
  
  counter           numeric(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from sysibm.tables t where ( t.table_type = 'BASE TABLE' or t.table_type is null ) and lower ( t.table_schema ) = lower ( curr_user ) and t.table_name = tab_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'CREATE TABLE TARGET_RESOURCE_SCHEMA
(
  ID                             NUMERIC(16)       NOT NULL,
  TARGET_ID                      NUMERIC(16)       DEFAULT 1 NOT NULL,
  RESOURCE_TYPE                  VARCHAR(256)      NOT NULL,
  TARGET_NAME                    VARCHAR(256),
  EVENT_MARKER                   VARCHAR(256),
  DEFINITION                     CLOB(2G),
  ATTR1                          VARCHAR(256),
  ATTR2                          VARCHAR(256),
  ATTR3                          VARCHAR(256),
  ATTR4                          VARCHAR(256),
  ATTR5                          VARCHAR(256),
  CREATION_USER                  VARCHAR(128),
  CREATION_DATE                  DATE                DEFAULT CURRENT_DATE,
  LAST_MOD_USER                  VARCHAR(128),
  LAST_MOD_TIME                  DATE                DEFAULT CURRENT_DATE
)
IN &DATA_TABLESPACE
INDEX IN &INDEX_TABLESPACE
LONG IN &LOB_TABLESPACE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE TARGET_RESOURCE_SCHEMA ADD
  CONSTRAINT TARGET_RESOURCE_SCHEMA_PK
 PRIMARY KEY (ID)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE TARGET_RESOURCE_SCHEMA ADD
  CONSTRAINT TARGET_RES_SCHEMA_TARGETID_FK
 FOREIGN KEY (TARGET_ID)
 REFERENCES TARGET (ID)
    ON DELETE CASCADE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'CREATE UNIQUE INDEX TARGET_RESOURCE_SCHEMA_IDX ON TARGET_RESOURCE_SCHEMA
(TARGET_ID, RESOURCE_TYPE)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
commit;
set serveroutput off
set verify on

--REORGANIZE A TABLE
set verify off
set serveroutput on
declare
  curr_user         varchar(30);
  
  tab_name          varchar(30) := 'TARGET_RESOURCE_SCHEMA';
  dml_def           varchar(4000);
  
  counter           numeric(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from sysibm.tables t where ( t.table_type = 'BASE TABLE' or t.table_type is null ) and lower ( t.table_schema ) = lower ( curr_user ) and t.table_name = tab_name;
  if ( counter = 0 ) then
    return;
  end if;

  dml_def :=
'CALL SYSPROC.ADMIN_CMD( ''REORG TABLE TARGET_RESOURCE_SCHEMA'' )
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
commit;
set serveroutput off
set verify on

grant select on TARGET_RESOURCE_SCHEMA to &AA_SUPER_ADMIN_USER;
grant select, insert, update, delete, references on TARGET_RESOURCE_SCHEMA to &IDEAS_SUPER_ADMIN_USER;
grant select, insert, update, delete, references on TARGET_RESOURCE_SCHEMA to &IDEAS_CONN_SUPER_ADMIN_USER;
grant select on TARGET_RESOURCE_SCHEMA to &IDEAS_REPORT_SUPER_ADMIN_USER;


--CREATE A SEQUENCE
set verify off
set serveroutput on
declare
  curr_user         varchar(30);
  
  seq_name          varchar(30) := 'TARGET_RESOURCE_SCHEMA_SEQ';
  dml_def           varchar(4000);
  
  counter           numeric(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from syscat.sequences t where lower ( t.seqschema ) = lower ( curr_user ) and t.seqtype <> 'I' and lower ( t.seqname ) = lower ( seq_name );
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'create sequence TARGET_RESOURCE_SCHEMA_SEQ
  AS NUMERIC(18)
  START WITH 100
  INCREMENT BY 1
  MINVALUE 100
  MAXVALUE 999999999999999999
  NO CACHE
  NO CYCLE
  NO ORDER
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
commit;
set serveroutput off
set verify on

grant usage on sequence TARGET_RESOURCE_SCHEMA_SEQ to &AA_SUPER_ADMIN_USER;
grant usage, alter on sequence TARGET_RESOURCE_SCHEMA_SEQ to &IDEAS_SUPER_ADMIN_USER;
grant usage, alter on sequence TARGET_RESOURCE_SCHEMA_SEQ to &IDEAS_CONN_SUPER_ADMIN_USER;
grant usage on sequence TARGET_RESOURCE_SCHEMA_SEQ to &IDEAS_REPORT_SUPER_ADMIN_USER;
