--CREATE A TABLE AND ITS CONSTRAINTS
set verify off
set serveroutput on
declare
  curr_user         varchar2(30);
  
  tab_name          varchar2(30) := 'TARGET_RESOURCE_SCHEMA_DEF';
  dml_def           varchar2(4000);
  
  counter           number(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from all_tables t where t.owner = curr_user and t.table_name = tab_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'CREATE TABLE TARGET_RESOURCE_SCHEMA_DEF
(
  ID              NUMBER(16)       NOT NULL,
  TR_SCHEMA_ID    NUMBER(16)       NOT NULL,
  DEFINITION      CLOB
)
  LOB (DEFINITION) STORE AS
  (
    TABLESPACE   &LOB_TABLESPACE
    ENABLE       STORAGE IN ROW
    CHUNK        8192
    NOCACHE
    INDEX TARGET_RES_SCHEMA_DEF_IDX
    (
      TABLESPACE &LOB_TABLESPACE
    )
  )
TABLESPACE &DATA_TABLESPACE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE TARGET_RESOURCE_SCHEMA_DEF ADD (
  CONSTRAINT TARGET_RESOURCE_SCHEMA_DEF_PK
 PRIMARY KEY
 (ID)
  USING INDEX TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE TARGET_RESOURCE_SCHEMA_DEF ADD
  CONSTRAINT TARGET_RES_SCHEMA_DEF_TRSID_FK
 FOREIGN KEY (TR_SCHEMA_ID)
 REFERENCES TARGET_RESOURCE_SCHEMA_DEF (ID)
    ON DELETE CASCADE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
set serveroutput off
set verify on

COMMENT ON COLUMN TARGET_RESOURCE_SCHEMA_DEF.DEFINITION IS
'DB2_CLOB_SIZE: 2G';

grant select on TARGET_RESOURCE_SCHEMA_DEF to AA;
grant select, insert, update, delete, references on TARGET_RESOURCE_SCHEMA_DEF to IDEAS;
grant select, insert, update, delete, references on TARGET_RESOURCE_SCHEMA_DEF to IDEAS_CONNECTOR;
grant select on TARGET_RESOURCE_SCHEMA_DEF to IDEAS_REPORT;


--CREATE A SEQUENCE
set verify off
set serveroutput on
declare
  curr_user         varchar2(30);
  
  seq_name          varchar2(30) := 'TARGET_RESOURCE_SCHEMA_DEF_SEQ';
  dml_def           varchar2(4000);
  
  counter           number(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from all_sequences t where t.sequence_owner = curr_user and t.sequence_name = seq_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'create sequence TARGET_RESOURCE_SCHEMA_DEF_SEQ
  START WITH 100
  INCREMENT BY 1
  MINVALUE 100
  MAXVALUE 999999999999999999999999999
  NOCACHE
  NOCYCLE
  NOORDER
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
set serveroutput off
set verify on

grant select on TARGET_RESOURCE_SCHEMA_DEF_SEQ to AA;
grant select, alter on TARGET_RESOURCE_SCHEMA_DEF_SEQ to IDEAS;
grant select on TARGET_RESOURCE_SCHEMA_DEF_SEQ to IDEAS_CONNECTOR;
grant select on TARGET_RESOURCE_SCHEMA_DEF_SEQ to IDEAS_REPORT;
