--CREATE A TABLE AND ITS CONSTRAINTS
set verify off
set serveroutput on
declare
  curr_user         varchar(30);
  
  tab_name          varchar(30) := 'TARGET_RESOURCE_SCHEMA_DEF';
  dml_def           varchar(4000);
  
  counter           numeric(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from sysibm.tables t where ( t.table_type = 'BASE TABLE' or t.table_type is null ) and lower ( t.table_schema ) = lower ( curr_user ) and t.table_name = tab_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'CREATE TABLE TARGET_RESOURCE_SCHEMA_DEF
(
  ID              NUMERIC(16)       NOT NULL,
  TR_SCHEMA_ID    NUMERIC(16)       NOT NULL,
  DEFINITION      CLOB(2G)
)
IN &DATA_TABLESPACE
INDEX IN &INDEX_TABLESPACE
LONG IN &LOB_TABLESPACE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE TARGET_RESOURCE_SCHEMA_DEF ADD
  CONSTRAINT TARGET_RESOURCE_SCHEMA_DEF_PK
 PRIMARY KEY (ID)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE TARGET_RESOURCE_SCHEMA_DEF ADD
  CONSTRAINT TARGET_RES_SCHEMA_DEF_TRSID_FK
 FOREIGN KEY (TR_SCHEMA_ID)
 REFERENCES TARGET_RESOURCE_SCHEMA_DEF (ID)
    ON DELETE CASCADE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
commit;
set serveroutput off
set verify on

COMMENT ON COLUMN TARGET_RESOURCE_SCHEMA_DEF.DEFINITION IS
'DB2_CLOB_SIZE: 2G';


--REORGANIZE A TABLE
set verify off
set serveroutput on
declare
  curr_user         varchar(30);
  
  tab_name          varchar(30) := 'TARGET_RESOURCE_SCHEMA_DEF';
  dml_def           varchar(4000);
  
  counter           numeric(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from sysibm.tables t where ( t.table_type = 'BASE TABLE' or t.table_type is null ) and lower ( t.table_schema ) = lower ( curr_user ) and t.table_name = tab_name;
  if ( counter = 0 ) then
    return;
  end if;

  dml_def :=
'CALL SYSPROC.ADMIN_CMD( ''REORG TABLE TARGET_RESOURCE_SCHEMA_DEF'' )
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
commit;
set serveroutput off
set verify on

grant select on TARGET_RESOURCE_SCHEMA_DEF to &AA_SUPER_ADMIN_USER;
grant select, insert, update, delete, references on TARGET_RESOURCE_SCHEMA_DEF to &IDEAS_SUPER_ADMIN_USER;
grant select, insert, update, delete, references on TARGET_RESOURCE_SCHEMA_DEF to &IDEAS_CONN_SUPER_ADMIN_USER;
grant select on TARGET_RESOURCE_SCHEMA_DEF to &IDEAS_REPORT_SUPER_ADMIN_USER;


--CREATE A SEQUENCE
set verify off
set serveroutput on
declare
  curr_user         varchar(30);
  
  seq_name          varchar(30) := 'TARGET_RESOURCE_SCHEMA_DEF_SEQ';
  dml_def           varchar(4000);
  
  counter           numeric(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from syscat.sequences t where lower ( t.seqschema ) = lower ( curr_user ) and t.seqtype <> 'I' and lower ( t.seqname ) = lower ( seq_name );
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'CREATE SEQUENCE TARGET_RESOURCE_SCHEMA_DEF_SEQ
  AS NUMERIC(18)
  START WITH 100
  INCREMENT BY 1
  MINVALUE 100
  MAXVALUE 999999999999999999
  NO CACHE
  NO CYCLE
  NO ORDER
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
commit;
set serveroutput off
set verify on

grant usage on sequence TARGET_RESOURCE_SCHEMA_DEF_SEQ to &AA_SUPER_ADMIN_USER;
grant usage, alter on sequence TARGET_RESOURCE_SCHEMA_DEF_SEQ to &IDEAS_SUPER_ADMIN_USER;
grant usage, alter on sequence TARGET_RESOURCE_SCHEMA_DEF_SEQ to &IDEAS_CONN_SUPER_ADMIN_USER;
grant usage on sequence TARGET_RESOURCE_SCHEMA_DEF_SEQ to &IDEAS_REPORT_SUPER_ADMIN_USER;
