CREATE TABLE PERSON_PROFILE_SERVICE
(
  ID                             NUMERIC(16)         NOT NULL,
  PERSON_PROFILE                 NUMERIC(16),
  SERVICE_ATTRIBUTE              NUMERIC(16),
  NAME                           VARCHAR(256),
  VALUE                          VARCHAR(256),
  TARGET                         VARCHAR(256),
  STATUS                         NUMERIC(16)         DEFAULT 0 NOT NULL,
  VERIFY_DATE                    DATE,
  VERIFIED_BY                    VARCHAR(256),
  EXT_ID                         NUMERIC(16),
  ATTR1                          VARCHAR(256),
  ATTR2                          VARCHAR(256),
  ATTR3                          VARCHAR(256),
  ATTR4                          VARCHAR(256),
  ATTR5                          VARCHAR(256),
  CREATION_USER                  VARCHAR(128),
  CREATION_DATE                  DATE                DEFAULT CURRENT_DATE,
  LAST_MOD_USER                  VARCHAR(128),
  LAST_MOD_TIME                  DATE                DEFAULT CURRENT_DATE
)
IN &DATA_TABLESPACE
INDEX IN &INDEX_TABLESPACE
LONG IN &LOB_TABLESPACE
;

ALTER TABLE PERSON_PROFILE_SERVICE ADD
  CONSTRAINT PERSON_PROFILE_SERVICE_PK
 PRIMARY KEY (ID);

ALTER TABLE PERSON_PROFILE_SERVICE ADD
  CONSTRAINT PER_PRO_SERV_PP_FK
 FOREIGN KEY (PERSON_PROFILE)
 REFERENCES PERSON_PROFILE (ID)
    ON DELETE CASCADE;

ALTER TABLE PERSON_PROFILE_SERVICE ADD
  CONSTRAINT PER_PRO_SERV_SA_FK
 FOREIGN KEY (SERVICE_ATTRIBUTE)
 REFERENCES SERVICE_ATTRIBUTE (ID)
    ON DELETE CASCADE;

CREATE UNIQUE INDEX PER_PRO_SERV_EXT_ID_IDX ON PERSON_PROFILE_SERVICE
(EXT_ID);

CREATE INDEX PER_PRO_SERV_PP_SA_IDX ON PERSON_PROFILE_SERVICE
(PERSON_PROFILE, SERVICE_ATTRIBUTE);

CREATE INDEX PER_PRO_SERV_SA_PP_IDX ON PERSON_PROFILE_SERVICE
(SERVICE_ATTRIBUTE, PERSON_PROFILE);

CALL SYSPROC.ADMIN_CMD ( 'REORG TABLE PERSON_PROFILE_SERVICE' );

grant select on PERSON_PROFILE_SERVICE to &AA_SUPER_ADMIN_USER;
grant select, insert, update, delete, references on PERSON_PROFILE_SERVICE to &IDEAS_SUPER_ADMIN_USER;
grant select, insert, update, delete, references on PERSON_PROFILE_SERVICE to &IDEAS_CONN_SUPER_ADMIN_USER;
grant select on PERSON_PROFILE_SERVICE to &IDEAS_REPORT_SUPER_ADMIN_USER;


CREATE SEQUENCE PERSON_PROFILE_SERVICE_SEQ
  AS NUMERIC(18)
  START WITH 100
  INCREMENT BY 1
  MINVALUE 100
  MAXVALUE 999999999999999999
  NO CACHE
  NO CYCLE
  NO ORDER;

grant usage on sequence PERSON_PROFILE_SERVICE_SEQ to &AA_SUPER_ADMIN_USER;
grant usage, alter on sequence PERSON_PROFILE_SERVICE_SEQ to &IDEAS_SUPER_ADMIN_USER;
grant usage, alter on sequence PERSON_PROFILE_SERVICE_SEQ to &IDEAS_CONN_SUPER_ADMIN_USER;
grant usage on sequence PERSON_PROFILE_SERVICE_SEQ to &IDEAS_REPORT_SUPER_ADMIN_USER;
