--CREATE A TABLE AND ITS CONSTRAINTS
set verify off
set serveroutput on
declare
  curr_user         varchar2(30);
  
  tab_name          varchar2(30) := 'PERSON_PROFILE_SERVICE';
  dml_def           varchar2(4000);
  
  counter           number(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from all_tables t where t.owner = curr_user and t.table_name = tab_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'create table PERSON_PROFILE_SERVICE
(
  ID                NUMBER(16) not null,
  PERSON_PROFILE    NUMBER(16),
  SERVICE_ATTRIBUTE NUMBER(16),
  NAME              VARCHAR2(256 CHAR),
  VALUE             VARCHAR2(256 CHAR),
  TARGET            VARCHAR2(256 CHAR),
  STATUS            NUMBER(16) default 0 not null,
  VERIFY_DATE       DATE,
  VERIFIED_BY       VARCHAR2(256 CHAR),
  EXT_ID            NUMBER(16),
  ATTR1             VARCHAR2(256 CHAR),
  ATTR2             VARCHAR2(256 CHAR),
  ATTR3             VARCHAR2(256 CHAR),
  ATTR4             VARCHAR2(256 CHAR),
  ATTR5             VARCHAR2(256 CHAR),
  CREATION_USER     VARCHAR2(128 CHAR),
  CREATION_DATE     DATE default SYSDATE,
  LAST_MOD_USER     VARCHAR2(128 CHAR),
  LAST_MOD_TIME     DATE default SYSDATE
)
tablespace &DATA_TABLESPACE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'alter table PERSON_PROFILE_SERVICE
  add constraint PERSON_PROFILE_SERVICE_PK primary key (ID)
  using index 
  tablespace &INDEX_TABLESPACE compute statistics
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'alter table PERSON_PROFILE_SERVICE
  add constraint PER_PRO_SERV_PP_FK foreign key (PERSON_PROFILE)
  references PERSON_PROFILE (ID) on delete cascade
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'alter table PERSON_PROFILE_SERVICE
  add constraint PER_PRO_SERV_SA_FK foreign key (SERVICE_ATTRIBUTE)
  references SERVICE_ATTRIBUTE (ID) on delete cascade
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'create unique index PER_PRO_SERV_EXT_ID_IDX on PERSON_PROFILE_SERVICE (EXT_ID)
  tablespace &INDEX_TABLESPACE compute statistics
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'create index PER_PRO_SERV_PP_SA_IDX on PERSON_PROFILE_SERVICE (PERSON_PROFILE, SERVICE_ATTRIBUTE)
  tablespace &INDEX_TABLESPACE compute statistics
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'create index PER_PRO_SERV_SA_PP_IDX on PERSON_PROFILE_SERVICE (SERVICE_ATTRIBUTE, PERSON_PROFILE)
  tablespace &INDEX_TABLESPACE compute statistics
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
set serveroutput off
set verify on

grant select on PERSON_PROFILE_SERVICE to AA;
grant select, insert, update, delete, references on PERSON_PROFILE_SERVICE to IDEAS;
grant select, insert, update, delete, references on PERSON_PROFILE_SERVICE to IDEAS_CONNECTOR;
grant select on PERSON_PROFILE_SERVICE to IDEAS_REPORT;


--CREATE A SEQUENCE
set verify off
set serveroutput on
declare
  curr_user         varchar2(30);
  
  seq_name          varchar2(30) := 'PERSON_PROFILE_SERVICE_SEQ';
  dml_def           varchar2(4000);
  
  counter           number(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from all_sequences t where t.sequence_owner = curr_user and t.sequence_name = seq_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'create sequence PERSON_PROFILE_SERVICE_SEQ
  START WITH 100
  INCREMENT BY 1
  MINVALUE 100
  MAXVALUE 999999999999999999999999999
  NOCACHE
  NOCYCLE
  NOORDER
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
set serveroutput off
set verify on

grant select on PERSON_PROFILE_SERVICE_SEQ to AA;
grant select, alter on PERSON_PROFILE_SERVICE_SEQ to IDEAS;
grant select on PERSON_PROFILE_SERVICE_SEQ to IDEAS_CONNECTOR;
grant select on PERSON_PROFILE_SERVICE_SEQ to IDEAS_REPORT;
