CREATE OR REPLACE TRIGGER TRG_EV_TAR_TO_PER_PRO_SERV
  AFTER INSERT ON EVENT_TARGET
  FOR EACH ROW
declare
  counter              numeric(16);

  pro_name             varchar(256);
  per_prof_id          numeric(16);
  per_prof_serv_id     numeric(16);
  per_prof_serv_status numeric(16);
begin
  if ( :new.operation not in ( 12, 13 ) ) then
    return;
  end if;

  if ( :new.attr3 is not null ) then
    pro_name := :new.attr3;
  else
    pro_name := :new.functionality;
  end if;

  select count(1) into counter from person_profile t
  where lower ( t.account_code ) = lower ( :new.code ) and lower ( t.permission_code ) = lower ( pro_name )
  and lower ( t.permission_type ) = lower ( :new.functionality_type ) and lower ( t.target ) = lower ( :new.target );

  if ( counter = 0 and :new.operation = 12 ) then
    select person_profile_seq.nextval into per_prof_id from dual;
    insert into person_profile ( id, status, account_code, permission_code, permission_type, target )
    values ( per_prof_id, 4, :new.code, pro_name, :new.functionality_type, :new.target );
  elsif ( counter = 0 and :new.operation = 13 ) then
    return;
  end if;

  if ( counter = 1 ) then
    select t.id into per_prof_id from person_profile t
    where lower ( t.account_code ) = lower ( :new.code ) and lower ( t.permission_code ) = lower ( pro_name )
    and lower ( t.permission_type ) = lower ( :new.functionality_type ) and lower ( t.target ) = lower ( :new.target );
  elsif ( counter > 1 ) then
    return;
  end if;

  select count(1) into counter from person_profile_service t
  where t.person_profile = per_prof_id and lower ( t.name ) = lower ( :new.attr5 ) and lower ( t.value ) = lower ( :new.attr6 )
  and lower ( t.target ) = lower ( :new.target );
  if ( counter = 1 ) then
    select t.id, t.status into per_prof_serv_id, per_prof_serv_status from person_profile_service t
    where t.person_profile = per_prof_id and lower ( t.name ) = lower ( :new.attr5 ) and lower ( t.value ) = lower ( :new.attr6 )
    and lower ( t.target ) = lower ( :new.target );
  elsif ( counter > 1 ) then
    return;
  end if;

  --12) aggiunta right a utente
  if ( :new.operation in ( 12 ) ) then
    if ( counter = 0 ) then
      insert into person_profile_service ( id, person_profile, status, name, value, target )
      values ( person_profile_service_seq.nextval, per_prof_id, 4, :new.attr5, :new.attr6, :new.target );
    elsif ( counter = 1 ) then
      --person profile_service presente su IGI e aggiunto anche in maniera indipendente sul target
      if ( per_prof_serv_status in ( 1, 2, 3 ) ) then
        update person_profile set status = 2, ext_id = null where id = per_prof_id;
      --person_profile_service non presente su IGI (perche' rimosso) ma aggiunto sul target
      elsif ( per_prof_serv_status in ( 11, 12, 13 ) ) then
        update person_profile set status = 4, ext_id = null where id = per_prof_id;
      end if;
    end if;
  end if;

  --13) rimozione right da utente
  if ( :new.operation = 13 ) then
    if ( counter = 1 ) then
      --non si cancella l'entry solo nel caso in cui sia richiesta un'assegnazione sul target (status=1)
      --poiche' il motore di regole potrebbe notificare l'assegnazione al target, ma non ci sarebbe poi
      --l'entry su person_profile_service
      if ( per_prof_serv_status in ( 2, 3, 11, 12, 13 ) ) then
        delete from person_profile_service where id = per_prof_serv_id;
      end if;
    end if;
  end if;

end TRG_EV_TAR_TO_PER_PRO_SERV;
/
