set define off
declare
  ft_id         numeric(16);
  ft_name       varchar(256) := 'RUN';
  
  im_id         numeric(16);
  im_name       varchar(256) := 'AGC';

  fc_id         numeric(16);
  fc_name       varchar(256) := 'system';
  
  fet_root      numeric(16) := 0;
  fet_rule      numeric(16) := 1;
  fet_group     numeric(16) := 2;
  fet_split     numeric(16) := 3;
  fet_split_con numeric(16) := 4;
  
  fet_par_id    numeric(16);
  fet_par_type  numeric(16);
  
  fevt_id       numeric(16);
  fevt_name     varchar(256) := 'IN';
  
  f_id          numeric(16);
  f_name        varchar(256) := 'USER_MOVE';
  
  fer_id        numeric(16);
  feg_id        numeric(16);
  feg_name      varchar(256) := 'Move User Default Group';
  
  fe_id         numeric(16);
  fe_pos_old    numeric(16);
  --specifica la posizione della regola nel gruppo, -1 se non si deve aggiungere
  fe_pos        numeric(16) := -1;
  
  fr_id         numeric(16);
  fr_name       varchar(256) := 'Move User (if null skip event)';
  fr_desc       varchar(512) := '[ V1.0 - 2016-09-30 ] - Move the user to a new OU. 
'||'If new OU is null, event is skipped';
  
  fr_lob        clob := 'rule "Move User (if null skip event)"
'||'when
'||'    userBean : UserBean(  )  
'||'    orgUnitBean : OrgUnitBean(  )  
'||'then
'||'if (orgUnitBean.getCode() == null || orgUnitBean.getCode().equals("")) {
'||'    // if null we skip events
'||'    return;
'||'  }
'||'
'||'  // Check if the new OU is actually different
'||'  if (userBean.getOrganizationalunit_code() == null ||
'||'(!userBean.getOrganizationalunit_code().equalsIgnoreCase(orgUnitBean.getCode()))) {
'||'
'||'    // Make sure all the user entitlements will be available on the new OU
'||'    BeanList entitlements = UserAction.findJobRoles(sql, userBean);
'||'
'||'    OrgUnitAction.addRoles(sql, orgUnitBean, entitlements, false);
'||'
'||'    // Move the user assigning the default entitlements of the new OU
'||'    UtilAction.moveUser(sql, userBean, orgUnitBean);
'||'
'||'    logger.debug("User " + userBean.getCode() + " moved to " + orgUnitBean.getCode());
'||'  } 
'||'
'||'end
'||'';

  counter       numeric(16);
begin
  select count(1) into counter from flow_type t where lower ( t.name ) = lower ( ft_name );
  if ( counter = 1 ) then
    select t.id into ft_id from flow_type t where lower ( t.name ) = lower ( ft_name );
  else
    RAISE_APPLICATION_ERROR ( -20200, 'NO FLOW TYPE FOUND' );
  end if;

  select count(1) into counter from ideas_module t where lower ( t.code ) = lower ( im_name );
  if ( counter = 1 ) then
    select t.id into im_id from ideas_module t where lower ( t.code ) = lower ( im_name );
  else
    RAISE_APPLICATION_ERROR ( -20200, 'NO IDEAS MODULE FOUND' );
  end if;

  select count(1) into counter from flow_context t where lower ( t.name ) = lower ( fc_name );
  if ( counter = 1 ) then
    select t.id into fc_id from flow_context t where lower ( t.name ) = lower ( fc_name );
  else
    RAISE_APPLICATION_ERROR ( -20200, 'NO FLOW CONTEXT FOUND' );
  end if;

  select count(1) into counter from flow_event_type t
  where t.flow_context = fc_id and t.ideas_module = im_id and lower ( t.name ) = lower ( fevt_name );
  if ( counter = 1 ) then
    select t.id into fevt_id from flow_event_type t
    where t.flow_context = fc_id and t.ideas_module = im_id and lower ( t.name ) = lower ( fevt_name );
  else
    RAISE_APPLICATION_ERROR ( -20200, 'NO FLOW EVENT TYPE FOUND' );
  end if;
  
  select count(1) into counter from flow t
  where t.ideas_module = im_id and t.flow_event_type = fevt_id and lower ( t.name ) = lower ( f_name ); 
  if ( counter = 1 ) then
    select t.id into f_id from flow t
    where t.ideas_module = im_id and t.flow_event_type = fevt_id and lower ( t.name ) = lower ( f_name ); 
  else
    RAISE_APPLICATION_ERROR ( -20200, 'NO FLOW FOUND' );
  end if;

  select count(1) into counter from flow_rule t where t.flow = f_id and t.ideas_module = im_id and lower ( t.name ) = lower ( fr_name );
  if ( counter = 0 ) then
    select flow_rule_seq.nextval into fr_id from dual;
    insert into flow_rule ( id, flow, name, description, rule_lob, ideas_module )
    values ( fr_id, f_id, fr_name, fr_desc, fr_lob, im_id );
  else
    select t.id into fr_id from flow_rule t where t.flow = f_id and t.ideas_module = im_id and lower ( t.name ) = lower ( fr_name );

    update flow_rule set description = fr_desc where id = fr_id;

    update flow_rule set rule_lob = fr_lob where id = fr_id;
  end if;

  if ( fe_pos = -1 ) then
    return;
  end if;

  select count(1) into counter from flow_entity t
  where t.ideas_module = im_id and t.flow = f_id and t.flow_type = ft_id and t.flow_entity_type = fet_root and t.parent is null; 
  if ( counter = 1 ) then
    select t.id into fer_id from flow_entity t
    where t.ideas_module = im_id and t.flow = f_id and t.flow_type = ft_id and t.flow_entity_type = fet_root and t.parent is null; 
  end if;

  if ( feg_name is not null and length ( trim ( feg_name )  ) > 0 ) then
    select count(1) into counter from flow_entity t
    where t.ideas_module = im_id and t.flow = f_id and flow_type = ft_id and t.flow_entity_type = fet_group and t.root = fer_id;
    if ( counter = 0 ) then
      select flow_entity_seq.nextval into feg_id from dual;
      
      insert into flow_entity ( id, flow, flow_type, root, parent, flow_entity_type, name, position, ideas_module)
      values ( feg_id, f_id, ft_id, fer_id, fer_id, fet_group, feg_name, 0, im_id );
    else
      select t.id, t.flow_type into feg_id, fet_par_type from flow_entity t
      where t.ideas_module = im_id and t.flow = f_id and flow_type = ft_id and t.flow_entity_type = fet_group and t.root = fer_id;
    end if;
  end if;
  
  if ( feg_id is null ) then
    fet_par_id   := fer_id;
  else
    fet_par_id   := feg_id;
  end if;
  fet_par_type := fet_rule;
  
  select count(1) into counter from flow_entity t
  where t.ideas_module = im_id and t.flow = f_id and flow_type = ft_id
  and t.flow_entity_type = fet_par_type and t.root = fer_id and t.flow_rule = fr_id;
  if ( counter = 0 ) then
    select flow_entity_seq.nextval into fe_id from dual;
  else
    select t.id, t.position into fe_id, fe_pos_old from flow_entity t
    where t.ideas_module = im_id and t.flow = f_id and flow_type = ft_id
    and t.flow_entity_type = fet_par_type and t.root = fer_id and t.flow_rule = fr_id;
  end if;
  
  if ( fe_pos is null and fe_pos_old is null ) then
    select max ( t.position ) into fe_pos from flow_entity t
    where t.ideas_module = im_id and t.flow = f_id and flow_type = ft_id
    and t.flow_entity_type = fet_rule and t.root = fer_id;

    if ( fe_pos is null ) then
      fe_pos := 0;
    else
      fe_pos := fe_pos + 1;
    end if;
  elsif ( fe_pos is null and fe_pos_old is not null ) then
    fe_pos := fe_pos_old;
  elsif ( fe_pos is not null and fe_pos_old is not null and fe_pos <> fe_pos_old  ) then
    --modificare le posizioni del corrente e dei successivi
    update flow_entity set position = ( position + 1 ) where ideas_module = im_id and flow = f_id and flow_type = ft_id
    and flow_entity_type = fet_rule and root = fer_id and position >= fe_pos;
  end if;

  if ( counter = 0 ) then
    insert into flow_entity ( id, flow, flow_type, root, parent, flow_entity_type, flow_rule, position, ideas_module)
    values ( fe_id, f_id, ft_id, fer_id, fet_par_id, fet_rule, fr_id, fe_pos, im_id );
  else
    update flow_entity set position = fe_pos where id = fe_id;
  end if;

end;
/
commit;
set define on
