create or replace function event_11_serv_add_rem
(
  v_eventpm in eventpm%rowtype,
  v_user_erc_id in number,
  v_state in number,
  v_trace in varchar2,
  v_cod_operation in varchar2,
  v_priority in number
)
return number is
  -- cursore temporaneo
  cur_tmp          sys_refcursor;
  cur_appl         sys_refcursor;
  cur_service      sys_refcursor;

  v_counter        number(16);
  v_id_profile     number(16);
  v_prof_type      varchar2(256);

  v_appl_name      varchar2(256);
  v_tar_sync       number(1);
  v_app_sync_dis   number(1);
  v_target         varchar2(256);

  v_pwdcfg_id      number(16);
  v_acc_user_code  varchar2(256);

  v_funct_ext_type varchar2(256);
  v_funct_code     varchar2(256);
  v_attr_perm      varchar2(256);

  v_ins_event_out  number(1) := 0;
  v_per_prof_id    number(16);
  v_sa_id          number(16);
  v_event_out      number(16);

  counter          number(16);
begin

  if (v_eventpm.attr2 is null) then
    return 99;
  end if;

  open cur_tmp for select count(id) from person p where p.id = v_eventpm.person;
  fetch cur_tmp into v_counter;
  close cur_tmp;

  if ( v_counter <= 0 ) then
    -- user not found
    return 99;
  end if;

  open cur_tmp for select count(id) from service_attribute sa where sa.profile = v_eventpm.entity;
  fetch cur_tmp into v_counter;
  close cur_tmp;

  if ( v_counter <= 0 ) then
    return 99;
  end if;

  open cur_service for
    select sa.id, sa.profile, sa.pwdcfg
      from service_attribute sa
     where sa.profile = v_eventpm.entity
     and sa.name = v_eventpm.attr1;

  loop
    -- ciclo sulle applicazioni, profili, ruoli assegnati al servizio
    fetch cur_service into v_sa_id, v_id_profile, v_pwdcfg_id;
    exit when cur_service%NOTFOUND;

    if ( v_id_profile is not null ) then
      open cur_appl for
        select a.name, pt.name, p.sync, a.sync_disable, t.value, p.id,
            case
              when e.ext_type = 3 then 'PERMISSION'
              when e.ext_type = 4 then 'EXTERNAL_ROLE'
              else 'N/A'
            end ext_type,
            case
              when e.ext_ref is not null then e.ext_ref
              else e.name
            end ext_ref,
            case
              when e.attribute_based = 1 then '1'
              else ''
            end attr_based
          from application a, target t, pwdcfg p, entitlement e, profile_type pt
         where a.id = e.application
           and a.target = t.id
           and t.pwdcfg = p.id
           and e.profile_type = pt.id
           and pt.application = a.id
           and e.id = v_id_profile;

    elsif ( v_pwdcfg_id is not null ) then
      open cur_appl for
        select distinct null, null, p.sync, null, t.value, p.id, null
          from target t, pwdcfg p
         where t.pwdcfg = p.id
           and t.pwdcfg = v_pwdcfg_id;

    else
      return 99;
    end if;

    loop
      fetch cur_appl into
        v_appl_name, v_prof_type, v_tar_sync, v_app_sync_dis,
        v_target, v_pwdcfg_id, v_funct_ext_type, v_funct_code, v_attr_perm;
      exit when cur_appl%NOTFOUND;

      v_acc_user_code := event_02_user_acc_code ( v_pwdcfg_id, v_eventpm.person );

      if ( v_id_profile is not null and v_acc_user_code is not null) then
        select count(1) into counter from person_profile t
        where t.person = v_eventpm.person and t.profile = v_id_profile;
        if ( counter = 0 ) then
          select person_profile_seq.nextval into v_per_prof_id from dual;
          insert into person_profile ( id, person, profile, status, verify_date, verified_by, account_code, permission_code, permission_type, target, ext_id )
          values (  v_per_prof_id, v_eventpm.person, v_id_profile, 0, sysdate, v_cod_operation, v_acc_user_code, v_funct_code, v_prof_type, v_target, v_event_out );
        else
          select t.id into v_per_prof_id from person_profile t
          where t.person = v_eventpm.person and t.profile = v_id_profile;
        end if;

        --assegnazione gia avvenuta da target, non e necessario generare un event_out
        select count(1) into counter from person_profile_service t
        where t.person_profile = v_per_prof_id and t.service_attribute = v_sa_id
        and lower ( t.value ) = lower ( v_eventpm.attr2 ) and t.status = 4;
        if ( counter = 0 ) then
          v_ins_event_out := 1;
          --l'associazione person profile_service esiste ma non viene da target
          select count(1) into counter from person_profile_service t
          where t.person_profile = v_per_prof_id and t.service_attribute = v_sa_id
          and lower ( t.value ) = lower ( v_eventpm.attr2 ) and t.status <> 4;
          if ( counter = 0 ) then
            insert into person_profile_service ( id, person_profile, service_attribute, status, verify_date, verified_by, target )
            values ( person_profile_service_seq.nextval, v_per_prof_id, v_sa_id, 0, sysdate, v_cod_operation, v_target );
          else
            update person_profile_service set status = 0 where person_profile = v_per_prof_id and service_attribute = v_sa_id and status <> 4;
          end if;
        elsif ( counter = 1 ) then
          v_ins_event_out := 2;
          update person_profile_service set status = 2 where person_profile = v_per_prof_id and service_attribute = v_sa_id and status = 4;
        end if;
      end if;

      if ( v_app_sync_dis = 1 ) then
        return 0;
      end if;

      if ( v_tar_sync <> 0 and v_acc_user_code is not null) then
        select event_out_seq.nextval into v_event_out from dual;

        insert into event_out
          (id,
           person,
           user_erc,
           target,
           cod_operation,
           operation,
           attr1 /*key service*/,
           attr2 /*value service*/,
           attr3 /*entitlement ext ref*/,
           attr4 /*attribute permission*/,
           attr5 /*entitlement ext type*/,
           application,
           state,
           date_process,
           date_event,
           last_mod_time,
           last_mod_user,
           priority,
           user_id)
        values
          (v_event_out,
           v_eventpm.person,
           v_user_erc_id,
           v_target,
           v_cod_operation,
           v_eventpm.operation,
           v_eventpm.attr1,
           v_eventpm.attr2,
           v_funct_code,
           v_attr_perm,
           v_funct_ext_type,
           v_appl_name,
           v_state,
           sysdate,
           sysdate,
           sysdate,
           user,
           v_priority,
           v_acc_user_code);

         if ( v_ins_event_out = 1 ) then
            update person_profile_service set ext_id = v_event_out where person_profile = v_per_prof_id and service_attribute = v_sa_id;
         end if;
      end if;
    end loop;
    close cur_appl;
  end loop;

  close cur_service;

  return v_eventpm.operation;

end event_11_serv_add_rem;
/
