set define off
declare
  im_id         number(16);
  im_name       varchar2(256) := 'AGC';

  fc_id         number(16);
  fc_name       varchar2(256) := 'system';
  
  fevt_id       number(16);
  fevt_name     varchar2(256) := 'TARGET';
  
  f_id          number(16);
  f_name        varchar2(256) := 'BEFORE';
  
  f_lob         clob := 'package tBEFORE3
'||'
'||'import com.engiweb.logger.impl.Log4JImpl;
'||'import com.engiweb.pm.entity.BeanList;
'||'import com.engiweb.profilemanager.backend.dao.db.SQLH;
'||'import com.engiweb.profilemanager.common.bean.AccountBean;
'||'import com.engiweb.profilemanager.common.bean.Block;
'||'import com.engiweb.profilemanager.common.bean.OrgUnitBean;
'||'import com.engiweb.profilemanager.common.bean.UserBean;
'||'import com.engiweb.profilemanager.common.bean.entitlement.EntitlementBean;
'||'import com.engiweb.profilemanager.common.bean.event.EntStateBean;
'||'import com.engiweb.profilemanager.common.bean.event.EventTargetBean;
'||'import com.engiweb.profilemanager.common.bean.rule.SyncStateBean;
'||'import com.engiweb.profilemanager.common.ruleengine.action.EntitlementAction;
'||'import com.engiweb.profilemanager.common.ruleengine.action.OrgUnitAction;
'||'import com.engiweb.profilemanager.common.ruleengine.action.UserAction;
'||'import com.engiweb.toolkit.common.DBMSException;
'||'import java.util.HashMap
'||'import java.util.Map
'||'
'||'global com.engiweb.profilemanager.backend.dao.db.SQLH sql;
'||'global com.engiweb.logger.impl.Log4JImpl logger;
'||'
'||'
'||'
';
  
  fr_id         number(16);
  fr_name       varchar2(256) := 'SAP CUA Reconciliation';
  fr_desc       varchar2(512) := '[V1.0 - 2016-11-02] - Handles events generated by a target SAP CUA'; 
  
  fr_lob        clob := 'rule "SAP CUA Reconciliation"
'||'when
'||'    event : EventTargetBean(  )  
'||'then
'||'// SAP CUA Marker.
'||'// Insert The ILC Service
'||'String sapCUAMarker = "ILC_7149450082213092256"; // Put here the SAP CUA marker.
'||'
'||'// Checks if the target can be elaborated.
'||'if (!event.getTarget().equals(sapCUAMarker))
'||'{
'||'	return;
'||'}
'||'
'||'// This map contains as key the "SAP Logical System" and as value the "IGI Marker".
'||'Map<String, String> map = new HashMap<>(); // Map<prefix, target>
'||'
'||'// Fill the map here.
'||'// SAP CUA Server Logical System 
'||'// Example
'||'//map.put("RM1CLNT200: ", "RM1-200 IT"); (Logical system sap with: and space) + (Application AGC)
'||'map.put("RM1CLNT200: ", "RM1-200 IT");
'||'
'||'// SAP CUA Client.
'||'//map.put("RM1CLNT220: ", "RM1-220 IT"); (Logical system sap with: and space) + (Application AGC)
'||'map.put("RM1CLNT220: ", "RM1-220 IT");
'||'map.put("RM1CLNT210: ", "RM1-210 IT");
'||'
'||'// Finds the correct operation to do.
'||'switch (event.getOperation().intValue()) {
'||'
'||'	case 1: // Add Permission.
'||'	case 2: // Remove Permission.
'||'	case 12: // Add Rights.
'||'	case 13: // Remove Rights.
'||'
'||'		map.forEach((prefix, application) -> {
'||'
'||'			if (event.getAttr3() != null && event.getAttr3().startsWith(prefix)) {
'||'
'||'				event.setApplication(application);
'||'			}
'||'		});
'||'
'||'		break;
'||'
'||'	case 25: // Create External Role.
'||'	case 26: // Remove External Role.
'||'
'||'		map.forEach((prefix, application) -> {
'||'
'||'			if (event.getAttr1() != null && event.getAttr1().startsWith(prefix)) {
'||'
'||'				String value = event.getAttr1().substring(prefix.length());
'||'				event.setAttr1(value);
'||'				event.setApplication(application);
'||'			}
'||'		});
'||'
'||'		break;
'||'
'||'	case 27: // Add Child.
'||'	case 28: // Remove Child.
'||'
'||'		map.forEach((prefix, application) -> {
'||'
'||'			if (event.getAttr1() != null && event.getAttr1().startsWith(prefix)) {
'||'
'||'				String value = event.getAttr1().substring(prefix.length());
'||'				event.setAttr1(value);
'||'				event.setApplication(application);
'||'			}
'||'
'||'			if(event.getAttr6() != null && event.getAttr6().startsWith(prefix)) {
'||'
'||'				String value = event.getAttr6().substring(prefix.length());
'||'				event.setAttr6(value);
'||'				event.setApplication(application);
'||'			}
'||'		});
'||'
'||'		break;
'||'}
'||' 
'||'
'||'end
'||'
'||'
';

  counter       number(16);
begin
  select count(1) into counter from ideas_module t where lower ( t.code ) = lower ( im_name );
  if ( counter = 1 ) then
    select t.id into im_id from ideas_module t where lower ( t.code ) = lower ( im_name );
  else
    RAISE_APPLICATION_ERROR ( -20200, 'NO IDEAS MODULE FOUND' );
  end if;

  select count(1) into counter from flow_context t where lower ( t.name ) = lower ( fc_name );
  if ( counter = 1 ) then
    select t.id into fc_id from flow_context t where lower ( t.name ) = lower ( fc_name );
  else
    RAISE_APPLICATION_ERROR ( -20200, 'NO FLOW CONTEXT FOUND' );
  end if;

  select count(1) into counter from flow_event_type t
  where t.flow_context = fc_id and t.ideas_module = im_id and lower ( t.name ) = lower ( fevt_name );
  if ( counter = 1 ) then
    select t.id into fevt_id from flow_event_type t
    where t.flow_context = fc_id and t.ideas_module = im_id and lower ( t.name ) = lower ( fevt_name );
  else
    RAISE_APPLICATION_ERROR ( -20200, 'NO FLOW EVENT TYPE FOUND' );
  end if;
  
  select count(1) into counter from flow t
  where t.ideas_module = im_id and t.flow_event_type = fevt_id and lower ( t.name ) = lower ( f_name ); 
  if ( counter = 1 ) then
    select t.id into f_id from flow t
    where t.ideas_module = im_id and t.flow_event_type = fevt_id and lower ( t.name ) = lower ( f_name );
	
	update flow set flow_lob = f_lob where id = f_id;
  else
    RAISE_APPLICATION_ERROR ( -20200, 'NO FLOW FOUND' );
  end if;

  select count(1) into counter from flow_rule t where t.flow = f_id and t.ideas_module = im_id and lower ( t.name ) = lower ( fr_name );
  if ( counter = 0 ) then
    select flow_rule_seq.nextval into fr_id from dual;
    insert into flow_rule ( id, flow, name, description, rule_lob, ideas_module )
    values ( fr_id, f_id, fr_name, fr_desc, fr_lob, im_id );
  else
    select t.id into fr_id from flow_rule t where t.flow = f_id and t.ideas_module = im_id and lower ( t.name ) = lower ( fr_name );

    update flow_rule set description = fr_desc where id = fr_id;

    update flow_rule set rule_lob = fr_lob where id = fr_id;
  end if;

end;
/
commit;
set define on
