CREATE OR REPLACE function rep_risk_detail
(
  ent_type in numeric(31),
  env_selected_id in numeric(31),
  ran_code in varchar
)
return numeric(31) is
  RPD_PERSON_TYPE       constant numeric(1) := 0;
  RPD_ENTITLEMENT_TYPE  constant numeric(1) := 1;

  cur                   sys_refcursor;
  cur_ume               sys_refcursor;
  cur_dom               sys_refcursor;
  cur_risk              sys_refcursor;
  cur_ent_app           sys_refcursor;

  risk_rec_environment  numeric(16);
  risk_rec_risk         numeric(16);
  risk_rec_risk_level   numeric(1);

  risk_ent_cur          sys_refcursor;
  r_ent_rec_entity_task numeric(16);
  r_ent_rec_prof_task   numeric(16);
  r_ent_rec_entity      numeric(16);

  cur_risk_task         sys_refcursor;

  -- cursore per controllare se per ogni risk della tmp_report_incomp esiste un rimedio nella tmp_report_remediation
  cur_risk_rem          sys_refcursor;

  dom_id                numeric(16);
  per_id                numeric(16);

  entity_id             numeric(16);
  entity_type_id        numeric(16);
  task_id               numeric(16);
  risk_sev              varchar(10);

  risk_id               numeric(16);
  risk_cnt              numeric(16);

  counter               numeric(16);
  r_under               numeric(1);
  r_ok                  numeric(1);
  r_over                numeric(1);
  count_rem_und         numeric(16);
  count_rem_ov          numeric(16);

  per_ume_code          varchar(128);
  per_ume_list          varchar(1024);
  rem_rnd_id            numeric(16);

  environment_id        numeric(16);

  v_return              numeric(16);

  entitlement_id        numeric(16);

  rem_id                numeric(16);
begin
  if ( env_selected_id is not null and env_selected_id = 0 ) then
    select t.id into environment_id from environment t where t.working = 1;
  else
    environment_id := env_selected_id;
  end if;

  --[POPOLAZIONE TMP_REPORT_ENTITLEMENT - INIZIO]
  --inseriamo la coppia entitlement, application
  --in modo da avere la dipendenza degli entitlement dall'applicazioni

  select count(1) into counter from tmp_report_entitlement t;
  if ( counter > 0 ) then
    RAISE_APPLICATION_ERROR ( -20200, 'TEMPORARY TMP_REP_ENTITLMENT TABLE ALREADY USED!');
    return -1;
  end if;

  open cur_ent_app for select distinct t.parent from entitlement_hier t;
  loop
    fetch cur_ent_app into entitlement_id;
    exit when cur_ent_app%NOTFOUND;

    insert into tmp_report_entitlement ( id, application )
    select distinct ent.id, pro.application
      from entitlement ent,
           entitlement pro,
           /*PG-BEGIN*/
           (select t.parent, t.child, t.parent_int_type, t.child_int_type
              from entitlement_hier t
            connect by prior t.parent = t.child
            start with t.parent = entitlement_id) h
           /*(select * from connectby ( 'entitlement_hier',  'child', 'parent', cast (entitlement_id as varchar), 0 )
            as t ( child numeric(16), parent numeric(16), level int )) h*/
           /*PG-END*/
     where h.parent = ent.id
       and h.child = pro.id
       and pro.int_type in ( 1, -1 );
  end loop;

  insert into tmp_report_entitlement ( id, application )
  select t.id, t.application from entitlement t where t.int_type in ( 1, -1 );

  --[POPOLAZIONE TMP_REPORT_ENTITLEMENT - FINE]

  if ( ent_type = RPD_PERSON_TYPE ) then
    open cur for
      select p.id from person_incomp pi, person p
      where pi.environment = environment_id and pi.person = p.id and pi.comp_time > 0 and ( p.ume is null or p.ume = p.id );
    entity_type_id := RPD_PERSON_TYPE;

    /*DBALT-BEGIN*/
    /*select dbms_random.random into rem_rnd_id from dual;*/
    /*PG*select trunc(random()*1000) into rem_rnd_id from generate_series(1,1000) limit 1;*PG*/
    select int((rand()-0.5) * 32768) into rem_rnd_id from dual;
    /*DBALT-END*/

    if ( rem_rnd_id > 0 ) then
      rem_rnd_id := 0 - rem_rnd_id;
    end if;

    delete from remediation rem where rem.code = ' ';
    insert into remediation (id, name, code )
    values ( rem_rnd_id, ' ', ' ' );
  elsif ( ent_type = RPD_ENTITLEMENT_TYPE ) then
    open cur for select t.entitlement from entitlement_incomp t where t.environment = environment_id and t.comp_time > 0;
    entity_type_id := RPD_ENTITLEMENT_TYPE;
  end if;

  loop
    fetch cur into entity_id;
    exit when cur%NOTFOUND;

    r_under := 0;
    r_ok := 0;
    r_over := 0;
    per_ume_list := null;

    if ( ent_type = RPD_PERSON_TYPE ) then
      cur_dom := arc_21_init_user ( entity_id, environment_id );

      open cur_ume for select p.code from person p where p.ume = entity_id;
      loop
        fetch cur_ume into per_ume_code;
        exit when cur_ume%NOTFOUND;
        if ( per_ume_list is not null ) then
          if ( ( length ( per_ume_list ) + length ( per_ume_code ) ) < 1024 ) then
            per_ume_list := per_ume_list || ',' || per_ume_code;
          else
            per_ume_list :=  per_ume_list || '...';
            return -1;
          end if;
        else
          per_ume_list := per_ume_code;
        end if;
      end loop;
      close cur_ume;

    elsif ( ent_type = RPD_ENTITLEMENT_TYPE ) then
      cur_dom := arc_21_init_ent ( entity_id, environment_id, 1 );
    end if;

    loop
      fetch cur_dom into dom_id;
      exit when cur_dom%NOTFOUND;

      cur_risk := arc_31_check_risk ( dom_id, environment_id, 0 );
      loop
        fetch cur_risk into risk_rec_environment, risk_rec_risk, risk_rec_risk_level;
        exit when cur_risk%NOTFOUND;

        select
          case
            when risk_rec_risk_level = 0 then 'LOW'
            when risk_rec_risk_level = 1 then 'MEDIUM'
            when risk_rec_risk_level = 2 then 'HIGH'
          end into risk_sev from dual;

        open cur_risk_task for
          select t.task from risk_task t where t.environment = environment_id and t.risk = risk_rec_risk;
        loop
          fetch cur_risk_task into task_id;
          exit when cur_risk_task%NOTFOUND;

          risk_ent_cur := arc_31_get_ent_risk_detail ( dom_id, environment_id, risk_rec_risk, task_id );
          loop
            fetch risk_ent_cur into r_ent_rec_entity_task, r_ent_rec_prof_task, r_ent_rec_entity;
            exit when risk_ent_cur%NOTFOUND;

            insert into tmp_report_incomp
              ( environment, entity, entity_type, domain, risk, task, risk_severity,
                entitlement, profile, ume_list, random_code )
            values
              ( environment_id, entity_id, entity_type_id, dom_id, risk_rec_risk, task_id, risk_sev,
                r_ent_rec_entity, r_ent_rec_prof_task, per_ume_list, ran_code );

          end loop;
          close risk_ent_cur;

        end loop;
        close cur_risk_task;

      end loop;
      close cur_risk;

    end loop;
    close cur_dom;

    if ( ent_type = RPD_PERSON_TYPE ) then
      select count(1) into counter from tmp_report_incomp t
      where t.environment = environment_id and t.entity = entity_id and t.entity_type = RPD_PERSON_TYPE;
      count_rem_und := 0;
      count_rem_ov := 0;

      if ( counter = 0 ) then
        insert into tmp_report_incomp ( environment, entity, entity_type, rem_under, rem_ok, rem_over, random_code )
        values ( environment_id, entity_id, entity_type_id, r_under, r_ok, r_over, ran_code );
      else
        update tmp_report_incomp set rem_under = r_under, rem_ok = r_ok, rem_over = r_over
        where environment = environment_id and entity = entity_id and entity_type = RPD_PERSON_TYPE;
      end if;

      if ( counter = 0 ) then
        select count(1) into count_rem_ov from person_remediation pr
        where pr.person = entity_id;

        insert into tmp_report_remediation (environment, person, risk, risk_severity, remediation, random_code)
        select environment_id, entity_id, null, null, a.remediation, ran_code from
        (
          select pr.remediation from person_remediation pr where pr.person = entity_id
        ) a;
      else
        insert into tmp_report_remediation (environment, person, risk, risk_severity, remediation, random_code)
        with ti_rem as
        (
          select rr.environment, rr.risk, rr.remediation
          from risk_remediation rr
          where rr.environment = environment_id
        ),
        tmp_ti_rem as
        (
          select distinct tmp.environment, tmp.entity, tmp.risk, tmp.incomp_level, rr.remediation, tmp.random_code
          from tmp_report_incomp tmp, ti_rem rr
          where tmp.environment = environment_id and tmp.environment = rr.environment and tmp.random_code = ran_code
          and tmp.entity = entity_id and tmp.entity_type = RPD_PERSON_TYPE
          and tmp.risk = rr.risk
        )
        select distinct tmp.environment, tmp.entity, tmp.risk, tmp.risk_severity, pr.remediation, tmp.random_code
        from tmp_report_incomp tmp, person_remediation pr, ti_rem tr
        where tmp.environment = tr.environment and pr.person = tmp.entity and tmp.risk = tr.risk
        and tmp.environment = environment_id and tmp.random_code = ran_code and tmp.entity = entity_id and tmp.entity_type = RPD_PERSON_TYPE
        union
        select environment_id as environment, per_rem_not_used.person, null as risk, null as risk_severity, per_rem_not_used.remediation, ran_code from
        ( select pr.person, pr.remediation from person_remediation pr where pr.person = entity_id
          minus
          select distinct ttr.entity, ttr.remediation from tmp_ti_rem ttr ) per_rem_not_used;

        select count(1) into count_rem_und from tmp_report_remediation tmp
        where tmp.environment = environment_id and tmp.person = entity_id
        and tmp.remediation is null;

        select count(1) into count_rem_ov from tmp_report_remediation tmp
        where tmp.environment = environment_id and tmp.person = entity_id
        and tmp.risk is null;

        if ( count_rem_und = 0 ) then
          r_ok := 1;
        else
          r_under := 1;
        end if;
      end if;


      -- add by Fabrino

      open cur_risk_rem for
           select distinct ri.risk
             from tmp_report_incomp ri
            where ri.entity = entity_id
              and ri.environment = environment_id
              and not exists (select 1
                     from tmp_report_remediation rr
                    where rr.person = ri.entity
                      and rr.risk = ri.risk
                      and rr.environment = ri.environment);

      loop
        fetch cur_risk_rem into risk_id;
        exit when cur_risk_rem%NOTFOUND;

        insert into tmp_report_remediation (environment, person, risk, remediation, random_code)
        values (environment_id,entity_id, risk_id, rem_rnd_id, ran_code);

      end loop;
      close cur_risk_rem;

      if ( count_rem_ov > 0 ) then
        r_over := 1;
      end if;

    end if;

  end loop;
  close cur;

  --2015-05-22 - Person-Remediation-Risk cleanup
  if ( ent_type = RPD_PERSON_TYPE ) then
    open cur for select distinct t.environment, t.person, t.remediation, t.risk from tmp_report_remediation t;
    loop
      fetch cur into environment_id, entity_id, rem_id, risk_id;
      exit when cur%NOTFOUND;

      if ( rem_id <> rem_rnd_id ) then
        select count(1) into counter from person_remediation pr, risk_remediation rr
        where pr.remediation = rr.remediation and pr.person = entity_id and pr.remediation = rem_id
        and rr.risk = risk_id and rr.environment = environment_id;

        if ( counter = 0 ) then
          --delete from tmp_report_remediation t
          --where t.environment = environment_id and t.person = entity_id
          --and t.risk = risk_id and t.remediation = rem_id;
          update tmp_report_remediation set remediation = rem_rnd_id
          where environment = environment_id and person = entity_id
          and risk = risk_id and remediation = rem_id;
        end if;
      end if;

    end loop;
    close cur;
  end if;

  --2015-06-05 - Cleaning up fake per risk remediation when a real remediation is present
  open cur for select distinct t.person from tmp_report_remediation t;
  loop
    fetch cur into per_id;
    exit when cur%NOTFOUND;
    open cur_risk for
      select t.risk, count(1) from tmp_report_remediation t
      where t.person = per_id
      group by t.risk;
    loop
      fetch cur_risk into risk_id, risk_cnt;
      exit when cur_risk%NOTFOUND;

      select count(1) into counter from tmp_report_remediation t
      where t.person = per_id and risk = risk_id and environment = environment_id
      and t.remediation = rem_rnd_id;
      if ( risk_cnt > counter ) then
        delete from tmp_report_remediation t
        where t.person = per_id and risk = risk_id and environment = environment_id
        and t.remediation = rem_rnd_id;
      end if;
    end loop;
    close cur_risk;
  end loop;
  close cur;

  return 0;
end rep_risk_detail;
/
