create or replace function arc_16_pg_eval_permission_task
(
  entity_id      in number,
  pg_parent_id   in number,
  pg_par_cond    in number,
  pg_profile_id  in number,
  entity_type    in number
)
return boolean is
  CONDITION_OR    constant number(1) := 0;
  CONDITION_AND   constant number(1) := 1;
  ENTITY_TYPE_ENT constant number(1) := 0;
  ENTITY_TYPE_OU  constant number(1) := 1;
  ENTITY_TYPE_PER constant number(1) := 2;
  ENTITY_TYPE_APP constant number(1) := 3;
  ENTITY_TYPE_PWD constant number(1) := 4;
  
  cur_pg          sys_refcursor;

  pg_id           number(16);
  pg_type         number(16);
  pg_condition    number(16);
  pg_attribute_id number(16);

  counter         number(16);
begin
  if ( entity_type = ENTITY_TYPE_ENT ) then
    select count(1) into counter from entitlement_flat_hier t where t.child = pg_profile_id
    and t.parent = entity_id;
  elsif ( entity_type = ENTITY_TYPE_OU ) then
    select count(1) into counter from job_unit ju, entitlement_flat_hier t
    where ju.entitlement = t.parent and t.child = pg_profile_id
    and ju.organizational_unit = entity_id;
  elsif ( entity_type = ENTITY_TYPE_PER ) then
    select count(1) into counter from employment emp, entitlement_flat_hier t
    where emp.entitlement = t.parent and t.child = pg_profile_id
    and emp.person = entity_id;
  elsif ( entity_type = ENTITY_TYPE_APP ) then
    select count(1) into counter from entitlement_flat_hier t
    where t.child = pg_profile_id
    and t.child_application = entity_id;
  elsif ( entity_type = ENTITY_TYPE_PWD ) then
    select count(1) into counter from target ta, entitlement_flat_hier t
    where ta.id = t.child_application and t.child = pg_profile_id
    and ta.pwdcfg = entity_id;
  else
    --non dovrebbe succedere
    RAISE_APPLICATION_ERROR ( -20060, 'ENTITY TYPE NOT SUPPORTED');
  end if;

  --l'entita non ha il permesso
  if ( counter = 0 ) then
    return false;
  end if;
  
  if ( entity_type = ENTITY_TYPE_PER ) then
    select count(1) into counter from profile_group t
    where t.parent = pg_parent_id;

    --nel profile group, il permission non ha attribute figli
    if ( counter = 0 ) then
      return true;
    end if;

    open cur_pg for
      select t.id, t.type, t.condition, t.attribute from profile_group t
      where t.parent = pg_parent_id
      order by t.type asc;
    loop
      fetch cur_pg into pg_id, pg_type, pg_condition, pg_attribute_id;
      exit when cur_pg%NOTFOUND;

      if ( pg_par_cond = CONDITION_OR ) then
        if ( arc_15_pg_eval_attribute ( entity_id, pg_id, pg_condition, pg_profile_id, pg_attribute_id ) = true ) then
          return true;
        end if;
      elsif ( pg_par_cond = CONDITION_AND ) then
        if ( arc_15_pg_eval_attribute ( entity_id, pg_id, pg_condition, pg_profile_id, pg_attribute_id ) = false ) then
          return false;
        end if;
      else
        --non dovrebbe succedere
        RAISE_APPLICATION_ERROR ( -20050, 'PROFILE GROUP CONDITION NOT VALID');
        return false;
      end if;

    end loop;
    close cur_pg;
  end if;--if ( entity_type = ENTITY_TYPE_PER ) then
  
  if ( pg_par_cond = CONDITION_OR ) then
    return false;
  elsif ( pg_par_cond = CONDITION_AND ) then
    return true;
  end if;

end arc_16_pg_eval_permission_task;
/
