create or replace function arc_18_pg_init_task
(
  environment_id in number,
  task_id        in number,
  entity_type    in number
)
return number is
  SKIP_APP          constant number(1) := 0;
  ASSIGNMENT_PG     constant number(1) := 4;
  
  ENTITY_TYPE_ENT   constant number(1) := 0;
  ENTITY_TYPE_OU    constant number(1) := 1;
  ENTITY_TYPE_PER   constant number(1) := 2;
  ENTITY_TYPE_APP   constant number(1) := 3;
  ENTITY_TYPE_PWD   constant number(1) := 4;

  cur_pg_root       sys_refcursor;
  cur_entity        sys_refcursor;

  pg_root           number(16);

  pg_root_ent       number(16);

  pg_id             number(16);
  pg_condition      number(1);

  entity_id         number(16);

  counter           number(16);
begin
  open cur_pg_root for
    select distinct p.root from task_profile tp, profile_group p, entitlement ent
    where tp.environment = environment_id and tp.task = task_id
    and tp.profile = p.profile and p.profile = ent.id and ent.int_type = 0;
  loop
    fetch cur_pg_root into pg_root;
    exit when cur_pg_root%NOTFOUND;

    select t.id, t.condition, t.profile into pg_id, pg_condition, pg_root_ent
    from profile_group t where t.root = pg_root and t.parent is null;

    select count(1) into counter from task_profile t, entitlement ent
    where t.profile = pg_root_ent and t.environment = environment_id
    and t.profile = ent.id and ent.int_type = 0;

    if ( counter > 0 ) then
      if ( entity_type = ENTITY_TYPE_ENT ) then
        open cur_entity for
          select distinct
            efh.parent
          from
            profile_group pg,
            entitlement_flat_hier efh,
            application app
          where
            pg.root = pg_id and pg.type = 3 and pg.profile = efh.child
            and efh.child_application = app.id
            --2015-06-10 - SoD Extension to Extenal Roles
            --add join between application SoD level and external role level
            and app.sod_ext_level = efh.child_ext_type
            and efh.child_int_type in ( 1, -1 )
            and app.enable_sod = SKIP_APP
            and not exists ( select 1 from tmp_rpd2_join tmp where tmp.employment = efh.parent );
      elsif ( entity_type = ENTITY_TYPE_OU ) then
        open cur_entity for
          select distinct
            ju.organizational_unit
          from
            profile_group pg,
            entitlement_flat_hier efh,
            application app,
            job_unit ju
          where
            pg.root = pg_id and pg.type = 3 and pg.profile = efh.child
            and efh.child_application = app.id
            --2015-06-10 - SoD Extension to Extenal Roles
            --add join between application SoD level and external role level
            and app.sod_ext_level = efh.child_ext_type
            and efh.parent = ju.entitlement
            and efh.child_int_type in ( 1, -1 )
            and app.enable_sod = SKIP_APP
            and not exists ( select 1 from tmp_rpd2_join tmp where tmp.employment = ju.organizational_unit );
      elsif ( entity_type = ENTITY_TYPE_PER ) then
        open cur_entity for
          select distinct
            emp.person
          from
            profile_group pg,
            entitlement_flat_hier efh,
            application app,
            employment emp
          where
            pg.root = pg_id and pg.type = 3 and pg.profile = efh.child
            and efh.child_application = app.id
            --2015-06-10 - SoD Extension to Extenal Roles
            --add join between application SoD level and external role level
            and app.sod_ext_level = efh.child_ext_type
            and efh.parent = emp.entitlement
            and efh.child_int_type in ( 1, -1 )
            and app.enable_sod = SKIP_APP
            and not exists ( select 1 from tmp_rpd2_join tmp where tmp.employment = emp.person );
      elsif ( entity_type = ENTITY_TYPE_APP ) then
        open cur_entity for
          select distinct
            efh.child_application
          from
            profile_group pg,
            entitlement_flat_hier efh,
            application app
          where
            pg.root = pg_id and pg.type = 3 and pg.profile = efh.child
            and efh.child_application = app.id
            --2015-06-10 - SoD Extension to Extenal Roles
            --add join between application SoD level and external role level
            and app.sod_ext_level = efh.child_ext_type
            and efh.child_int_type in ( 1, -1 )
            and app.enable_sod = SKIP_APP
            and not exists ( select 1 from tmp_rpd2_join tmp where tmp.employment = efh.child_application );
      elsif ( entity_type = ENTITY_TYPE_PWD ) then
        open cur_entity for
          select distinct
            t.pwdcfg
          from
            profile_group pg,
            entitlement_flat_hier efh,
            application app,
            target t
          where
            pg.root = pg_id and pg.type = 3 and pg.profile = efh.child
            and efh.child_application = app.id
            --2015-06-10 - SoD Extension to Extenal Roles
            --add join between application SoD level and external role level
            and app.sod_ext_level = efh.child_ext_type
            and app.target = t.id
            and efh.child_int_type in ( 1, -1 )
            and app.enable_sod = SKIP_APP
            and not exists ( select 1 from tmp_rpd2_join tmp where tmp.employment = t.pwdcfg );
      else
        --non dovrebbe succedere
        RAISE_APPLICATION_ERROR ( -20060, 'ENTITY TYPE NOT SUPPORTED');
      end if;

      loop
        fetch cur_entity into entity_id;
        exit when cur_entity%NOTFOUND;
          if ( arc_17_pg_eval_group_task ( entity_id, pg_id, pg_condition, entity_type ) ) then
            insert into tmp_rpd2_join ( environment, entity, profile, domain, task, employment, assignment )
            values ( environment_id, task_id, pg_root_ent, null, task_id, entity_id, ASSIGNMENT_PG );
          end if;--if ( arc_17_pg_eval_group ( pg_id, pg_condition ) ) then
      end loop;
      close cur_entity;
    end if;--if ( counter > 0 ) then
  end loop;
  close cur_pg_root;

  return 0;
end arc_18_pg_init_task;
/

GRANT EXECUTE ON arc_18_pg_init_task TO ideas;
