create or replace function arc_21_init_task
(
  task_id        in number,
  environment_id in number,
  entity_type    in number
)
return sys_refcursor is
/*
Dato un intitlement valorizziamo la tabella temporanea TMP_RPD2_JOIN
Vengono restituiti una lista di DOMINI
*/
  SKIP_APP          constant number(1) := 0;
  ASSIGNMENT_DIRECT constant number(1) := 1;

  ENTITY_TYPE_ENT   constant number(1) := 0;
  ENTITY_TYPE_OU    constant number(1) := 1;
  ENTITY_TYPE_PER   constant number(1) := 2;
  ENTITY_TYPE_APP   constant number(1) := 3;
  ENTITY_TYPE_PWD   constant number(1) := 4;

  t_entity_cur      sys_refcursor;
begin
  delete from tmp_rpd2_join;

  if ( entity_type = ENTITY_TYPE_ENT ) then
    insert into tmp_rpd2_join ( environment, entity, task, domain, profile, employment, assignment )
    select distinct
      /*+ ORDERED */
      tp.environment,
      tp.task as entity,
      tp.task,
      cast(null as number(16)),
      tp.profile,
      efh.parent as employment,
      ASSIGNMENT_DIRECT as assignment
    from
      task_profile tp,
      domain_profile dp,
      entitlement_flat_hier efh,
      application app
    where
      tp.environment = dp.environment
      and tp.profile = dp.profile
      and dp.profile = efh.child
      and efh.child_application = app.id
      --2015-06-10 - SoD Extension to Extenal Roles
      --add join between application SoD level and external role level
      and app.sod_ext_level = efh.child_ext_type
      and tp.task = task_id
      and efh.child_int_type in ( 1, -1 )
      and app.enable_sod = SKIP_APP
      and tp.environment = environment_id
    ;
  elsif ( entity_type = ENTITY_TYPE_OU ) then
    insert into tmp_rpd2_join ( environment, entity, task, domain, profile, employment, assignment )
    select distinct
      /*+ ORDERED */
      tp.environment,
      tp.task as entity,
      tp.task,
      cast(null as number(16)),
      tp.profile,
      ju.organizational_unit as employment,
      ASSIGNMENT_DIRECT as assignment
    from
      task_profile tp,
      domain_profile dp,
      entitlement_flat_hier efh,
      application app,
      job_unit ju
    where
      tp.environment = dp.environment
      and tp.profile = dp.profile
      and dp.profile = efh.child
      and efh.child_application = app.id
      --2015-06-10 - SoD Extension to Extenal Roles
      --add join between application SoD level and external role level
      and app.sod_ext_level = efh.child_ext_type
      and efh.parent = ju.entitlement
      and tp.task = task_id
      and efh.child_int_type in ( 1, -1 )
      and app.enable_sod = SKIP_APP
      and tp.environment = environment_id
    ;
  elsif ( entity_type = ENTITY_TYPE_PER ) then
    insert into tmp_rpd2_join ( environment, entity, task, domain, profile, employment, assignment )
    select distinct
      /*+ ORDERED */
      tp.environment,
      tp.task as entity,
      tp.task,
      cast(null as number(16)),
      tp.profile,
      emp.person as employment,
      ASSIGNMENT_DIRECT as assignment
    from
      task_profile tp,
      domain_profile dp,
      entitlement_flat_hier efh,
      application app,
      employment emp
    where
      tp.environment = dp.environment
      and tp.profile = dp.profile
      and dp.profile = efh.child
      and efh.child_application = app.id
      --2015-06-10 - SoD Extension to Extenal Roles
      --add join between application SoD level and external role level
      and app.sod_ext_level = efh.child_ext_type
      and efh.parent = emp.entitlement
      and tp.task = task_id
      and efh.child_int_type in ( 1, -1 )
      and app.enable_sod = SKIP_APP
      and tp.environment = environment_id
    ;
  elsif ( entity_type = ENTITY_TYPE_APP ) then
    insert into tmp_rpd2_join ( environment, entity, task, domain, profile, employment, assignment )
    select distinct
      /*+ ORDERED */
      tp.environment,
      tp.task as entity,
      tp.task,
      cast(null as number(16)),
      tp.profile,
      efh.child_application as employment,
      ASSIGNMENT_DIRECT as assignment
    from
      task_profile tp,
      domain_profile dp,
      entitlement_flat_hier efh,
      application app
    where
      tp.environment = dp.environment
      and tp.profile = dp.profile
      and dp.profile = efh.child
      and efh.child_application = app.id
      --2015-06-10 - SoD Extension to Extenal Roles
      --add join between application SoD level and external role level
      and app.sod_ext_level = efh.child_ext_type
      and tp.task = task_id
      and efh.child_int_type in ( 1, -1 )
      and app.enable_sod = SKIP_APP
      and tp.environment = environment_id
    ;
  elsif ( entity_type = ENTITY_TYPE_PWD ) then
    insert into tmp_rpd2_join ( environment, entity, task, domain, profile, employment, assignment )
    select distinct
      /*+ ORDERED */
      tp.environment,
      tp.task as entity,
      tp.task,
      cast(null as number(16)),
      tp.profile,
      t.pwdcfg as employment,
      ASSIGNMENT_DIRECT as assignment
    from
      task_profile tp,
      domain_profile dp,
      entitlement_flat_hier efh,
      application app,
      target t
    where
      tp.environment = dp.environment
      and tp.profile = dp.profile
      and dp.profile = efh.child
      and efh.child_application = app.id
      --2015-06-10 - SoD Extension to Extenal Roles
      --add join between application SoD level and external role level
      and app.sod_ext_level = efh.child_ext_type
      and app.target = t.id
      and tp.task = task_id
      and efh.child_int_type in ( 1, -1 )
      and app.enable_sod = SKIP_APP
      and tp.environment = environment_id
    ;
  else
    --non dovrebbe succedere
    RAISE_APPLICATION_ERROR ( -20060, 'ENTITY TYPE NOT SUPPORTED');
  end if;

  t_entity_cur := arc_19_calc_pg_on_task ( environment_id, task_id, entity_type  );
  return t_entity_cur;
end arc_21_init_task;
/

GRANT EXECUTE ON arc_21_init_task TO ideas;
