--CREATE A TABLE AND ITS CONSTRAINTS
set verify off
set serveroutput on
declare
  curr_user         varchar2(30);
  
  tab_name          varchar2(30) := 'CFG_NOTIFICATION';
  dml_def           varchar2(4000);
  
  counter           number(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from all_tables t where t.owner = curr_user and t.table_name = tab_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'create table CFG_NOTIFICATION
(
  ID                NUMBER(16) not null,
  EMS_TEMPLATE      NUMBER(16) not null,
  REQUESTED_FOR     NUMBER(1),
  REQUESTED_BY      NUMBER(1),
  APPROVERS         NUMBER(1),
  FIXED_NOTIFY      NUMBER(1),
  FIXED_NOTIFY_LIST VARCHAR2(2048 CHAR),
  ATTR1             VARCHAR2(256 CHAR),
  ATTR2             VARCHAR2(256 CHAR),
  ATTR3             VARCHAR2(256 CHAR),
  ATTR4             VARCHAR2(256 CHAR),
  ATTR5             VARCHAR2(256 CHAR),
  CREATION_DATE     DATE default SYSDATE,
  CREATION_USER     VARCHAR2(128 CHAR),
  LAST_MOD_USER     VARCHAR2(128 CHAR),
  LAST_MOD_TIME     DATE default SYSDATE
)
tablespace &DATA_TABLESPACE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'alter table CFG_NOTIFICATION
  add constraint CFG_NOTIFICATION_PK primary key (ID)
  using index 
  tablespace &INDEX_TABLESPACE compute statistics
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'alter table CFG_NOTIFICATION
  add constraint CFG_NOTIF_EMS_TEMPLATE_FK foreign key (EMS_TEMPLATE)
  references EMS_TEMPLATE (ID) on delete cascade
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
set serveroutput off
set verify on

comment on column CFG_NOTIFICATION.REQUESTED_FOR
  is '0: Unselected - 1: TO - 2: CC - 3: BCC - 4: SMS';
comment on column CFG_NOTIFICATION.REQUESTED_BY
  is '0: Unselected - 1: TO - 2: CC - 3: BCC - 4: SMS';
comment on column CFG_NOTIFICATION.APPROVERS
  is '0: Unselected - 1: TO - 2: CC - 3: BCC - 4: SMS';
comment on column CFG_NOTIFICATION.FIXED_NOTIFY
  is '0: Unselected - 1: TO - 2: CC - 3: BCC - 4: SMS';
comment on column CFG_NOTIFICATION.FIXED_NOTIFY_LIST
  is 'Email/SMS list';

grant select on CFG_NOTIFICATION to AA;
grant select, insert, update, delete, references on CFG_NOTIFICATION to IDEAS;
grant select, insert, update, delete, references on CFG_NOTIFICATION to IDEAS_CONNECTOR;
grant select on CFG_NOTIFICATION to IDEAS_REPORT;

--CREATE A SEQUENCE
set verify off
set serveroutput on
declare
  curr_user         varchar2(30);
  
  seq_name          varchar2(30) := 'CFG_NOTIFICATION_SEQ';
  dml_def           varchar2(4000);
  
  counter           number(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from all_sequences t where t.sequence_owner = curr_user and t.sequence_name = seq_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'create sequence CFG_NOTIFICATION_SEQ
minvalue 100
maxvalue 999999999999999999999999999
start with 100
increment by 1
nocache
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
set serveroutput off
set verify on

grant select on CFG_NOTIFICATION_SEQ to AA;
grant select, alter on CFG_NOTIFICATION_SEQ to IDEAS;
grant select on CFG_NOTIFICATION_SEQ to IDEAS_CONNECTOR;
grant select on CFG_NOTIFICATION_SEQ to IDEAS_REPORT;
