--CREATE A TABLE AND ITS CONSTRAINTS
set verify off
set serveroutput on
declare
  curr_user         varchar(30);
  
  tab_name          varchar(30) := 'CFG_NOTIFICATION';
  dml_def           varchar(4000);
  
  counter           numeric(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from sysibm.tables t where ( t.table_type = 'BASE TABLE' or t.table_type is null ) and lower ( t.table_schema ) = lower ( curr_user ) and t.table_name = tab_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'CREATE TABLE CFG_NOTIFICATION
(
  ID                             NUMERIC(16)         NOT NULL,
  EMS_TEMPLATE                   NUMERIC(16)         NOT NULL,
  REQUESTED_FOR                  NUMERIC(1),
  REQUESTED_BY                   NUMERIC(1),
  APPROVERS                      NUMERIC(1),
  FIXED_NOTIFY                   NUMERIC(1),
  FIXED_NOTIFY_LIST              VARCHAR(2048),
  ATTR1                          VARCHAR(256),
  ATTR2                          VARCHAR(256),
  ATTR3                          VARCHAR(256),
  ATTR4                          VARCHAR(256),
  ATTR5                          VARCHAR(256),
  CREATION_DATE                  DATE                DEFAULT CURRENT_DATE,
  CREATION_USER                  VARCHAR(128),
  LAST_MOD_USER                  VARCHAR(128),
  LAST_MOD_TIME                  DATE                DEFAULT CURRENT_DATE
)
IN &DATA_TABLESPACE
INDEX IN &INDEX_TABLESPACE
LONG IN &LOB_TABLESPACE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE CFG_NOTIFICATION ADD
  CONSTRAINT CFG_NOTIFICATION_PK
 PRIMARY KEY (ID)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE CFG_NOTIFICATION ADD
  CONSTRAINT CFG_NOTIF_EMS_TEMPLATE_FK
 FOREIGN KEY (EMS_TEMPLATE)
 REFERENCES EMS_TEMPLATE (ID)
    ON DELETE CASCADE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
commit;
set serveroutput off
set verify on


--REORGANIZE A TABLE
set verify off
set serveroutput on
declare
  curr_user         varchar(30);
  
  tab_name          varchar(30) := 'CFG_NOTIFICATION';
  dml_def           varchar(4000);
  
  counter           numeric(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from sysibm.tables t where ( t.table_type = 'BASE TABLE' or t.table_type is null ) and lower ( t.table_schema ) = lower ( curr_user ) and t.table_name = tab_name;
  if ( counter = 0 ) then
    return;
  end if;

  dml_def :=
'CALL SYSPROC.ADMIN_CMD( ''REORG TABLE CFG_NOTIFICATION'' )
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
commit;
set serveroutput off
set verify on

comment on column CFG_NOTIFICATION.REQUESTED_FOR
  is '0: Unselected - 1: TO - 2: CC - 3: BCC - 4: SMS';
comment on column CFG_NOTIFICATION.REQUESTED_BY
  is '0: Unselected - 1: TO - 2: CC - 3: BCC - 4: SMS';
comment on column CFG_NOTIFICATION.APPROVERS
  is '0: Unselected - 1: TO - 2: CC - 3: BCC - 4: SMS';
comment on column CFG_NOTIFICATION.FIXED_NOTIFY
  is '0: Unselected - 1: TO - 2: CC - 3: BCC - 4: SMS';
comment on column CFG_NOTIFICATION.FIXED_NOTIFY_LIST
  is 'Email/SMS list';

grant select on CFG_NOTIFICATION to &AA_SUPER_ADMIN_USER;
grant select, insert, update, delete, references on CFG_NOTIFICATION to &IDEAS_SUPER_ADMIN_USER;
grant select, insert, update, delete, references on CFG_NOTIFICATION to &IDEAS_CONN_SUPER_ADMIN_USER;
grant select on CFG_NOTIFICATION to &IDEAS_REPORT_SUPER_ADMIN_USER;

--CREATE A SEQUENCE
set verify off
set serveroutput on
declare
  curr_user         varchar(30);
  
  seq_name          varchar(30) := 'CFG_NOTIFICATION_SEQ';
  dml_def           varchar(4000);
  
  counter           numeric(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from syscat.sequences t where lower ( t.seqschema ) = lower ( curr_user ) and t.seqtype <> 'I' and lower ( t.seqname ) = lower ( seq_name );
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'CREATE SEQUENCE CFG_NOTIFICATION_SEQ
  AS NUMERIC(18)
  START WITH 100
  INCREMENT BY 1
  MINVALUE 100
  MAXVALUE 999999999999999999
  NO CACHE
  NO CYCLE
  NO ORDER
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
commit;
set serveroutput off
set verify on

grant usage on sequence CFG_NOTIFICATION_SEQ to &AA_SUPER_ADMIN_USER;
grant usage, alter on sequence CFG_NOTIFICATION_SEQ to &IDEAS_SUPER_ADMIN_USER;
grant usage, alter on sequence CFG_NOTIFICATION_SEQ to &IDEAS_CONN_SUPER_ADMIN_USER;
grant usage on sequence CFG_NOTIFICATION_SEQ to &IDEAS_REPORT_SUPER_ADMIN_USER;
