--CREATE A TABLE AND ITS CONSTRAINTS
set verify off
set serveroutput on
declare
  curr_user         varchar2(30);
  
  tab_name          varchar2(30) := 'CFG_PRIORITY';
  dml_def           varchar2(4000);
  
  counter           number(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from all_tables t where t.owner = curr_user and t.table_name = tab_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'create table CFG_PRIORITY
(
  ID                       NUMBER(16) not null,
  TYPE                     NUMBER(1) not null,
  CFG_NOTIFICATION_EMAIL   NUMBER(16),
  CFG_NOTIFICATION_SMS     NUMBER(16),
  DESCRIPTION              VARCHAR2(512 CHAR),
  PRIORITY_VALUE           NUMBER(16) not null,
  PRIORITY_UNIT            NUMBER(1) default 1 not null,
  REMINDER_START_VALUE     NUMBER(16) not null,
  REMINDER_START_UNIT      NUMBER(1) default 1 not null,
  REMINDER_FREQUENCY_VALUE NUMBER(16) not null,
  REMINDER_FREQUENCY_UNIT  NUMBER(1) default 1 not null,
  STATE                    NUMBER(16) default 0,
  ATTR1                    VARCHAR2(256 CHAR),
  ATTR2                    VARCHAR2(256 CHAR),
  ATTR3                    VARCHAR2(256 CHAR),
  ATTR4                    VARCHAR2(256 CHAR),
  ATTR5                    VARCHAR2(256 CHAR),
  CREATION_DATE            DATE default SYSDATE,
  CREATION_USER            VARCHAR2(128 CHAR),
  LAST_MOD_USER            VARCHAR2(128 CHAR),
  LAST_MOD_TIME            DATE default SYSDATE
)
tablespace &DATA_TABLESPACE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'alter table CFG_PRIORITY
  add constraint CFG_PRIORITY_PK primary key (ID)
  using index 
  tablespace &INDEX_TABLESPACE compute statistics
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'alter table CFG_PRIORITY
  add constraint CFG_PRIORITY_NOTIF_EMAIL_FK foreign key (CFG_NOTIFICATION_EMAIL)
  references CFG_NOTIFICATION (ID) on delete set null
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'alter table CFG_PRIORITY
  add constraint CFG_PRIORITY_NOTIF_SMS_FK foreign key (CFG_NOTIFICATION_SMS)
  references CFG_NOTIFICATION (ID) on delete set null
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'create unique index CFG_PRIORITY_TYPE_IDX on CFG_PRIORITY (TYPE)
  tablespace IGA_CORE_INDX compute statistics
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
set serveroutput off
set verify on

grant select on CFG_PRIORITY to AA;
grant select, insert, update, delete, references on CFG_PRIORITY to IDEAS;
grant select, insert, update, delete, references on CFG_PRIORITY to IDEAS_CONNECTOR;
grant select on CFG_PRIORITY to IDEAS_REPORT;

--CREATE A SEQUENCE
set verify off
set serveroutput on
declare
  curr_user         varchar2(30);
  
  seq_name          varchar2(30) := 'CFG_PRIORITY_SEQ';
  dml_def           varchar2(4000);
  
  counter           number(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from all_sequences t where t.sequence_owner = curr_user and t.sequence_name = seq_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'create sequence CFG_PRIORITY_SEQ
minvalue 100
maxvalue 999999999999999999999999999
start with 100
increment by 1
nocache
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
set serveroutput off
set verify on

grant select on CFG_PRIORITY_SEQ to AA;
grant select, alter on CFG_PRIORITY_SEQ to IDEAS;
grant select on CFG_PRIORITY_SEQ to IDEAS_CONNECTOR;
grant select on CFG_PRIORITY_SEQ to IDEAS_REPORT;
