--CREATE A TABLE AND ITS CONSTRAINTS
set verify off
set serveroutput on
declare
  curr_user         varchar(30);
  
  tab_name          varchar(30) := 'CFG_PRIORITY';
  dml_def           varchar(4000);
  
  counter           numeric(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from sysibm.tables t where ( t.table_type = 'BASE TABLE' or t.table_type is null ) and lower ( t.table_schema ) = lower ( curr_user ) and t.table_name = tab_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'CREATE TABLE CFG_PRIORITY
(
  ID                             NUMERIC(16)         NOT NULL,
  TYPE                           NUMERIC(1)          NOT NULL,
  CFG_NOTIFICATION_EMAIL         NUMERIC(16),
  CFG_NOTIFICATION_SMS           NUMERIC(16),
  DESCRIPTION                    VARCHAR(512),
  PRIORITY_VALUE                 NUMERIC(16)         NOT NULL,
  PRIORITY_UNIT                  NUMERIC(1)          DEFAULT 1 NOT NULL,
  REMINDER_START_VALUE           NUMERIC(16)         NOT NULL,
  REMINDER_START_UNIT            NUMERIC(1)          DEFAULT 1 NOT NULL,
  REMINDER_FREQUENCY_VALUE       NUMERIC(16)         NOT NULL,
  REMINDER_FREQUENCY_UNIT        NUMERIC(1)          DEFAULT 1 NOT NULL,
  STATE                          NUMERIC(16)         DEFAULT 0,
  ATTR1                          VARCHAR(256),
  ATTR2                          VARCHAR(256),
  ATTR3                          VARCHAR(256),
  ATTR4                          VARCHAR(256),
  ATTR5                          VARCHAR(256),
  CREATION_DATE                  DATE                DEFAULT CURRENT_DATE,
  CREATION_USER                  VARCHAR(128),
  LAST_MOD_USER                  VARCHAR(128),
  LAST_MOD_TIME                  DATE                DEFAULT CURRENT_DATE
)
IN &DATA_TABLESPACE
INDEX IN &INDEX_TABLESPACE
LONG IN &LOB_TABLESPACE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE CFG_PRIORITY ADD
  CONSTRAINT CFG_PRIORITY_PK
 PRIMARY KEY (ID)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE CFG_PRIORITY ADD
  CONSTRAINT CFG_PRIORITY_NOTIF_EMAIL_FK
 FOREIGN KEY (CFG_NOTIFICATION_EMAIL)
 REFERENCES CFG_NOTIFICATION (ID)
    ON DELETE SET NULL
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE CFG_PRIORITY ADD
  CONSTRAINT CFG_PRIORITY_NOTIF_SMS_FK
 FOREIGN KEY (CFG_NOTIFICATION_SMS)
 REFERENCES CFG_NOTIFICATION (ID)
    ON DELETE SET NULL
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'CREATE UNIQUE INDEX CFG_PRIORITY_TYPE_IDX ON CFG_PRIORITY
(TYPE)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
commit;
set serveroutput off
set verify on


--REORGANIZE A TABLE
set verify off
set serveroutput on
declare
  curr_user         varchar(30);
  
  tab_name          varchar(30) := 'CFG_PRIORITY';
  dml_def           varchar(4000);
  
  counter           numeric(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from sysibm.tables t where ( t.table_type = 'BASE TABLE' or t.table_type is null ) and lower ( t.table_schema ) = lower ( curr_user ) and t.table_name = tab_name;
  if ( counter = 0 ) then
    return;
  end if;

  dml_def :=
'CALL SYSPROC.ADMIN_CMD( ''REORG TABLE CFG_PRIORITY'' )
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
commit;
set serveroutput off
set verify on

grant select on CFG_PRIORITY to &AA_SUPER_ADMIN_USER;
grant select, insert, update, delete, references on CFG_PRIORITY to &IDEAS_SUPER_ADMIN_USER;
grant select, insert, update, delete, references on CFG_PRIORITY to &IDEAS_CONN_SUPER_ADMIN_USER;
grant select on CFG_PRIORITY to &IDEAS_REPORT_SUPER_ADMIN_USER;

--CREATE A SEQUENCE
set verify off
set serveroutput on
declare
  curr_user         varchar(30);
  
  seq_name          varchar(30) := 'CFG_PRIORITY_SEQ';
  dml_def           varchar(4000);
  
  counter           numeric(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from syscat.sequences t where lower ( t.seqschema ) = lower ( curr_user ) and t.seqtype <> 'I' and lower ( t.seqname ) = lower ( seq_name );
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'CREATE SEQUENCE CFG_PRIORITY_SEQ
  AS NUMERIC(18)
  START WITH 100
  INCREMENT BY 1
  MINVALUE 100
  MAXVALUE 999999999999999999
  NO CACHE
  NO CYCLE
  NO ORDER
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
commit;
set serveroutput off
set verify on

grant usage on sequence CFG_PRIORITY_SEQ to &AA_SUPER_ADMIN_USER;
grant usage, alter on sequence CFG_PRIORITY_SEQ to &IDEAS_SUPER_ADMIN_USER;
grant usage, alter on sequence CFG_PRIORITY_SEQ to &IDEAS_CONN_SUPER_ADMIN_USER;
grant usage on sequence CFG_PRIORITY_SEQ to &IDEAS_REPORT_SUPER_ADMIN_USER;
