create or replace function arc2arcs_05_align_all_task
(
  src_env_name in varchar2,
  dest_env_name in varchar2
)
return number is
  cur                sys_refcursor;
  upd_task           arc2arcs_task%ROWTYPE;

  src_environment    number(16);
  dest_environment   number(16);

  ret_var            number(16);
begin
  --cerchiamo l'environment di default (WORKING = 1) all'interno del
  --sistema di destinazione
  if ( src_env_name is null or length ( src_env_name ) = 0 ) then
    src_environment := arc2arcs_00_get_src_wrk_env();
  else
    select t.id into src_environment from &IGA_CORE_USER_OLD..environment t where lower(t.name) = lower(src_env_name);
  end if;

  --cerchiamo l'environment di default (WORKING = 1) all'interno del
  --sistema di destinazione
  if ( dest_env_name is null ) then
    dest_environment := arc2arcs_00_get_dest_wrk_env();
  else
    select t.id into dest_environment from environment t where lower(t.name) = lower(dest_env_name);
  end if;

  --modifichiamo la gerarchia dei task prima di cancellarli (per evitare l'effetto cascade)
  --e prima di aggiornarli per evitare i problemi di chiave violata
  update task set parent = ( select id from task where environment = dest_environment and parent is null )
  where environment = dest_environment and parent is not null;

  --cancelliamo nel sistema di destinazione i task non presenti
  --nel sistema sorgente
  ret_var := arc2arcs_01_del_non_ex_task ( src_environment, dest_environment );

  --allineiamo nel sistema di destinazione tutte le informazioni dei task
  ret_var := arc2arcs_01_align_task ( src_environment, dest_environment );

  --inseriamo nel sistema di destinazione i task non presenti
  --nel sistema sorgente
  ret_var := arc2arcs_01_ins_mis_task ( src_environment, dest_environment );

  --aggiorniamo la gerarchia ora che sono presenti tutti i task
  open cur for
    select
      t_src.id, t_src.name, t_src.description, t_src.state, t_src.attr1, t_src.attr2,
      t_src.attr3, t_src.attr4, t_src.attr5, t_src.last_mod_user, t_src.last_mod_time,
      t_src.parent, t_src.path, -1, t_src.profile_task, /*t_src.owner*/ 1 as owner,
      t_src.ownercode, t_src.code
    from &IGA_CORE_USER_OLD..task t_src where t_src.environment = src_environment;
  loop
    fetch cur into upd_task;
    exit when cur%NOTFOUND;

    update task set parent = upd_task.parent where environment = dest_environment and id = upd_task.id;
  end loop;
  close cur;

  return ret_var;
end arc2arcs_05_align_all_task;
/
