declare
  rq_id            number(16);
  rq_name          varchar2(256) := 'Export Entitlement Hierarchy';
  rq_desc          varchar2(512) := '';
  rqd              clob;

  counter          number(16);
begin
  rqd := 'with ent_detail as
'||'(
'||'  select
'||'         case
'||'           when e.id < 0 then ( 0 - e.id )
'||'           else e.id
'||'         end                as id,
'||'         e.code             as code,
'||'         e.name             as name,
'||'         e.description      as description,
'||'         e.int_type         as int_type,
'||'         e.ext_type         as ext_type,
'||'         e.administrative   as administrative,
'||'         ft.name            as functionality_type,
'||'         a.name             as application,
'||'         l.code             as language,
'||'         p.code             as owner_code,
'||'         e.scope_visibility as scope_type,
'||'         ef.name            as entitlement_family,
'||'         e.business_name    as business_name,
'||'         e.business_policy  as business_policy
'||'  from #pmschema#.language l, #pmschema#.entitlement_i18n e
'||'  left join #pmschema#.application a on a.id = e.application
'||'  left join #pmschema#.profile_type ft on ft.id = e.profile_type and a.id = ft.application
'||'  left outer join #pmschema#.person p on e.owner = p.id
'||'  left outer join #pmschema#.entitlement_family ef on e.family = ef.id
'||'  where e.int_type > 0
'||'  and e.language = l.id
'||')
'||'select distinct ent_all.name               as name,
'||'                ent_all.code               as code,
'||'                ent_all.description        as description,
'||'                case
'||'                  when ent_all.type = ''3'' then ''BUSINESS_ROLE''
'||'                  when ent_all.type = ''2'' then ''ITROLE''
'||'                  when ent_all.ext_type = ''3'' then ''PERMISSION''
'||'                  when ent_all.ext_type = ''4'' then ''EXTERNAL_ROLE''
'||'                end                        as type,
'||'                ent_all.permission_type    as permission_type,
'||'                ent_all.application        as application,
'||'                case
'||'                  when ent_all.administrative = 0 then ''FALSE''
'||'                  when ent_all.administrative = 1 then ''TRUE''
'||'                end                        as administrative,
'||'                ent_all.language           as language,
'||'                ent_all.parent_name        as parent_name,
'||'                ent_all.parent_code        as parent_code,
'||'                case
'||'                  when ent_all.parent_type = ''3'' then ''BUSINESS_ROLE''
'||'                  when ent_all.parent_type = ''2'' then ''ITROLE''
'||'                  when ent_all.parent_ext_type = ''3'' then ''PERMISSION''
'||'                  when ent_all.parent_ext_type = ''4'' then ''EXTERNAL_ROLE''
'||'                end                        as parent_type,
'||'                ent_all.parent_application as parent_application,
'||'                ent_all.owner_code         as owner_code,
'||'                ent_all.scope_type         as scope_type,
'||'                ent_all.business_name      as business_name,
'||'                ent_all.business_policy    as business_policy,
'||'                ent_all.entitlement_family as entitlement_family
'||'from (select distinct e.name               as name,
'||'                      e.code               as code,
'||'                      e.description        as description,
'||'                      e.int_type           as type,
'||'                      e.ext_type           as ext_type,
'||'                      e.functionality_type as permission_type,
'||'                      e.application        as application,
'||'                      e.administrative     as administrative,
'||'                      e.language           as language,
'||'                      null                 as parent_name,
'||'                      null                 as parent_code,
'||'                      null                 as parent_type,
'||'                      null                 as parent_ext_type,
'||'                      null                 as parent_application,
'||'                      e.owner_code         as owner_code,
'||'                      e.scope_type         as scope_type,
'||'                      e.entitlement_family as entitlement_family,
'||'                      e.business_name      as business_name,
'||'                      e.business_policy    as business_policy
'||'     from ent_detail e
'||'     union
'||'     select distinct c.name                               as name,
'||'                     c.code                               as code,
'||'                     c.description                        as description,
'||'                     c.int_type                           as type,
'||'                     c.ext_type                           as ext_type,
'||'                     c.functionality_type                 as permission_type,
'||'                     c.application                        as application,
'||'                     c.administrative                     as administrative,
'||'                     c.language                           as language,
'||'                     p.name                               as parent_name,
'||'                     p.code                               as parent_code,
'||'                     cast ( p.int_type as varchar2(256) ) as parent_type,
'||'                     cast ( p.ext_type as varchar2(256) ) as parent_ext_type,
'||'                     p.application                        as parent_application,
'||'                     c.owner_code                         as owner_code,
'||'                     c.scope_type                         as scope_type,
'||'                     c.entitlement_family                 as entitlement_family,
'||'                     c.business_name                      as business_name,
'||'                     c.business_policy                    as business_policy
'||'     from
'||'       #pmschema#.entitlement_hier eh, ent_detail p, ent_detail c
'||'     where
'||'        eh.parent = p.id
'||'        and eh.parent_int_type = p.int_type
'||'        and eh.child = c.id
'||'        and eh.child_int_type = c.int_type) ent_all
'||'order by ent_all.parent_name desc
';

  select count(1) into counter from r_query t where lower ( t.name ) = lower ( rq_name );
  if ( counter = 1 ) then
    select t.id into rq_id from r_query t where lower ( t.name ) = lower ( rq_name );

    update r_query_data set query = rqd where r_query = rq_id;
  end if;
  
end;
/

commit;
