declare
  rq_id                numeric(16);
  rq_name              varchar(256) := 'Activities by group';
  rq_desc              varchar(512) := 'Business Activity - Groups (where the activities are done)';
  rqd                  clob;

  counter              numeric(16);

  repfr_id             numeric(16);
  repfr_name_old       varchar(256);
  repfr_name           varchar(256);
  repfr_value          varchar(256);
  repfr_l_id           numeric(16);
  repfr_l_code_old     varchar(256);
  repfr_l_code         varchar(256);
  repfr_i18n_msg       varchar(256);
  repfr_vis            numeric(16);
  repfr_mand           numeric(16);
  repfr_type           numeric(16);
  repfr_cust_id        numeric(16);
  repfr_cust_name      varchar(256);
  repfr_posit_id       numeric(16);
  repfr_posit_id_old   numeric(16);

  rv_id                numeric(16);
  rv_name              varchar(256);

  v_ret                numeric(16);
begin
  rqd := 'select distinct
'||'  t.name as ACTIVITY_NAME,
'||'  t.code as ACTIVITY_CODE,
'||'  t.description as ACTIVITY_DESC,
'||'  h.name as HIERARCHY,
'||'  ou.name as GROUP_NAME,
'||'  ou.code as GROUP_CODE,
'||'  ou.description as GROUP_DESC,
'||'  tg.last_mod_time as CALC_DATE
'||'from
'||'  #pmschema#.environment env,
'||'  #pmschema#.task t,
'||'  #pmschema#.task_group tg,
'||'  #pmschema#.organizational_unit ou,
'||'  #pmschema#.hierarchy h
'||'where
'||'  env.id = t.environment
'||'  and t.id = tg.task
'||'  and tg.organizational_unit = ou.id
'||'  and ou.hierarchy = h.id
'||'  and tg.hierarchy = ou.hierarchy
'||'  and ou.hierarchy = h.id
'||'  and env.working = 1
'||'  and lower ( h.name ) like lower ( ''#hierarchy_name#'' )
'||'';

  select count(1) into counter from r_query t where lower ( t.name ) = lower ( rq_name );
  if ( counter = 1 ) then
    select t.id into rq_id from r_query t where lower ( t.name ) = lower ( rq_name );

    update r_query_data set query = rqd where r_query = rq_id;
  end if;

  --REPORT FILTER 01: BEGIN
  repfr_name_old     := null;
  repfr_name         := 'hierarchy_name';
  repfr_value        := null;
  repfr_l_code_old   := null;
  repfr_l_code       := 'hierarchy.name';
  repfr_i18n_msg     := 'Hierarchy';
  repfr_vis          := 1;
  repfr_mand         := 0;
  repfr_type         := 4;
  repfr_cust_id      := null;
  repfr_cust_name    := 'Hierarchy list';
  --Si puo' scegliere la posizione del filtro nel report. Gli indici iniziano da 0
  --Se il campo e' null viene lasciato per ultimo
  repfr_posit_id_old := null;
  repfr_posit_id     := null;

  v_ret := inst_rep_add_fil ( rq_id, repfr_name, repfr_value, repfr_l_code_old, repfr_l_code, repfr_i18n_msg, repfr_vis,
                              repfr_mand, repfr_type, repfr_cust_name, repfr_posit_id_old, repfr_posit_id );

  --DELETE QUERY VISIBILITY AND REPORT VISIBILITY 01: BEGIN
  rv_name := 'AG-Core Hierarchy Scope';

  select count (1) into counter from r_visibility rv where lower ( rv.name ) = lower ( rv_name );
  if ( counter = 1 ) then
    select rv.id into rv_id from r_visibility rv where lower ( rv.name ) = lower ( rv_name );

    --QUERY VISIBILITY
    select count(1) into counter from r_query_visibility rqv where rqv.r_query = rq_id and rqv.r_visibility = rv_id;
    if ( counter = 1 ) then
      delete from r_query_visibility rqv where rqv.r_query = rq_id and rqv.r_visibility = rv_id;
    end if;
  end if;
end;
/
commit;

declare
  cur                  sys_refcursor;

  rv_id                numeric(16);
  counter              numeric(16);
begin
  select count(1) into counter from report r, report_visibility rv where r.id = rv.report
  and not exists ( select 1 from r_query_visibility tt where r.r_query = tt.r_query and rv.r_visibility = tt.r_visibility );
  if ( counter > 0 ) then
    open cur for
      select distinct rv.id from report r, report_visibility rv where r.id = rv.report
      and not exists ( select 1 from r_query_visibility tt where r.r_query = tt.r_query and rv.r_visibility = tt.r_visibility );
    loop
      fetch cur into rv_id;
      exit when cur%NOTFOUND;

      delete from report_visibility where id = rv_id;
    end loop;
    close cur;
  end if;
end;
/
commit;
