ALTER TABLE IB_TARGETS 
  ADD ISHRFEED CHAR(1);

ALTER TABLE IB_TARGETS
  ADD CONSTRAINT IB_TARGETS_ISHRFEED_CHK
  CHECK (ISHRFEED IN ('0','1'));

DROP TABLE IB_ACCOUNT_DELTAS;
DROP TABLE IB_GROUP_DELTAS;

CREATE TABLE IB_ACCOUNT_DELTAS
(
  ID                             BIGINT              GENERATED ALWAYS AS IDENTITY(START WITH 1 INCREMENT BY 1 NOCACHE) NOT NULL,
  CLIENTID                       VARCHAR(256)        NOT NULL,
  TARGETID                       VARCHAR(256)        NOT NULL,
  ACCOUNTID                      VARCHAR(256)        NOT NULL,
  OPERATIONTYPE                  VARCHAR(50)         NOT NULL,
  CREATEDTIME                    TIMESTAMP(6)        DEFAULT CURRENT_TIMESTAMP,
  DELTA_JSON                     BLOB(2G),
  REQUESTID                      VARCHAR(256)
)
IN &DATA_TABLESPACE
INDEX IN &INDEX_TABLESPACE
LONG IN &LOB_TABLESPACE
;

CREATE TABLE IB_GROUP_DELTAS
(
  ID                             BIGINT              GENERATED ALWAYS AS IDENTITY(START WITH 1 INCREMENT BY 1 NOCACHE) NOT NULL,
  CLIENTID                       VARCHAR(256)        NOT NULL,
  TARGETID                       VARCHAR(256)        NOT NULL,
  GROUPID                        VARCHAR(256)        NOT NULL,
  GROUPTYPE                      VARCHAR(50)         NOT NULL,
  OPERATIONTYPE                  VARCHAR(50)         NOT NULL,
  CREATEDTIME                    TIMESTAMP(6)        DEFAULT CURRENT_TIMESTAMP,
  DELTA_JSON                     BLOB(2G),
  REQUESTID                      VARCHAR(256),
  ISEXTERNALROLE                 CHAR(1)             CHECK (ISEXTERNALROLE IN (0,1)),
  HASRIGHTS                      CHAR(1)             CHECK (HASRIGHTS IN (0,1))
)
IN &DATA_TABLESPACE
INDEX IN &INDEX_TABLESPACE
LONG IN &LOB_TABLESPACE
;

ALTER TABLE IB_ACCOUNT_DELTAS ADD
  CONSTRAINT IB_ACCOUNT_DELTAS_PK
 PRIMARY KEY (ID);
CALL SYSPROC.ADMIN_CMD ( 'REORG TABLE IB_ACCOUNT_DELTAS' );

ALTER TABLE IB_GROUP_DELTAS ADD
  CONSTRAINT IB_GROUP_DELTAS_PK
 PRIMARY KEY (ID);
CALL SYSPROC.ADMIN_CMD ( 'REORG TABLE IB_GROUP_DELTAS' );

ALTER TABLE IB_ACCOUNT_DELTAS ADD
  CONSTRAINT IB_ACCOUNT_DEL_IB_TARGETS_FK
 FOREIGN KEY (TARGETID)
 REFERENCES IB_TARGETS (TARGETID)
;

ALTER TABLE IB_ACCOUNT_DELTAS ADD
  CONSTRAINT IB_ACCOUNT_DEL_IB_USERS_FK
 FOREIGN KEY (CLIENTID)
 REFERENCES IB_USERS (USERID)
;

ALTER TABLE IB_GROUP_DELTAS ADD
  CONSTRAINT IB_GROUP_DEL_IB_TARGETS_FK
 FOREIGN KEY (TARGETID)
 REFERENCES IB_TARGETS (TARGETID)
;

ALTER TABLE IB_GROUP_DELTAS ADD
  CONSTRAINT IB_GROUP_DEL_IB_USERS_FK
 FOREIGN KEY (CLIENTID)
 REFERENCES IB_USERS (USERID)
;

CREATE INDEX ACCOUNT_IDX ON IB_ACCOUNT_DELTAS
(CLIENTID, TARGETID, ACCOUNTID, OPERATIONTYPE);

CREATE INDEX GROUP_IDX ON IB_GROUP_DELTAS
(CLIENTID, TARGETID, GROUPID, GROUPTYPE, OPERATIONTYPE);
