ALTER TABLE IB_TARGETS 
  ADD ISHRFEED CHAR(1);

ALTER TABLE IB_TARGETS
  ADD CONSTRAINT IB_TARGETS_ISHRFEED_CHK
  CHECK (ISHRFEED IN ('0','1'));

DROP TABLE IB_ACCOUNT_DELTAS CASCADE CONSTRAINTS PURGE;
DROP TABLE IB_GROUP_DELTAS CASCADE CONSTRAINTS PURGE;

CREATE TABLE IB_ACCOUNT_DELTAS
(
  ID                             NUMBER(38)          GENERATED ALWAYS AS IDENTITY(START WITH 1 INCREMENT BY 1 NOCACHE) NOT NULL,
  CLIENTID                       VARCHAR2(256 BYTE)  NOT NULL,
  TARGETID                       VARCHAR2(256 BYTE)  NOT NULL,
  ACCOUNTID                      VARCHAR2(256 BYTE)  NOT NULL,
  OPERATIONTYPE                  VARCHAR2(50 BYTE)   NOT NULL,
  CREATEDTIME                    TIMESTAMP(6)        DEFAULT CURRENT_TIMESTAMP,
  DELTA_JSON                     BLOB,
  REQUESTID                      VARCHAR2(256 BYTE)
)
  LOB (DELTA_JSON) STORE AS
  (
    TABLESPACE   &LOB_TABLESPACE
    ENABLE       STORAGE IN ROW
    CHUNK        8192
    NOCACHE
    INDEX IB_ACCOUNT_DELT_DELTA_JSON_IDX
    (
      TABLESPACE &LOB_TABLESPACE
    )
  )
TABLESPACE &DATA_TABLESPACE
;

CREATE TABLE IB_GROUP_DELTAS
(
  ID                             NUMBER(38)          GENERATED ALWAYS AS IDENTITY(START WITH 1 INCREMENT BY 1 NOCACHE) NOT NULL,
  CLIENTID                       VARCHAR2(256 BYTE)  NOT NULL,
  TARGETID                       VARCHAR2(256 BYTE)  NOT NULL,
  GROUPID                        VARCHAR2(256 BYTE)  NOT NULL,
  GROUPTYPE                      VARCHAR2(50 BYTE)   NOT NULL,
  OPERATIONTYPE                  VARCHAR2(50 BYTE)   NOT NULL,
  CREATEDTIME                    TIMESTAMP(6)        DEFAULT CURRENT_TIMESTAMP,
  DELTA_JSON                     BLOB,
  REQUESTID                      VARCHAR2(256 BYTE),
  ISEXTERNALROLE                 CHAR(1 BYTE)        CHECK (ISEXTERNALROLE IN (0,1)),
  HASRIGHTS                      CHAR(1 BYTE)        CHECK (HASRIGHTS IN (0,1))
)
  LOB (DELTA_JSON) STORE AS
  (
    TABLESPACE   &LOB_TABLESPACE
    ENABLE       STORAGE IN ROW
    CHUNK        8192
    NOCACHE
    INDEX IB_GROUP_DELTAS_DELTA_JSON_IDX
    (
      TABLESPACE &LOB_TABLESPACE
    )
  )
TABLESPACE &DATA_TABLESPACE
;

ALTER TABLE IB_ACCOUNT_DELTAS ADD (
  CONSTRAINT IB_ACCOUNT_DELTAS_PK
 PRIMARY KEY
 (ID)
  USING INDEX TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS);

ALTER TABLE IB_GROUP_DELTAS ADD (
  CONSTRAINT IB_GROUP_DELTAS_PK
 PRIMARY KEY
 (ID)
  USING INDEX TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS);
  
ALTER TABLE IB_ACCOUNT_DELTAS ADD (
  CONSTRAINT IB_ACCOUNT_DEL_IB_TARGETS_FK
 FOREIGN KEY (TARGETID)
 REFERENCES IB_TARGETS (TARGETID)
);

ALTER TABLE IB_ACCOUNT_DELTAS ADD (
  CONSTRAINT IB_ACCOUNT_DEL_IB_USERS_FK
 FOREIGN KEY (CLIENTID)
 REFERENCES IB_USERS (USERID)
);

ALTER TABLE IB_GROUP_DELTAS ADD (
  CONSTRAINT IB_GROUP_DEL_IB_TARGETS_FK
 FOREIGN KEY (TARGETID)
 REFERENCES IB_TARGETS (TARGETID)
);

ALTER TABLE IB_GROUP_DELTAS ADD (
  CONSTRAINT IB_GROUP_DEL_IB_USERS_FK
 FOREIGN KEY (CLIENTID)
 REFERENCES IB_USERS (USERID)
);

CREATE INDEX ACCOUNT_IDX ON IB_ACCOUNT_DELTAS
(CLIENTID, TARGETID, ACCOUNTID, OPERATIONTYPE)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS;

CREATE INDEX GROUP_IDX ON IB_GROUP_DELTAS
(CLIENTID, TARGETID, GROUPID, GROUPTYPE, OPERATIONTYPE)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS;
