DROP TABLE IB_GROUP_DELTAS CASCADE CONSTRAINTS PURGE;

CREATE TABLE IB_GROUP_DELTAS
(
  ID                             NUMBER(38)          GENERATED ALWAYS AS IDENTITY(START WITH 1 INCREMENT BY 1 NOCACHE) NOT NULL,
  CLIENTID                       VARCHAR2(256 BYTE)  NOT NULL,
  TARGETID                       VARCHAR2(256 BYTE)  NOT NULL,
  GROUPID                        VARCHAR2(256 BYTE)  NOT NULL,
  GROUPTYPE                      VARCHAR2(50 BYTE)   NOT NULL,
  OPERATIONTYPE                  VARCHAR2(50 BYTE)   NOT NULL,
  CREATEDTIME                    TIMESTAMP(6)        DEFAULT CURRENT_TIMESTAMP,
  DELTA_JSON                     BLOB,
  REQUESTID                      VARCHAR2(256 BYTE),
  ISEXTERNALROLE                 CHAR(1 BYTE),
  HASRIGHTS                      CHAR(1 BYTE)
)
  LOB (DELTA_JSON) STORE AS
  (
    TABLESPACE   &LOB_TABLESPACE
    ENABLE       STORAGE IN ROW
    CHUNK        8192
    NOCACHE
    INDEX IB_GROUP_DELTAS_DELTA_JSON_IDX
    (
      TABLESPACE &LOB_TABLESPACE
    )
  )
TABLESPACE &DATA_TABLESPACE
;

ALTER TABLE IB_GROUP_DELTAS ADD (
  CONSTRAINT IB_GROUP_DELTAS_PK
 PRIMARY KEY
 (ID)
  USING INDEX TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS);

ALTER TABLE IB_GROUP_DELTAS ADD (
  CONSTRAINT IB_GROUP_DEL_IB_TARGETS_FK
 FOREIGN KEY (TARGETID)
 REFERENCES IB_TARGETS (TARGETID)
);

ALTER TABLE IB_GROUP_DELTAS ADD (
  CONSTRAINT IB_GROUP_DEL_IB_USERS_FK
 FOREIGN KEY (CLIENTID)
 REFERENCES IB_USERS (USERID)
);

ALTER TABLE IB_GROUP_DELTAS ADD
  CONSTRAINT IB_GRP_DEL_HASRIGHTS_CHK
 CHECK (HASRIGHTS IN ('0','1'));

ALTER TABLE IB_GROUP_DELTAS ADD
  CONSTRAINT IB_GRP_DEL_ISEXTERNALROLE_CHK
 CHECK (ISEXTERNALROLE IN ('0','1'));

CREATE INDEX GROUP_IDX ON IB_GROUP_DELTAS
(CLIENTID, TARGETID, GROUPID, GROUPTYPE, OPERATIONTYPE)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS;

COMMENT ON COLUMN IB_GROUP_DELTAS.ID IS
'DBMS_AUTO_SEQ: #START# 1 | #INCREMENT# 1 | #CACHE# NO | #CYCLE# NO | ';
