DROP TABLE IB_GROUP_DELTAS;

CREATE TABLE IB_GROUP_DELTAS
(
  ID                             BIGINT              GENERATED ALWAYS AS IDENTITY(START WITH 1 INCREMENT BY 1 NOCACHE) NOT NULL,
  CLIENTID                       VARCHAR(256)        NOT NULL,
  TARGETID                       VARCHAR(256)        NOT NULL,
  GROUPID                        VARCHAR(256)        NOT NULL,
  GROUPTYPE                      VARCHAR(50)         NOT NULL,
  OPERATIONTYPE                  VARCHAR(50)         NOT NULL,
  CREATEDTIME                    TIMESTAMP(6)        DEFAULT CURRENT_TIMESTAMP,
  DELTA_JSON                     BLOB(2G),
  REQUESTID                      VARCHAR(256),
  ISEXTERNALROLE                 CHAR(1),
  HASRIGHTS                      CHAR(1)
)
IN &DATA_TABLESPACE
INDEX IN &INDEX_TABLESPACE
LONG IN &LOB_TABLESPACE
;

ALTER TABLE IB_GROUP_DELTAS ADD
  CONSTRAINT IB_GROUP_DELTAS_PK
 PRIMARY KEY (ID);
CALL SYSPROC.ADMIN_CMD ( 'REORG TABLE IB_GROUP_DELTAS' );

ALTER TABLE IB_GROUP_DELTAS ADD
  CONSTRAINT IB_GROUP_DEL_IB_TARGETS_FK
 FOREIGN KEY (TARGETID)
 REFERENCES IB_TARGETS (TARGETID)
;

ALTER TABLE IB_GROUP_DELTAS ADD
  CONSTRAINT IB_GROUP_DEL_IB_USERS_FK
 FOREIGN KEY (CLIENTID)
 REFERENCES IB_USERS (USERID)
;

ALTER TABLE IB_GROUP_DELTAS ADD
  CONSTRAINT IB_GRP_DEL_HASRIGHTS_CHK
 CHECK (HASRIGHTS IN ('0','1'));

ALTER TABLE IB_GROUP_DELTAS ADD
  CONSTRAINT IB_GRP_DEL_ISEXTERNALROLE_CHK
 CHECK (ISEXTERNALROLE IN ('0','1'));

CREATE INDEX GROUP_IDX ON IB_GROUP_DELTAS
(CLIENTID, TARGETID, GROUPID, GROUPTYPE, OPERATIONTYPE);

COMMENT ON COLUMN IB_GROUP_DELTAS.ID IS
'DBMS_AUTO_SEQ: #START# 1 | #INCREMENT# 1 | #CACHE# NO | #CYCLE# NO | ';
