--CREATE A TABLE AND ITS CONSTRAINTS
set verify off
set serveroutput on
declare
  curr_user         varchar2(30);
  
  tab_name          varchar2(30) := 'IB_TARGET_RESOURCE_SCHEMA_EXT';
  dml_def           varchar2(4000);
  
  counter           number(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from all_tables t where t.owner = curr_user and t.table_name = tab_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'CREATE TABLE IB_TARGET_RESOURCE_SCHEMA_EXT
(
  URN                            VARCHAR2(256 BYTE)       NOT NULL,
  NAME                           VARCHAR2(100 BYTE),
  PROFILE_NAME                   VARCHAR2(256 BYTE)       NOT NULL,
  RESOURCETYPE                   VARCHAR2(256 BYTE)       NOT NULL,
  DEFINITION                     CLOB,
  ATTRIBUTEMAP                   CLOB
)
TABLESPACE &DATA_TABLESPACE
  LOB (ATTRIBUTEMAP) STORE AS
  (
    TABLESPACE   &LOB_TABLESPACE
    ENABLE       STORAGE IN ROW
    CHUNK        8192
    NOCACHE
    INDEX IB_TAR_RES_EX_ATTRIBUTEMAP_IDX
    (
      TABLESPACE &LOB_TABLESPACE
    )
  )
  LOB (DEFINITION) STORE AS
  (
    TABLESPACE   &LOB_TABLESPACE
    ENABLE       STORAGE IN ROW
    CHUNK        8192
    NOCACHE
    INDEX IB_TAR_RES_EX_DEFINITION_IDX
    (
      TABLESPACE &LOB_TABLESPACE
    )
  )
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE IB_TARGET_RESOURCE_SCHEMA_EXT ADD (
  CONSTRAINT IB_TRGT_RSRCE_SCHEMA_EXT_PK
 PRIMARY KEY
 (URN)
  USING INDEX TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
set serveroutput off
set verify on


comment on column IB_TARGET_RESOURCE_SCHEMA_EXT.ATTRIBUTEMAP
  is 'DB2_CLOB_SIZE: 1M';

comment on column IB_TARGET_RESOURCE_SCHEMA_EXT.DEFINITION
  is 'DB2_CLOB_SIZE: 1M';


--CREATE AN INDEX
set verify off
set serveroutput on
declare
  curr_user         varchar2(30);
  
  idx_name          varchar2(30) := 'SCHEMA_IDX';
  dml_def           varchar2(4000);
  
  counter           number(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from all_indexes t where t.owner = curr_user and t.index_name = idx_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'CREATE INDEX SCHEMA_IDX ON IB_TARGET_RESOURCE_SCHEMA_EXT
(PROFILE_NAME)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
set serveroutput off
set verify on


--CREATE AN INDEX
set verify off
set serveroutput on
declare
  curr_user         varchar2(30);
  
  idx_name          varchar2(30) := 'SCHEMA_NAME_IDX';
  dml_def           varchar2(4000);
  
  counter           number(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from all_indexes t where t.owner = curr_user and t.index_name = idx_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'CREATE INDEX SCHEMA_NAME_IDX ON IB_TARGET_RESOURCE_SCHEMA_EXT
(NAME)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
set serveroutput off
set verify on
