--CREATE A TABLE AND ITS CONSTRAINTS
set verify off
set serveroutput on
declare
  curr_user         varchar2(30);
  
  tab_name          varchar2(30) := 'IB_TARGET_RESOURCE_TYPE';
  dml_def           varchar2(4000);
  
  counter           number(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from all_tables t where t.owner = curr_user and t.table_name = tab_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'CREATE TABLE IB_TARGET_RESOURCE_TYPE
(
  PROFILE_NAME                   VARCHAR2(256)       NOT NULL,
  ID                             VARCHAR2(256)       NOT NULL,
  ENDPOINT                       VARCHAR2(256)       NOT NULL,
  CATEGORY                       VARCHAR2(50)        NOT NULL,
  DEFINITION                     CLOB
)
TABLESPACE &DATA_TABLESPACE
  LOB (DEFINITION) STORE AS
  (
    TABLESPACE   &LOB_TABLESPACE
    ENABLE       STORAGE IN ROW
    CHUNK        8192
    NOCACHE
    INDEX IB_TAR_RES_T_DEFINITION_IDX
    (
      TABLESPACE &LOB_TABLESPACE
    )
  )
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE IB_TARGET_RESOURCE_TYPE ADD (
  CONSTRAINT IB_TARGET_RESOURCE_TYPE_PK
 PRIMARY KEY
 (ID)
  USING INDEX TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
set serveroutput off
set verify on


comment on column IB_TARGET_RESOURCE_TYPE.DEFINITION
  is 'DB2_CLOB_SIZE: 1M';


--CREATE AN INDEX
set verify off
set serveroutput on
declare
  curr_user         varchar2(30);
  
  idx_name          varchar2(30) := 'RESOURCE_TYPE_IDX';
  dml_def           varchar2(4000);
  
  counter           number(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from all_indexes t where t.owner = curr_user and t.index_name = idx_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'CREATE INDEX RESOURCE_TYPE_IDX ON IB_TARGET_RESOURCE_TYPE
(PROFILE_NAME)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
set serveroutput off
set verify on
