CREATE TABLE QRZ7_BLOB_TRIGGERS
(
  SCHED_NAME                     VARCHAR2(120 CHAR)  NOT NULL,
  TRIGGER_NAME                   VARCHAR2(200 CHAR)  NOT NULL,
  TRIGGER_GROUP                  VARCHAR2(200 CHAR)  NOT NULL,
  BLOB_DATA                      BLOB
)
  LOB (BLOB_DATA) STORE AS
  (
    TABLESPACE   &LOB_TABLESPACE
    ENABLE       STORAGE IN ROW
    CHUNK        8192
    NOCACHE
    INDEX QRZ7_BLOB_TRIGGE_BLOB_DATA_IDX
    (
      TABLESPACE &LOB_TABLESPACE
    )
  )
TABLESPACE &DATA_TABLESPACE
;

CREATE TABLE QRZ7_CALENDARS
(
  SCHED_NAME                     VARCHAR2(120 CHAR)  NOT NULL,
  CALENDAR_NAME                  VARCHAR2(200 CHAR)  NOT NULL,
  CALENDAR                       BLOB                NOT NULL
)
  LOB (CALENDAR) STORE AS
  (
    TABLESPACE   &LOB_TABLESPACE
    ENABLE       STORAGE IN ROW
    CHUNK        8192
    NOCACHE
    INDEX QRZ7_CALENDARS_CALENDAR_IDX
    (
      TABLESPACE &LOB_TABLESPACE
    )
  )
TABLESPACE &DATA_TABLESPACE
;

CREATE TABLE QRZ7_CRON_TRIGGERS
(
  SCHED_NAME                     VARCHAR2(120 CHAR)  NOT NULL,
  TRIGGER_NAME                   VARCHAR2(200 CHAR)  NOT NULL,
  TRIGGER_GROUP                  VARCHAR2(200 CHAR)  NOT NULL,
  CRON_EXPRESSION                VARCHAR2(120 CHAR)  NOT NULL,
  TIME_ZONE_ID                   VARCHAR2(80 CHAR)
)
TABLESPACE &DATA_TABLESPACE
;

CREATE TABLE QRZ7_FIRED_TRIGGERS
(
  SCHED_NAME                     VARCHAR2(120 CHAR)  NOT NULL,
  ENTRY_ID                       VARCHAR2(95 CHAR)   NOT NULL,
  TRIGGER_NAME                   VARCHAR2(200 CHAR)  NOT NULL,
  TRIGGER_GROUP                  VARCHAR2(200 CHAR)  NOT NULL,
  INSTANCE_NAME                  VARCHAR2(200 CHAR)  NOT NULL,
  FIRED_TIME                     NUMBER(13)          NOT NULL,
  SCHED_TIME                     NUMBER(13)          NOT NULL,
  PRIORITY                       NUMBER(13)          NOT NULL,
  STATE                          VARCHAR2(16 CHAR)   NOT NULL,
  JOB_NAME                       VARCHAR2(200 CHAR),
  JOB_GROUP                      VARCHAR2(200 CHAR),
  IS_NONCONCURRENT               VARCHAR2(1 CHAR),
  REQUESTS_RECOVERY              VARCHAR2(1 CHAR)
)
TABLESPACE &DATA_TABLESPACE
;

CREATE TABLE QRZ7_JOB_DETAILS
(
  SCHED_NAME                     VARCHAR2(120 CHAR)  NOT NULL,
  JOB_NAME                       VARCHAR2(200 CHAR)  NOT NULL,
  JOB_GROUP                      VARCHAR2(200 CHAR)  NOT NULL,
  DESCRIPTION                    VARCHAR2(250 CHAR),
  JOB_CLASS_NAME                 VARCHAR2(250 CHAR)  NOT NULL,
  IS_DURABLE                     VARCHAR2(1 CHAR)    NOT NULL,
  IS_NONCONCURRENT               VARCHAR2(1 CHAR)    NOT NULL,
  IS_UPDATE_DATA                 VARCHAR2(1 CHAR)    NOT NULL,
  REQUESTS_RECOVERY              VARCHAR2(1 CHAR)    NOT NULL,
  JOB_DATA                       BLOB
)
  LOB (JOB_DATA) STORE AS
  (
    TABLESPACE   &LOB_TABLESPACE
    ENABLE       STORAGE IN ROW
    CHUNK        8192
    NOCACHE
    INDEX QRZ7_JOB_DETAILS_JOB_DATA_IDX
    (
      TABLESPACE &LOB_TABLESPACE
    )
  )
TABLESPACE &DATA_TABLESPACE
;

CREATE TABLE QRZ7_LOCKS
(
  SCHED_NAME                     VARCHAR2(120 CHAR)  NOT NULL,
  LOCK_NAME                      VARCHAR2(40 CHAR)   NOT NULL
)
TABLESPACE &DATA_TABLESPACE
;

CREATE TABLE QRZ7_PAUSED_TRIGGER_GRPS
(
  SCHED_NAME                     VARCHAR2(120 CHAR)  NOT NULL,
  TRIGGER_GROUP                  VARCHAR2(200 CHAR)  NOT NULL
)
TABLESPACE &DATA_TABLESPACE
;

CREATE TABLE QRZ7_SCHEDULER_STATE
(
  SCHED_NAME                     VARCHAR2(120 CHAR)  NOT NULL,
  INSTANCE_NAME                  VARCHAR2(200 CHAR)  NOT NULL,
  LAST_CHECKIN_TIME              NUMBER(13)          NOT NULL,
  CHECKIN_INTERVAL               NUMBER(13)          NOT NULL
)
TABLESPACE &DATA_TABLESPACE
;

CREATE TABLE QRZ7_SIMPLE_TRIGGERS
(
  SCHED_NAME                     VARCHAR2(120 CHAR)  NOT NULL,
  TRIGGER_NAME                   VARCHAR2(200 CHAR)  NOT NULL,
  TRIGGER_GROUP                  VARCHAR2(200 CHAR)  NOT NULL,
  REPEAT_COUNT                   NUMBER(7)           NOT NULL,
  REPEAT_INTERVAL                NUMBER(12)          NOT NULL,
  TIMES_TRIGGERED                NUMBER(10)          NOT NULL
)
TABLESPACE &DATA_TABLESPACE
;

CREATE TABLE QRZ7_SIMPROP_TRIGGERS
(
  SCHED_NAME                     VARCHAR2(120 CHAR)  NOT NULL,
  TRIGGER_NAME                   VARCHAR2(200 CHAR)  NOT NULL,
  TRIGGER_GROUP                  VARCHAR2(200 CHAR)  NOT NULL,
  STR_PROP_1                     VARCHAR2(512 CHAR),
  STR_PROP_2                     VARCHAR2(512 CHAR),
  STR_PROP_3                     VARCHAR2(512 CHAR),
  INT_PROP_1                     NUMBER(10),
  INT_PROP_2                     NUMBER(10),
  LONG_PROP_1                    NUMBER(13),
  LONG_PROP_2                    NUMBER(13),
  DEC_PROP_1                     NUMBER(13,4),
  DEC_PROP_2                     NUMBER(13,4),
  BOOL_PROP_1                    VARCHAR2(1 CHAR),
  BOOL_PROP_2                    VARCHAR2(1 CHAR)
)
TABLESPACE &DATA_TABLESPACE
;

CREATE TABLE QRZ7_TRIGGERS
(
  SCHED_NAME                     VARCHAR2(120 CHAR)  NOT NULL,
  TRIGGER_NAME                   VARCHAR2(200 CHAR)  NOT NULL,
  TRIGGER_GROUP                  VARCHAR2(200 CHAR)  NOT NULL,
  JOB_NAME                       VARCHAR2(200 CHAR)  NOT NULL,
  JOB_GROUP                      VARCHAR2(200 CHAR)  NOT NULL,
  DESCRIPTION                    VARCHAR2(250 CHAR),
  NEXT_FIRE_TIME                 NUMBER(13),
  PREV_FIRE_TIME                 NUMBER(13),
  PRIORITY                       NUMBER(13),
  TRIGGER_STATE                  VARCHAR2(16 CHAR)   NOT NULL,
  TRIGGER_TYPE                   VARCHAR2(8 CHAR)    NOT NULL,
  START_TIME                     NUMBER(13)          NOT NULL,
  END_TIME                       NUMBER(13),
  CALENDAR_NAME                  VARCHAR2(200 CHAR),
  MISFIRE_INSTR                  NUMBER(2),
  JOB_DATA                       BLOB
)
  LOB (JOB_DATA) STORE AS
  (
    TABLESPACE   &LOB_TABLESPACE
    ENABLE       STORAGE IN ROW
    CHUNK        8192
    NOCACHE
    INDEX QRZ7_TRIGGERS_JOB_DATA_IDX
    (
      TABLESPACE &LOB_TABLESPACE
    )
  )
TABLESPACE &DATA_TABLESPACE
;

ALTER TABLE QRZ7_BLOB_TRIGGERS ADD (
  CONSTRAINT QRZ7_BLOB_TRIG_PK
 PRIMARY KEY
 (SCHED_NAME, TRIGGER_NAME, TRIGGER_GROUP)
  USING INDEX TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS);

ALTER TABLE QRZ7_CALENDARS ADD (
  CONSTRAINT QRZ7_CALENDARS_PK
 PRIMARY KEY
 (SCHED_NAME, CALENDAR_NAME)
  USING INDEX TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS);

ALTER TABLE QRZ7_CRON_TRIGGERS ADD (
  CONSTRAINT QRZ7_CRON_TRIG_PK
 PRIMARY KEY
 (SCHED_NAME, TRIGGER_NAME, TRIGGER_GROUP)
  USING INDEX TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS);

ALTER TABLE QRZ7_FIRED_TRIGGERS ADD (
  CONSTRAINT QRZ7_FIRED_TRIGGER_PK
 PRIMARY KEY
 (SCHED_NAME, ENTRY_ID)
  USING INDEX TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS);

ALTER TABLE QRZ7_JOB_DETAILS ADD (
  CONSTRAINT QRZ7_JOB_DETAILS_PK
 PRIMARY KEY
 (SCHED_NAME, JOB_NAME, JOB_GROUP)
  USING INDEX TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS);

ALTER TABLE QRZ7_LOCKS ADD (
  CONSTRAINT QRZ7_LOCKS_PK
 PRIMARY KEY
 (SCHED_NAME, LOCK_NAME)
  USING INDEX TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS);

ALTER TABLE QRZ7_PAUSED_TRIGGER_GRPS ADD (
  CONSTRAINT QRZ7_PAUSED_TRIG_GRPS_PK
 PRIMARY KEY
 (SCHED_NAME, TRIGGER_GROUP)
  USING INDEX TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS);

ALTER TABLE QRZ7_SCHEDULER_STATE ADD (
  CONSTRAINT QRZ7_SCHEDULER_STATE_PK
 PRIMARY KEY
 (SCHED_NAME, INSTANCE_NAME)
  USING INDEX TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS);

ALTER TABLE QRZ7_SIMPLE_TRIGGERS ADD (
  CONSTRAINT QRZ7_SIMPLE_TRIG_PK
 PRIMARY KEY
 (SCHED_NAME, TRIGGER_NAME, TRIGGER_GROUP)
  USING INDEX TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS);

ALTER TABLE QRZ7_SIMPROP_TRIGGERS ADD (
  CONSTRAINT QRZ7_SIMPROP_TRIG_PK
 PRIMARY KEY
 (SCHED_NAME, TRIGGER_NAME, TRIGGER_GROUP)
  USING INDEX TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS);

ALTER TABLE QRZ7_TRIGGERS ADD (
  CONSTRAINT QRZ7_TRIGGERS_PK
 PRIMARY KEY
 (SCHED_NAME, TRIGGER_NAME, TRIGGER_GROUP)
  USING INDEX TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS);

ALTER TABLE QRZ7_BLOB_TRIGGERS ADD (
  CONSTRAINT QRZ7_BLOB_TRIG_TO_TRIG_FK
 FOREIGN KEY (SCHED_NAME, TRIGGER_NAME, TRIGGER_GROUP)
 REFERENCES QRZ7_TRIGGERS (SCHED_NAME, TRIGGER_NAME, TRIGGER_GROUP)
);

ALTER TABLE QRZ7_CRON_TRIGGERS ADD (
  CONSTRAINT QRZ7_CRON_TRIG_TO_TRIG_FK
 FOREIGN KEY (SCHED_NAME, TRIGGER_NAME, TRIGGER_GROUP)
 REFERENCES QRZ7_TRIGGERS (SCHED_NAME, TRIGGER_NAME, TRIGGER_GROUP)
);

ALTER TABLE QRZ7_SIMPLE_TRIGGERS ADD (
  CONSTRAINT QRZ7_SIMPLE_TRIG_TO_TRIG_FK
 FOREIGN KEY (SCHED_NAME, TRIGGER_NAME, TRIGGER_GROUP)
 REFERENCES QRZ7_TRIGGERS (SCHED_NAME, TRIGGER_NAME, TRIGGER_GROUP)
);

ALTER TABLE QRZ7_SIMPROP_TRIGGERS ADD (
  CONSTRAINT QRZ7_SIMPROP_TRIG_TO_TRIG_FK
 FOREIGN KEY (SCHED_NAME, TRIGGER_NAME, TRIGGER_GROUP)
 REFERENCES QRZ7_TRIGGERS (SCHED_NAME, TRIGGER_NAME, TRIGGER_GROUP)
);

ALTER TABLE QRZ7_TRIGGERS ADD (
  CONSTRAINT QRZ7_TRIGGER_TO_JOBS_FK
 FOREIGN KEY (SCHED_NAME, JOB_NAME, JOB_GROUP)
 REFERENCES QRZ7_JOB_DETAILS (SCHED_NAME, JOB_NAME, JOB_GROUP)
);

CREATE INDEX IDX_QRZ7_FT_INST_JOB_REQ_RCVRY ON QRZ7_FIRED_TRIGGERS
(SCHED_NAME, INSTANCE_NAME, REQUESTS_RECOVERY)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS;

CREATE INDEX IDX_QRZ7_FT_J_G ON QRZ7_FIRED_TRIGGERS
(SCHED_NAME, JOB_NAME, JOB_GROUP)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS;

CREATE INDEX IDX_QRZ7_FT_JG ON QRZ7_FIRED_TRIGGERS
(SCHED_NAME, JOB_GROUP)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS;

CREATE INDEX IDX_QRZ7_FT_T_G ON QRZ7_FIRED_TRIGGERS
(SCHED_NAME, TRIGGER_NAME, TRIGGER_GROUP)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS;

CREATE INDEX IDX_QRZ7_FT_TG ON QRZ7_FIRED_TRIGGERS
(SCHED_NAME, TRIGGER_GROUP)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS;

CREATE INDEX IDX_QRZ7_FT_TRIG_INST_NAME ON QRZ7_FIRED_TRIGGERS
(SCHED_NAME, INSTANCE_NAME)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS;

CREATE INDEX IDX_QRZ7_J_GRP ON QRZ7_JOB_DETAILS
(SCHED_NAME, JOB_GROUP)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS;

CREATE INDEX IDX_QRZ7_J_REQ_RECOVERY ON QRZ7_JOB_DETAILS
(SCHED_NAME, REQUESTS_RECOVERY)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS;

CREATE INDEX IDX_QRZ7_T_C ON QRZ7_TRIGGERS
(SCHED_NAME, CALENDAR_NAME)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS;

CREATE INDEX IDX_QRZ7_T_G ON QRZ7_TRIGGERS
(SCHED_NAME, TRIGGER_GROUP)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS;

CREATE INDEX IDX_QRZ7_T_J ON QRZ7_TRIGGERS
(SCHED_NAME, JOB_NAME, JOB_GROUP)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS;

CREATE INDEX IDX_QRZ7_T_JG ON QRZ7_TRIGGERS
(SCHED_NAME, JOB_GROUP)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS;

CREATE INDEX IDX_QRZ7_T_NEXT_FIRE_TIME ON QRZ7_TRIGGERS
(SCHED_NAME, NEXT_FIRE_TIME)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS;

CREATE INDEX IDX_QRZ7_T_NFT_MISFIRE ON QRZ7_TRIGGERS
(SCHED_NAME, MISFIRE_INSTR, NEXT_FIRE_TIME)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS;

CREATE INDEX IDX_QRZ7_T_NFT_ST ON QRZ7_TRIGGERS
(SCHED_NAME, TRIGGER_STATE, NEXT_FIRE_TIME)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS;

CREATE INDEX IDX_QRZ7_T_NFT_ST_MISFIRE ON QRZ7_TRIGGERS
(SCHED_NAME, MISFIRE_INSTR, NEXT_FIRE_TIME, TRIGGER_STATE)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS;

CREATE INDEX IDX_QRZ7_T_NFT_ST_MISFIRE_GRP ON QRZ7_TRIGGERS
(SCHED_NAME, MISFIRE_INSTR, NEXT_FIRE_TIME, TRIGGER_GROUP, TRIGGER_STATE)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS;

CREATE INDEX IDX_QRZ7_T_N_G_STATE ON QRZ7_TRIGGERS
(SCHED_NAME, TRIGGER_GROUP, TRIGGER_STATE)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS;

CREATE INDEX IDX_QRZ7_T_N_STATE ON QRZ7_TRIGGERS
(SCHED_NAME, TRIGGER_NAME, TRIGGER_GROUP, TRIGGER_STATE)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS;

CREATE INDEX IDX_QRZ7_T_STATE ON QRZ7_TRIGGERS
(SCHED_NAME, TRIGGER_STATE)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS;


COMMENT ON COLUMN QRZ7_FIRED_TRIGGERS.IS_NONCONCURRENT IS
'BOOLEAN';

COMMENT ON COLUMN QRZ7_FIRED_TRIGGERS.REQUESTS_RECOVERY IS
'BOOLEAN';

COMMENT ON COLUMN QRZ7_JOB_DETAILS.IS_DURABLE IS
'BOOLEAN';

COMMENT ON COLUMN QRZ7_JOB_DETAILS.IS_NONCONCURRENT IS
'BOOLEAN';

COMMENT ON COLUMN QRZ7_JOB_DETAILS.IS_UPDATE_DATA IS
'BOOLEAN';

COMMENT ON COLUMN QRZ7_JOB_DETAILS.REQUESTS_RECOVERY IS
'BOOLEAN';

COMMENT ON COLUMN QRZ7_SIMPROP_TRIGGERS.BOOL_PROP_1 IS
'BOOLEAN';

COMMENT ON COLUMN QRZ7_SIMPROP_TRIGGERS.BOOL_PROP_2 IS
'BOOLEAN';
