--CREATE A QUARTZ SCHEDULER
set verify off
set serveroutput on
declare
  curr_user         varchar(30);

  sk_group_name     varchar(30) := 'QRZ7_';
  dml_def           varchar(4000);

  counter           numeric(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from sysibm.tables t where ( t.table_type = 'BASE TABLE' or t.table_type is null ) and lower ( t.table_schema ) = lower ( curr_user ) and upper ( t.table_name ) like upper ( sk_group_name || '%' );
  if ( counter > 0 ) then
    return;
  end if;

  dml_def :=
'CREATE TABLE QRZ7_BLOB_TRIGGERS
(
  SCHED_NAME                     VARCHAR(120)        NOT NULL,
  TRIGGER_NAME                   VARCHAR(200)        NOT NULL,
  TRIGGER_GROUP                  VARCHAR(200)        NOT NULL,
  BLOB_DATA                      BLOB(2G)
)
IN &DATA_TABLESPACE
INDEX IN &INDEX_TABLESPACE
LONG IN &LOB_TABLESPACE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'CREATE TABLE QRZ7_CALENDARS
(
  SCHED_NAME                     VARCHAR(120)        NOT NULL,
  CALENDAR_NAME                  VARCHAR(200)        NOT NULL,
  CALENDAR                       BLOB(2G)            NOT NULL
)
IN &DATA_TABLESPACE
INDEX IN &INDEX_TABLESPACE
LONG IN &LOB_TABLESPACE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'CREATE TABLE QRZ7_CRON_TRIGGERS
(
  SCHED_NAME                     VARCHAR(120)        NOT NULL,
  TRIGGER_NAME                   VARCHAR(200)        NOT NULL,
  TRIGGER_GROUP                  VARCHAR(200)        NOT NULL,
  CRON_EXPRESSION                VARCHAR(120)        NOT NULL,
  TIME_ZONE_ID                   VARCHAR(80)
)
IN &DATA_TABLESPACE
INDEX IN &INDEX_TABLESPACE
LONG IN &LOB_TABLESPACE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'CREATE TABLE QRZ7_FIRED_TRIGGERS
(
  SCHED_NAME                     VARCHAR(120)        NOT NULL,
  ENTRY_ID                       VARCHAR(95)         NOT NULL,
  TRIGGER_NAME                   VARCHAR(200)        NOT NULL,
  TRIGGER_GROUP                  VARCHAR(200)        NOT NULL,
  INSTANCE_NAME                  VARCHAR(200)        NOT NULL,
  FIRED_TIME                     NUMERIC(13)         NOT NULL,
  SCHED_TIME                     NUMERIC(13)         NOT NULL,
  PRIORITY                       NUMERIC(13)         NOT NULL,
  STATE                          VARCHAR(16)         NOT NULL,
  JOB_NAME                       VARCHAR(200),
  JOB_GROUP                      VARCHAR(200),
  IS_NONCONCURRENT               VARCHAR(1),
  REQUESTS_RECOVERY              VARCHAR(1)
)
IN &DATA_TABLESPACE
INDEX IN &INDEX_TABLESPACE
LONG IN &LOB_TABLESPACE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'CREATE TABLE QRZ7_JOB_DETAILS
(
  SCHED_NAME                     VARCHAR(120)        NOT NULL,
  JOB_NAME                       VARCHAR(200)        NOT NULL,
  JOB_GROUP                      VARCHAR(200)        NOT NULL,
  DESCRIPTION                    VARCHAR(250),
  JOB_CLASS_NAME                 VARCHAR(250)        NOT NULL,
  IS_DURABLE                     VARCHAR(1)          NOT NULL,
  IS_NONCONCURRENT               VARCHAR(1)          NOT NULL,
  IS_UPDATE_DATA                 VARCHAR(1)          NOT NULL,
  REQUESTS_RECOVERY              VARCHAR(1)          NOT NULL,
  JOB_DATA                       BLOB(2G)
)
IN &DATA_TABLESPACE
INDEX IN &INDEX_TABLESPACE
LONG IN &LOB_TABLESPACE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'CREATE TABLE QRZ7_LOCKS
(
  SCHED_NAME                     VARCHAR(120)        NOT NULL,
  LOCK_NAME                      VARCHAR(40)         NOT NULL
)
IN &DATA_TABLESPACE
INDEX IN &INDEX_TABLESPACE
LONG IN &LOB_TABLESPACE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'CREATE TABLE QRZ7_PAUSED_TRIGGER_GRPS
(
  SCHED_NAME                     VARCHAR(120)        NOT NULL,
  TRIGGER_GROUP                  VARCHAR(200)        NOT NULL
)
IN &DATA_TABLESPACE
INDEX IN &INDEX_TABLESPACE
LONG IN &LOB_TABLESPACE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'CREATE TABLE QRZ7_SCHEDULER_STATE
(
  SCHED_NAME                     VARCHAR(120)        NOT NULL,
  INSTANCE_NAME                  VARCHAR(200)        NOT NULL,
  LAST_CHECKIN_TIME              NUMERIC(13)         NOT NULL,
  CHECKIN_INTERVAL               NUMERIC(13)         NOT NULL
)
IN &DATA_TABLESPACE
INDEX IN &INDEX_TABLESPACE
LONG IN &LOB_TABLESPACE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'CREATE TABLE QRZ7_SIMPLE_TRIGGERS
(
  SCHED_NAME                     VARCHAR(120)        NOT NULL,
  TRIGGER_NAME                   VARCHAR(200)        NOT NULL,
  TRIGGER_GROUP                  VARCHAR(200)        NOT NULL,
  REPEAT_COUNT                   NUMERIC(7)          NOT NULL,
  REPEAT_INTERVAL                NUMERIC(12)         NOT NULL,
  TIMES_TRIGGERED                NUMERIC(10)         NOT NULL
)
IN &DATA_TABLESPACE
INDEX IN &INDEX_TABLESPACE
LONG IN &LOB_TABLESPACE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'CREATE TABLE QRZ7_SIMPROP_TRIGGERS
(
  SCHED_NAME                     VARCHAR(120)        NOT NULL,
  TRIGGER_NAME                   VARCHAR(200)        NOT NULL,
  TRIGGER_GROUP                  VARCHAR(200)        NOT NULL,
  STR_PROP_1                     VARCHAR(512),
  STR_PROP_2                     VARCHAR(512),
  STR_PROP_3                     VARCHAR(512),
  INT_PROP_1                     NUMERIC(10),
  INT_PROP_2                     NUMERIC(10),
  LONG_PROP_1                    NUMERIC(13),
  LONG_PROP_2                    NUMERIC(13),
  DEC_PROP_1                     NUMERIC(13,4),
  DEC_PROP_2                     NUMERIC(13,4),
  BOOL_PROP_1                    VARCHAR(1),
  BOOL_PROP_2                    VARCHAR(1)
)
IN &DATA_TABLESPACE
INDEX IN &INDEX_TABLESPACE
LONG IN &LOB_TABLESPACE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'CREATE TABLE QRZ7_TRIGGERS
(
  SCHED_NAME                     VARCHAR(120)        NOT NULL,
  TRIGGER_NAME                   VARCHAR(200)        NOT NULL,
  TRIGGER_GROUP                  VARCHAR(200)        NOT NULL,
  JOB_NAME                       VARCHAR(200)        NOT NULL,
  JOB_GROUP                      VARCHAR(200)        NOT NULL,
  DESCRIPTION                    VARCHAR(250),
  NEXT_FIRE_TIME                 NUMERIC(13),
  PREV_FIRE_TIME                 NUMERIC(13),
  PRIORITY                       NUMERIC(13),
  TRIGGER_STATE                  VARCHAR(16)         NOT NULL,
  TRIGGER_TYPE                   VARCHAR(8)          NOT NULL,
  START_TIME                     NUMERIC(13)         NOT NULL,
  END_TIME                       NUMERIC(13),
  CALENDAR_NAME                  VARCHAR(200),
  MISFIRE_INSTR                  NUMERIC(2),
  JOB_DATA                       BLOB(2G)
)
IN &DATA_TABLESPACE
INDEX IN &INDEX_TABLESPACE
LONG IN &LOB_TABLESPACE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE QRZ7_BLOB_TRIGGERS ADD
  CONSTRAINT QRZ7_BLOB_TRIG_PK
 PRIMARY KEY (SCHED_NAME, TRIGGER_NAME, TRIGGER_GROUP)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE QRZ7_CALENDARS ADD
  CONSTRAINT QRZ7_CALENDARS_PK
 PRIMARY KEY (SCHED_NAME, CALENDAR_NAME)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE QRZ7_CRON_TRIGGERS ADD
  CONSTRAINT QRZ7_CRON_TRIG_PK
 PRIMARY KEY (SCHED_NAME, TRIGGER_NAME, TRIGGER_GROUP)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE QRZ7_FIRED_TRIGGERS ADD
  CONSTRAINT QRZ7_FIRED_TRIGGER_PK
 PRIMARY KEY (SCHED_NAME, ENTRY_ID)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE QRZ7_JOB_DETAILS ADD
  CONSTRAINT QRZ7_JOB_DETAILS_PK
 PRIMARY KEY (SCHED_NAME, JOB_NAME, JOB_GROUP)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE QRZ7_LOCKS ADD
  CONSTRAINT QRZ7_LOCKS_PK
 PRIMARY KEY (SCHED_NAME, LOCK_NAME)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE QRZ7_PAUSED_TRIGGER_GRPS ADD
  CONSTRAINT QRZ7_PAUSED_TRIG_GRPS_PK
 PRIMARY KEY (SCHED_NAME, TRIGGER_GROUP)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE QRZ7_SCHEDULER_STATE ADD
  CONSTRAINT QRZ7_SCHEDULER_STATE_PK
 PRIMARY KEY (SCHED_NAME, INSTANCE_NAME)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE QRZ7_SIMPLE_TRIGGERS ADD
  CONSTRAINT QRZ7_SIMPLE_TRIG_PK
 PRIMARY KEY (SCHED_NAME, TRIGGER_NAME, TRIGGER_GROUP)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE QRZ7_SIMPROP_TRIGGERS ADD
  CONSTRAINT QRZ7_SIMPROP_TRIG_PK
 PRIMARY KEY (SCHED_NAME, TRIGGER_NAME, TRIGGER_GROUP)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE QRZ7_TRIGGERS ADD
  CONSTRAINT QRZ7_TRIGGERS_PK
 PRIMARY KEY (SCHED_NAME, TRIGGER_NAME, TRIGGER_GROUP)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE QRZ7_BLOB_TRIGGERS ADD
  CONSTRAINT QRZ7_BLOB_TRIG_TO_TRIG_FK
 FOREIGN KEY (SCHED_NAME, TRIGGER_NAME, TRIGGER_GROUP)
 REFERENCES QRZ7_TRIGGERS (SCHED_NAME, TRIGGER_NAME, TRIGGER_GROUP)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE QRZ7_CRON_TRIGGERS ADD
  CONSTRAINT QRZ7_CRON_TRIG_TO_TRIG_FK
 FOREIGN KEY (SCHED_NAME, TRIGGER_NAME, TRIGGER_GROUP)
 REFERENCES QRZ7_TRIGGERS (SCHED_NAME, TRIGGER_NAME, TRIGGER_GROUP)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE QRZ7_SIMPLE_TRIGGERS ADD
  CONSTRAINT QRZ7_SIMPLE_TRIG_TO_TRIG_FK
 FOREIGN KEY (SCHED_NAME, TRIGGER_NAME, TRIGGER_GROUP)
 REFERENCES QRZ7_TRIGGERS (SCHED_NAME, TRIGGER_NAME, TRIGGER_GROUP)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE QRZ7_SIMPROP_TRIGGERS ADD
  CONSTRAINT QRZ7_SIMPROP_TRIG_TO_TRIG_FK
 FOREIGN KEY (SCHED_NAME, TRIGGER_NAME, TRIGGER_GROUP)
 REFERENCES QRZ7_TRIGGERS (SCHED_NAME, TRIGGER_NAME, TRIGGER_GROUP)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE QRZ7_TRIGGERS ADD
  CONSTRAINT QRZ7_TRIGGER_TO_JOBS_FK
 FOREIGN KEY (SCHED_NAME, JOB_NAME, JOB_GROUP)
 REFERENCES QRZ7_JOB_DETAILS (SCHED_NAME, JOB_NAME, JOB_GROUP)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'CREATE INDEX IDX_QRZ7_FT_INST_JOB_REQ_RCVRY ON QRZ7_FIRED_TRIGGERS
(SCHED_NAME, INSTANCE_NAME, REQUESTS_RECOVERY)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'CREATE INDEX IDX_QRZ7_FT_J_G ON QRZ7_FIRED_TRIGGERS
(SCHED_NAME, JOB_NAME, JOB_GROUP)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'CREATE INDEX IDX_QRZ7_FT_JG ON QRZ7_FIRED_TRIGGERS
(SCHED_NAME, JOB_GROUP)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'CREATE INDEX IDX_QRZ7_FT_T_G ON QRZ7_FIRED_TRIGGERS
(SCHED_NAME, TRIGGER_NAME, TRIGGER_GROUP)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'CREATE INDEX IDX_QRZ7_FT_TG ON QRZ7_FIRED_TRIGGERS
(SCHED_NAME, TRIGGER_GROUP)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'CREATE INDEX IDX_QRZ7_FT_TRIG_INST_NAME ON QRZ7_FIRED_TRIGGERS
(SCHED_NAME, INSTANCE_NAME)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'CREATE INDEX IDX_QRZ7_J_GRP ON QRZ7_JOB_DETAILS
(SCHED_NAME, JOB_GROUP)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'CREATE INDEX IDX_QRZ7_J_REQ_RECOVERY ON QRZ7_JOB_DETAILS
(SCHED_NAME, REQUESTS_RECOVERY)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'CREATE INDEX IDX_QRZ7_T_C ON QRZ7_TRIGGERS
(SCHED_NAME, CALENDAR_NAME)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'CREATE INDEX IDX_QRZ7_T_G ON QRZ7_TRIGGERS
(SCHED_NAME, TRIGGER_GROUP)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'CREATE INDEX IDX_QRZ7_T_J ON QRZ7_TRIGGERS
(SCHED_NAME, JOB_NAME, JOB_GROUP)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'CREATE INDEX IDX_QRZ7_T_JG ON QRZ7_TRIGGERS
(SCHED_NAME, JOB_GROUP)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'CREATE INDEX IDX_QRZ7_T_NEXT_FIRE_TIME ON QRZ7_TRIGGERS
(SCHED_NAME, NEXT_FIRE_TIME)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'CREATE INDEX IDX_QRZ7_T_NFT_MISFIRE ON QRZ7_TRIGGERS
(SCHED_NAME, MISFIRE_INSTR, NEXT_FIRE_TIME)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'CREATE INDEX IDX_QRZ7_T_NFT_ST ON QRZ7_TRIGGERS
(SCHED_NAME, TRIGGER_STATE, NEXT_FIRE_TIME)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'CREATE INDEX IDX_QRZ7_T_NFT_ST_MISFIRE ON QRZ7_TRIGGERS
(SCHED_NAME, MISFIRE_INSTR, NEXT_FIRE_TIME, TRIGGER_STATE)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'CREATE INDEX IDX_QRZ7_T_NFT_ST_MISFIRE_GRP ON QRZ7_TRIGGERS
(SCHED_NAME, MISFIRE_INSTR, NEXT_FIRE_TIME, TRIGGER_GROUP, TRIGGER_STATE)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'CREATE INDEX IDX_QRZ7_T_N_G_STATE ON QRZ7_TRIGGERS
(SCHED_NAME, TRIGGER_GROUP, TRIGGER_STATE)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'CREATE INDEX IDX_QRZ7_T_N_STATE ON QRZ7_TRIGGERS
(SCHED_NAME, TRIGGER_NAME, TRIGGER_GROUP, TRIGGER_STATE)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'CREATE INDEX IDX_QRZ7_T_STATE ON QRZ7_TRIGGERS
(SCHED_NAME, TRIGGER_STATE)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
commit;
set serveroutput off
set verify on

CALL SYSPROC.ADMIN_CMD ( 'REORG TABLE QRZ7_BLOB_TRIGGERS' );
CALL SYSPROC.ADMIN_CMD ( 'REORG TABLE QRZ7_CALENDARS' );
CALL SYSPROC.ADMIN_CMD ( 'REORG TABLE QRZ7_CRON_TRIGGERS' );
CALL SYSPROC.ADMIN_CMD ( 'REORG TABLE QRZ7_FIRED_TRIGGERS' );
CALL SYSPROC.ADMIN_CMD ( 'REORG TABLE QRZ7_JOB_DETAILS' );
CALL SYSPROC.ADMIN_CMD ( 'REORG TABLE QRZ7_LOCKS' );
CALL SYSPROC.ADMIN_CMD ( 'REORG TABLE QRZ7_PAUSED_TRIGGER_GRPS' );
CALL SYSPROC.ADMIN_CMD ( 'REORG TABLE QRZ7_SCHEDULER_STATE' );
CALL SYSPROC.ADMIN_CMD ( 'REORG TABLE QRZ7_SIMPLE_TRIGGERS' );
CALL SYSPROC.ADMIN_CMD ( 'REORG TABLE QRZ7_SIMPROP_TRIGGERS' );
CALL SYSPROC.ADMIN_CMD ( 'REORG TABLE QRZ7_TRIGGERS' );

COMMENT ON COLUMN QRZ7_FIRED_TRIGGERS.IS_NONCONCURRENT IS
'BOOLEAN';

COMMENT ON COLUMN QRZ7_FIRED_TRIGGERS.REQUESTS_RECOVERY IS
'BOOLEAN';

COMMENT ON COLUMN QRZ7_JOB_DETAILS.IS_DURABLE IS
'BOOLEAN';

COMMENT ON COLUMN QRZ7_JOB_DETAILS.IS_NONCONCURRENT IS
'BOOLEAN';

COMMENT ON COLUMN QRZ7_JOB_DETAILS.IS_UPDATE_DATA IS
'BOOLEAN';

COMMENT ON COLUMN QRZ7_JOB_DETAILS.REQUESTS_RECOVERY IS
'BOOLEAN';

COMMENT ON COLUMN QRZ7_SIMPROP_TRIGGERS.BOOL_PROP_1 IS
'BOOLEAN';

COMMENT ON COLUMN QRZ7_SIMPROP_TRIGGERS.BOOL_PROP_2 IS
'BOOLEAN';
