--set serveroutput on

declare
  cur                sys_refcursor;

  user_src           varchar(32);
  user_dest          varchar(32) := '&1';

  source_object      varchar(32);
  source_object_type varchar(32);
  plsql_statement    varchar(255);

begin
  select current_schema into user_src from sysibm.sysdummy1;

  -- GRANT TABLE
  open cur for
    select t.table_name as dml from sysibm.tables t
    where ( t.table_type = 'BASE TABLE' or t.table_type is null ) and t.table_schema = user_src
    order by t.table_name;
  loop
    fetch cur into source_object;
    exit when cur%NOTFOUND;
    plsql_statement := 'GRANT SELECT, DELETE, INSERT, UPDATE ON "' || source_object || '" TO ' || user_dest;
    
    --dbms_output.put_line(plsql_statement);
    execute immediate(plsql_statement);
  end loop;
  close cur;

  -- GRANT SEQUENCE
  open cur for
    select t.seqname from syscat.sequences t
    where t.seqschema = user_src and t.seqtype <> 'I'
    order by t.seqname;
  loop
    fetch cur into source_object;
    exit when cur%NOTFOUND;

    plsql_statement := 'GRANT USAGE, ALTER ON SEQUENCE "' || source_object || '" TO ' || user_dest;
    
    --dbms_output.put_line(plsql_statement);
    execute immediate(plsql_statement);
  end loop;
  close cur;

  -- GRANT FUNCTION, PROCEDURE AND PACKAGES
  open cur for
    select dml, type from
    (
      select t.funcname as dml, 'FUNCTION' as type from syscat.functions t
      where t.funcschema = user_src
      union
      select t.procname as dml, 'PROCEDURE' as type from syscat.procedures t
      where t.procschema = user_src
      union
      select t.modulename as dml, 'MODULE' as type from syscat.modules t
      where t.moduleschema = user_src
    )
    order by type, dml;
  loop
    fetch cur into source_object, source_object_type;
    exit when cur%NOTFOUND;
    
    plsql_statement := 'GRANT EXECUTE ON ' || source_object_type || ' "' || source_object || '" TO ' || user_dest;

    --dbms_output.put_line(plsql_statement);
    execute immediate(plsql_statement);
  end loop;
  close cur;

  -- GRANT VIEW
  open cur for
    select t.table_name from sysibm.tables t
    where t.table_type = 'VIEW' and t.is_insertable_into = 'NO'
    and t.table_schema = user_src
    order by t.table_name;
  loop
    fetch cur into source_object;
    exit when cur%NOTFOUND;

    plsql_statement := 'GRANT SELECT ON '|| source_object || ' TO ' || user_dest;

    --dbms_output.put_line(plsql_statement);
    execute immediate(plsql_statement);
  end loop;
  close cur;

end;
/
commit;
