declare
  cur              sys_refcursor;
  
  user_dest         varchar2(32) := '&1';

  source_object    varchar2(32);
  plsql_statement  varchar2(255);

begin
  -- GRANT TABLE
  open cur for
    select t.table_name from user_tables t
    union
    select t.synonym_name from user_synonyms t, all_objects ao
    where t.table_owner = ao.owner and t.synonym_name = ao.object_name
    and ao.object_type = 'TABLE';
  loop
    fetch cur into source_object;
    exit when cur%NOTFOUND;
    plsql_statement := 'GRANT SELECT ON ' || source_object || ' TO ' || user_dest;
    
    --dbms_output.put_line(plsql_statement);
    execute immediate(plsql_statement);
  end loop;
  close cur;

  -- GRANT SEQUENCE
  open cur for
    select t.sequence_name from user_sequences t
    union
    select t.synonym_name from user_synonyms t, all_objects ao
    where t.table_owner = ao.owner and t.synonym_name = ao.object_name
    and ao.object_type = 'SEQUENCE';
  loop
    fetch cur into source_object;
    exit when cur%NOTFOUND;

    plsql_statement := 'GRANT SELECT ON ' || source_object || ' TO ' || user_dest;
    
    --dbms_output.put_line(plsql_statement);
    execute immediate(plsql_statement);
  end loop;
  close cur;

  -- GRANT FUNCTION, PROCEDURE AND PACKAGES
  open cur for
    select distinct t.object_name from user_objects t
    where t.object_type in ( 'FUNCTION', 'PACKAGE', 'PROCEDURE' )
    and t.object_name <> 'COMPLEX_INDEX'
    union
    select t.synonym_name from user_synonyms t, all_objects ao
    where t.table_owner = ao.owner and t.synonym_name = ao.object_name
    and ao.object_type in ( 'FUNCTION', 'PACKAGE', 'PROCEDURE' )
    and t.synonym_name <> 'COMPLEX_INDEX';
  loop
    fetch cur into source_object;
    exit when cur%NOTFOUND;
    
    plsql_statement := 'GRANT EXECUTE ON '|| source_object || ' TO ' || user_dest;

    --dbms_output.put_line(plsql_statement);
    execute immediate(plsql_statement);
  end loop;
  close cur;

  -- GRANT VIEW
  open cur for
    select distinct t.view_name from user_views t
    union
    select t.synonym_name from user_synonyms t, all_objects ao
    where t.table_owner = ao.owner and t.synonym_name = ao.object_name
    and ao.object_type = 'VIEW';
  loop
    fetch cur into source_object;
    exit when cur%NOTFOUND;

    plsql_statement := 'GRANT SELECT ON '|| source_object || ' TO ' || user_dest;

    --dbms_output.put_line(plsql_statement);
    execute immediate(plsql_statement);
  end loop;
  close cur;

end;
/
