set define off
declare
  ft_id         number(16);
  ft_name       varchar2(256) := 'RUN';
  
  im_id         number(16);
  im_name       varchar2(256) := 'AGC';

  fc_id         number(16);
  fc_name       varchar2(256) := 'system';
  
  fet_root      number(16) := 0;
  fet_rule      number(16) := 1;
  fet_group     number(16) := 2;
  fet_split     number(16) := 3;
  fet_split_con number(16) := 4;
  
  fet_par_id    number(16);
  fet_par_type  number(16);
  
  fevt_id       number(16);
  fevt_name     varchar2(256) := 'TARGET';
  
  f_id          number(16);
  f_name        varchar2(256) := 'RIGHT_ADD';

  fer_id        number(16);
  feg_id        number(16);
  feg_name      varchar2(256) := 'Add User Right Default Group';
  
  fe_id         number(16);
  fe_pos_old    number(16) := 5;
  --specifica la posizione della regola nel gruppo, -1 se non si deve aggiungere
  fe_pos        number(16) := 4;
  
  fr_id         number(16);
  fr_name       varchar2(256) := 'Add permission to user';
  fr_desc       varchar2(512) := '[ V1.0 - 2017-06-26 ]' ;
  
  fr_lob        clob := 'rule "Add permission to user"
'||'when
'||'    userBean : UserBean(  )  
'||'    orgUnitBean : OrgUnitBean(  )  
'||'    event : EventTargetBean(  )  
'||'    syncBean : SyncStateBean(  )
'||'then
'||'
'||'  if (event.getLevel() == EventTargetBean.USER_NOT_FOUND) {
'||'    throw new Exception("Account " + event.getCode() + " does not exist");
'||'  }
'||'
'||'  EntitlementBean entBean = syncBean.getProfile();
'||'
'||'  String pName = entBean.getName();
'||'  String uCode = userBean.getCode();
'||'
'||'  // User already has the profile
'||'  if (event.getLevel() == EventTargetBean.USER_PROFILE_FOUND) {
'||'
'||'    logger.debug("Permission " + pName + " already assigned to User " + uCode);
'||'
'||'    return;
'||'  }
'||'
'||'  // User does not have the profile
'||'  if (event.getLevel() == EventTargetBean.USER_PROFILE_NOT_FOUND) {
'||'
'||'    BeanList bl = new BeanList();
'||'    bl.add(entBean);
'||'    UserAction.addRoles(sql, userBean, null, bl, true, false);
'||'
'||'    logger.debug("Permission " + pName + " assigned to User " + uCode);
'||'
'||'    return;
'||'
'||'  }
'||'
'||'  throw new Exception("Unexpected sync level: " + event.getLevel());
'||'end
';

  counter       number(16);
begin
  select count(1) into counter from flow_type t where lower ( t.name ) = lower ( ft_name );
  if ( counter = 1 ) then
    select t.id into ft_id from flow_type t where lower ( t.name ) = lower ( ft_name );
  else
    RAISE_APPLICATION_ERROR ( -20200, 'NO FLOW TYPE FOUND' );
  end if;

  select count(1) into counter from ideas_module t where lower ( t.code ) = lower ( im_name );
  if ( counter = 1 ) then
    select t.id into im_id from ideas_module t where lower ( t.code ) = lower ( im_name );
  else
    RAISE_APPLICATION_ERROR ( -20200, 'NO IDEAS MODULE FOUND' );
  end if;

  select count(1) into counter from flow_context t where lower ( t.name ) = lower ( fc_name );
  if ( counter = 1 ) then
    select t.id into fc_id from flow_context t where lower ( t.name ) = lower ( fc_name );
  else
    RAISE_APPLICATION_ERROR ( -20200, 'NO FLOW CONTEXT FOUND' );
  end if;

  select count(1) into counter from flow_event_type t
  where t.flow_context = fc_id and t.ideas_module = im_id and lower ( t.name ) = lower ( fevt_name );
  if ( counter = 1 ) then
    select t.id into fevt_id from flow_event_type t
    where t.flow_context = fc_id and t.ideas_module = im_id and lower ( t.name ) = lower ( fevt_name );
  else
    RAISE_APPLICATION_ERROR ( -20200, 'NO FLOW EVENT TYPE FOUND' );
  end if;
  
  select count(1) into counter from flow t
  where t.ideas_module = im_id and t.flow_event_type = fevt_id and lower ( t.name ) = lower ( f_name ); 
  if ( counter = 1 ) then
    select t.id into f_id from flow t
    where t.ideas_module = im_id and t.flow_event_type = fevt_id and lower ( t.name ) = lower ( f_name ); 
  else
    RAISE_APPLICATION_ERROR ( -20200, 'NO FLOW FOUND' );
  end if;

  select count(1) into counter from flow_rule t where t.flow = f_id and t.ideas_module = im_id and lower ( t.name ) = lower ( fr_name );
  if ( counter = 0 ) then
    select flow_rule_seq.nextval into fr_id from dual;
    insert into flow_rule ( id, flow, name, description, rule_lob, ideas_module )
    values ( fr_id, f_id, fr_name, fr_desc, fr_lob, im_id );
  else
    select t.id into fr_id from flow_rule t where t.flow = f_id and t.ideas_module = im_id and lower ( t.name ) = lower ( fr_name );

    update flow_rule set description = fr_desc where id = fr_id;

    update flow_rule set rule_lob = fr_lob where id = fr_id;
  end if;

  if ( fe_pos = -1 ) then
    return;
  end if;

  select count(1) into counter from flow_entity t
  where t.ideas_module = im_id and t.flow = f_id and t.flow_type = ft_id and t.flow_entity_type = fet_root and t.parent is null; 
  if ( counter = 1 ) then
    select t.id into fer_id from flow_entity t
    where t.ideas_module = im_id and t.flow = f_id and t.flow_type = ft_id and t.flow_entity_type = fet_root and t.parent is null; 
  end if;

  if ( feg_name is not null and length ( trim ( feg_name )  ) > 0 ) then
    select count(1) into counter from flow_entity t
    where t.ideas_module = im_id and t.flow = f_id and flow_type = ft_id and t.flow_entity_type = fet_group and t.root = fer_id;
    if ( counter = 0 ) then
      select flow_entity_seq.nextval into feg_id from dual;
      
      insert into flow_entity ( id, flow, flow_type, root, parent, flow_entity_type, name, position, ideas_module)
      values ( feg_id, f_id, ft_id, fer_id, fer_id, fet_group, feg_name, 0, im_id );
    else
      select t.id, t.flow_type into feg_id, fet_par_type from flow_entity t
      where t.ideas_module = im_id and t.flow = f_id and flow_type = ft_id and t.flow_entity_type = fet_group and t.root = fer_id;
    end if;
  end if;
  
  if ( feg_id is null ) then
    fet_par_id   := fer_id;
  else
    fet_par_id   := feg_id;
  end if;
  fet_par_type := fet_rule;
  
  select count(1) into counter from flow_entity t
  where t.ideas_module = im_id and t.flow = f_id and flow_type = ft_id
  and t.flow_entity_type = fet_par_type and t.root = fer_id and t.flow_rule = fr_id;
  if ( counter = 0 ) then
    select flow_entity_seq.nextval into fe_id from dual;
  else
    select t.id, t.position into fe_id, fe_pos_old from flow_entity t
    where t.ideas_module = im_id and t.flow = f_id and flow_type = ft_id
    and t.flow_entity_type = fet_par_type and t.root = fer_id and t.flow_rule = fr_id;
  end if;
  
  if ( fe_pos is null and fe_pos_old is null ) then
    select max ( t.position ) into fe_pos from flow_entity t
    where t.ideas_module = im_id and t.flow = f_id and flow_type = ft_id
    and t.flow_entity_type = fet_rule and t.root = fer_id;

    if ( fe_pos is null ) then
      fe_pos := 0;
    else
      fe_pos := fe_pos + 1;
    end if;
  elsif ( fe_pos is null and fe_pos_old is not null ) then
    fe_pos := fe_pos_old;
  elsif ( fe_pos is not null and fe_pos_old is not null and fe_pos <> fe_pos_old  ) then
    --modificare le posizioni del corrente e dei successivi
    update flow_entity set position = ( position + 1 ) where ideas_module = im_id and flow = f_id and flow_type = ft_id
    and flow_entity_type = fet_rule and root = fer_id and position >= fe_pos;
  end if;

  if ( counter = 0 ) then
    insert into flow_entity ( id, flow, flow_type, root, parent, flow_entity_type, flow_rule, position, ideas_module)
    values ( fe_id, f_id, ft_id, fer_id, fet_par_id, fet_rule, fr_id, fe_pos, im_id );
  else
    update flow_entity set position = fe_pos where id = fe_id;
  end if;

end;
/
commit;
set define on
