declare
  p_name       varchar(256) := 'Modify Account';
  p_id         numeric(16);

  pri_id       numeric(16) := null;

  funct        varchar(256) := 'UPDATE_ACCOUNT';
  a_name       varchar(256);
  a_desc       varchar(256);
  a_id         numeric(16);
  a_id_next    numeric(16);
  a_funct      varchar(256);
  a_modality   varchar(256);
  a_wfstatus   varchar(256);

  pa_id        numeric(16);
  pa_perm      varchar(256);

  counter      numeric(16);

begin
  select count(1) into counter from cfg_process t where lower ( t.name ) = lower ( p_name );
  if ( counter > 0 ) then
    return;
  end if;

  select cfg_process_seq.nextval into p_id from dual;
  insert into cfg_process ( name, functionality_context, process_type, description, process_status, creation_date, id, extended_escalation, updatable, last_mod_time, code, product, cfg_priority, expiration_action, expiration_wf, notification_enable, cfg_notification, enable_priority_override, cfg_notification_sms)
  values ( p_name, 'ACCOUNT_CHANGE', 1, null, 0, current_date, p_id, null, 0, current_timestamp, null, 1, pri_id, 0, null, 0, null, 0, null);

  a_name := 'Modify Account Execution';
  a_desc := null;
  a_modality := 'EXE';
  a_funct := funct || '_' || a_modality;
  a_id_next := null;
  select count(1) into counter from cfg_activity t where lower ( t.activity_name ) = lower ( a_name );
  if ( counter > 0 ) then
    return;
  end if;
  select cfg_activity_seq.nextval into a_id from dual;
  a_wfstatus := a_modality || a_id;
  insert into cfg_activity ( id, functionality, activity_name, description, userscope, appscope, apps_filter, ownership, wf_status, activity_type, modality, representedscope, resourcescope, resourcescope_filter, activity_status, to_sinchronize, last_sync_time, entitlementscope, entitlement_filter, product, redirectscope, enable_dashboard )
  values ( a_id, a_funct, a_name, a_desc, null, null, null, 0, a_wfstatus, 1, a_modality, null, null, null, 0, 0, current_date, null, null, 1, null, 0);

  pa_perm := a_modality || '/' || a_name || '$' || p_name;
  select cfg_processactivity_seq.nextval into pa_id from dual;
  insert into cfg_processactivity ( activity, next_activity, authmode, counter, status, escalation_activity, process, escalation_process, linked_process, linked_activity, approver, permission, id, required_approver )
  values ( a_id, a_id_next, 0, 4, 1, null, p_id, null, null, null, null, pa_perm, pa_id, 0);

  a_name := 'Account Modification Authorization';
  a_desc := 'Designed for Account managers who have to approve an account modification';
  a_modality := 'AUTH';
  a_funct := funct || '_' || a_modality;
  a_id_next := a_id;
  select count(1) into counter from cfg_activity t where lower ( t.activity_name ) = lower ( a_name );
  if ( counter > 0 ) then
    return;
  end if;
  select cfg_activity_seq.nextval into a_id from dual;
  a_wfstatus := a_modality || a_id;
  insert into cfg_activity ( id, functionality, activity_name, description, userscope, appscope, apps_filter, ownership, wf_status, activity_type, modality, representedscope, resourcescope, resourcescope_filter, activity_status, to_sinchronize, last_sync_time, entitlementscope, entitlement_filter, product, redirectscope, enable_dashboard )
  values ( a_id, a_funct, a_name, a_desc, 1, 2, null, 0, a_wfstatus, 1, a_modality, null, null, null, 0, 0, current_date, null, null, 1, 1, 0);
  
  insert into cfg_activity_requireddata ( activity_id, required_key, required_value, required_type )
  values ( a_id, 'ChangeAccountAttributes', 'false', 1 );
  insert into cfg_activity_requireddata ( activity_id, required_key, required_value, required_type )
  values ( a_id, 'LockType', 'Auth.Suspend', 2 );
  insert into cfg_activity_requireddata ( activity_id, required_key, required_value, required_type )
  values ( a_id, 'LockType', 'Expired', 2 );
  insert into cfg_activity_requireddata ( activity_id, required_key, required_value, required_type )
  values ( a_id, 'LockType', 'Maint.Suspend', 2 );
  insert into cfg_activity_requireddata ( activity_id, required_key, required_value, required_type )
  values ( a_id, 'LockType', 'Sec.Suspend', 2 );
  insert into cfg_activity_requireddata ( activity_id, required_key, required_value, required_type )
  values ( a_id, 'LockType', 'Tech.Suspend', 2 );
  insert into cfg_activity_requireddata ( activity_id, required_key, required_value, required_type )
  values ( a_id, 'LockType', 'Terminated', 2 );
  insert into cfg_activity_requireddata ( activity_id, required_key, required_value, required_type )
  values ( a_id, 'ShowLockUnlock', 'false', 1 );
  
  pa_perm := a_modality || '/' || a_name || '$' || p_name;
  select cfg_processactivity_seq.nextval into pa_id from dual;
  insert into cfg_processactivity ( activity, next_activity, authmode, counter, status, escalation_activity, process, escalation_process, linked_process, linked_activity, approver, permission, id, required_approver )
  values ( a_id, a_id_next, 0, 3, 1, null, p_id, null, null, null, null, pa_perm, pa_id, 0);

  a_name := 'Authorize Account modification';
  a_desc := 'Designed for Business Manager who have to Authorize the changes';
  a_modality := 'AUTH';
  a_funct := funct || '_' || a_modality;
  a_id_next := a_id;
  select count(1) into counter from cfg_activity t where lower ( t.activity_name ) = lower ( a_name );
  if ( counter > 0 ) then
    return;
  end if;
  select cfg_activity_seq.nextval into a_id from dual;
  a_wfstatus := a_modality || a_id;
  insert into cfg_activity ( id, functionality, activity_name, description, userscope, appscope, apps_filter, ownership, wf_status, activity_type, modality, representedscope, resourcescope, resourcescope_filter, activity_status, to_sinchronize, last_sync_time, entitlementscope, entitlement_filter, product, redirectscope, enable_dashboard )
  values ( a_id, a_funct, a_name, a_desc, 3, 1, null, 0, a_wfstatus, 1, a_modality, null, null, null, 0, 0, current_date, null, null, 1, 1, 0);

  insert into cfg_activity_requireddata ( activity_id, required_key, required_value, required_type )
  values (a_id, 'ChangeAccountAttributes', 'false', 1);
  insert into cfg_activity_requireddata ( activity_id, required_key, required_value, required_type )
  values (a_id, 'LockType', 'Auth.Suspend', 2);
  insert into cfg_activity_requireddata ( activity_id, required_key, required_value, required_type )
  values (a_id, 'LockType', 'Expired', 2);
  insert into cfg_activity_requireddata ( activity_id, required_key, required_value, required_type )
  values (a_id, 'LockType', 'Maint.Suspend', 2);
  insert into cfg_activity_requireddata ( activity_id, required_key, required_value, required_type )
  values (a_id, 'LockType', 'Sec.Suspend', 2);
  insert into cfg_activity_requireddata ( activity_id, required_key, required_value, required_type )
  values (a_id, 'LockType', 'Tech.Suspend', 2);
  insert into cfg_activity_requireddata ( activity_id, required_key, required_value, required_type )
  values (a_id, 'LockType', 'Terminated', 2);
  insert into cfg_activity_requireddata ( activity_id, required_key, required_value, required_type )
  values (a_id, 'ShowLockUnlock', 'false', 1);

  pa_perm := a_modality || '/' || a_name || '$' || p_name;
  select cfg_processactivity_seq.nextval into pa_id from dual;
  insert into cfg_processactivity ( activity, next_activity, authmode, counter, status, escalation_activity, process, escalation_process, linked_process, linked_activity, approver, permission, id, required_approver )
  values ( a_id, a_id_next, 0, 2, 1, null, p_id, null, null, null, null, pa_perm, pa_id, 0);
  
  a_name := 'Modify your Account';
  a_desc := 'Designed for Employees who have to modify their accounts';
  a_modality := 'GEN';
  a_funct := funct || '_' || a_modality;
  a_id_next := a_id;
  select count(1) into counter from cfg_activity t where lower ( t.activity_name ) = lower ( a_name );
  if ( counter > 0 ) then
    return;
  end if;
  select cfg_activity_seq.nextval into a_id from dual;
  a_wfstatus := a_modality || a_id;
  insert into cfg_activity ( id, functionality, activity_name, description, userscope, appscope, apps_filter, ownership, wf_status, activity_type, modality, representedscope, resourcescope, resourcescope_filter, activity_status, to_sinchronize, last_sync_time, entitlementscope, entitlement_filter, product, redirectscope, enable_dashboard )
  values ( a_id, a_funct, a_name, a_desc, 6, 1, null, 0, a_wfstatus, 1, a_modality, null, null, null, 0, 0, current_date, null, null, 1, null, 0 );

  insert into cfg_activity_requireddata ( activity_id, required_key, required_value, required_type )
  values ( a_id, 'ChangeAccountAttributes', 'true', 1 );
  insert into cfg_activity_requireddata ( activity_id, required_key, required_value, required_type )
  values ( a_id, 'DeleteAccount', 'false', 1 );
  insert into cfg_activity_requireddata ( activity_id, required_key, required_value, required_type )
  values ( a_id, 'LockType', 'Auth.Suspend', 2 );
  insert into cfg_activity_requireddata ( activity_id, required_key, required_value, required_type )
  values ( a_id, 'LockType', 'Expired', 2 );
  insert into cfg_activity_requireddata ( activity_id, required_key, required_value, required_type )
  values ( a_id, 'LockType', 'Maint.Suspend', 2 );
  insert into cfg_activity_requireddata ( activity_id, required_key, required_value, required_type )
  values ( a_id, 'LockType', 'Sec.Suspend', 2 );
  insert into cfg_activity_requireddata ( activity_id, required_key, required_value, required_type )
  values ( a_id, 'LockType', 'Tech.Suspend', 2 );
  insert into cfg_activity_requireddata ( activity_id, required_key, required_value, required_type )
  values ( a_id, 'LockType', 'Terminated', 2 );
  insert into cfg_activity_requireddata ( activity_id, required_key, required_value, required_type )
  values ( a_id, 'ShowLockUnlock', 'false', 1 );

  pa_perm := a_modality || '/' || a_name || '$' || p_name;
  select cfg_processactivity_seq.nextval into pa_id from dual;
  insert into cfg_processactivity ( activity, next_activity, authmode, counter, status, escalation_activity, process, escalation_process, linked_process, linked_activity, approver, permission, id, required_approver )
  values ( a_id, a_id_next, 0, 1, 1, null, p_id, null, null, null, null, pa_perm, pa_id, 0);

end;
/
commit;