declare
  counter              numeric(16);

  -- report
  r_id                 numeric(16);
  r_name               varchar(256) := 'Fulfillment status for managed Users';
  r_desc               varchar(512) := 'Available to any user with an Admin Role that is associated to the dashboard. The dashboard shows the fulfillment status for all the assignments that are related to Automatic Account Configurations, only for matched accounts to identities (users). The scopes are set to view all the managed users and all the applications.';
  r_code               varchar(256) := null;
  r_i18n_mess          varchar(256) := null;
  r_dashboard          numeric(1) := 1; -- 0: report, 1: dashboard

  -- localization
  r_loc_id             numeric(16);
  r_loc_code           varchar(256);

  -- query
  rq_id                numeric(16);
  rq_name              varchar(256) := 'Fulfillment status for managed Users';

  rv_name              varchar(256);
  repv_vis_type        numeric(2);

  rqf_type_def         varchar(256) := 'java.lang.String';
  rqf_width_def        numeric(16) := 300;

  rqf_name_old         varchar(256);
  rqf_name             varchar(256);
  rqf_type             varchar(256);
  rqf_width            numeric(16);
  rqf_ord_by           numeric(1);
  rqf_ord_by_clau      varchar(256);
  loc_code_old         varchar(256);
  loc_code             varchar(256);
  loc_rename           boolean;
  i18n_msg             varchar(256);
  repf_pos_id          numeric(16);
  repf_pos_id_old      numeric(16);

  repfr_id             numeric(16);
  repfr_name_old       varchar(256);
  repfr_name           varchar(256);
  repfr_value          varchar(256);
  repfr_l_id           numeric(16);
  repfr_l_code_old     varchar(256);
  repfr_l_code         varchar(256);
  repfr_i18n_msg       varchar(256);
  repfr_vis            numeric(16);
  repfr_mand           numeric(16);
  repfr_type           numeric(16);
  repfr_cust_id        numeric(16);
  repfr_cust_name      varchar(256);
  repfr_posit_id       numeric(16);
  repfr_posit_id_old   numeric(16);

  cur_lan              sys_refcursor;
  lan_id               numeric(16);

  v_ret                numeric(16);

begin

  select count(1) into counter from r_query t where lower ( t.name ) = lower ( rq_name ) and t.product = 1;
  if ( counter = 0 ) then
    RAISE_APPLICATION_ERROR ( -20200, 'NO QUERY FOUND' );
  else
    select t.id into rq_id from r_query t where lower ( t.name ) = lower ( rq_name ) and t.product = 1;
  end if;

  select count(1) into counter from report t where lower ( t.name ) = lower ( r_name ) and t.dashboard = r_dashboard and t.product = 1;
  if ( counter = 0 ) then
    if ( r_loc_code is null ) then
      /*DBALT-BEGIN*/
      /*select dbms_random.random into r_loc_code from dual;*/
      /*PG*select trunc(random()*1000) into r_loc_code from generate_series(1,1000) limit 1;*PG*/
      select int((rand()-0.5) * 32768) into r_loc_code from dual;
      /*DBALT-END*/

      select count(1) into counter from localization t where lower ( t.code ) = lower ( r_loc_code );
      if ( counter = 0 ) then
        select localization_seq.nextval into r_loc_id from dual;
        insert into localization ( id, code, code_type )
        values ( r_loc_id, r_loc_code, 0 );
      end if;

    else
      select count(1) into counter from localization t where lower ( t.code ) = lower ( r_loc_code );
      if ( counter = 1 ) then
        select t.id into r_loc_id from localization t where lower ( t.code ) = lower ( r_loc_code );
      end if;
    end if;

    if ( r_loc_id is null ) then
      select t.id into r_loc_id from localization t where lower ( t.code ) = lower ( r_loc_code );
    end if;

    select max(id) + 1 into r_id from report t;

    insert into report ( id, name, description, localization, r_query, status, report_type, code, product, parent, dashboard )
    values ( r_id, r_name, r_desc, r_loc_id, rq_id, 0, null, r_code, 1, 1, r_dashboard );

    insert into report_attribute ( id, report, name, value )
    values ( report_attribute_seq.nextval, r_id, 'CHART', '0' );
    insert into report_attribute ( id, report, name, value )
    values ( report_attribute_seq.nextval, r_id, 'LEGEND', 'false' );
  
  else
    select t.id, t.name into r_id, r_name from report t where lower ( t.name ) = lower ( r_name ) and t.dashboard = r_dashboard and t.product = 1;
    select t.localization into r_loc_id from report t where t.id = r_id;
    update report set r_query = rq_id where id = r_id;
  end if;

  if ( r_i18n_mess is null or length ( r_i18n_mess ) = 0 ) then
    r_i18n_mess := r_name;
  end if;

  open cur_lan for select t.id from language t where t.language_status > 0;
  loop
    fetch cur_lan into lan_id;
    exit when cur_lan%NOTFOUND;

    select count(1) into counter from i18n_message t where t.language = lan_id and t.localization = r_loc_id;
    if ( counter = 0 ) then
      insert into i18n_message ( id, localization, language, message )
      values ( i18n_message_seq.nextval, r_loc_id, lan_id, r_i18n_mess );
    else
      update i18n_message set message = r_i18n_mess where language = lan_id and localization = r_loc_id;
    end if;
  end loop;
  close cur_lan;

  -- Report FIELD 1
  rqf_name_old    := null;
  rqf_name        := 'ACCOUNT_CODE';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'account.code';
  loc_rename      := true;
  i18n_msg        := 'Account Code';
  repf_pos_id_old := null;
  repf_pos_id     := null;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );

  -- Report FIELD 2
  rqf_name_old    := null;
  rqf_name        := 'USER_NAME';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'user.name';
  loc_rename      := true;
  i18n_msg        := 'First Name';
  repf_pos_id_old := null;
  repf_pos_id     := null;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );

  -- Report FIELD 3
  rqf_name_old    := null;
  rqf_name        := 'USER_SURNAME';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'user.surname';
  loc_rename      := true;
  i18n_msg        := 'Last Name';
  repf_pos_id_old := null;
  repf_pos_id     := null;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );

  -- Report FIELD 4
  rqf_name_old    := null;
  rqf_name        := 'USER_CODE';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'user.code';
  loc_rename      := true;
  i18n_msg        := 'UserID';
  repf_pos_id_old := null;
  repf_pos_id     := null;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );

  -- Report FIELD 5
  rqf_name_old    := null;
  rqf_name        := 'GROUP_NAME';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'group.name';
  loc_rename      := true;
  i18n_msg        := 'Group';
  repf_pos_id_old := null;
  repf_pos_id     := null;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );

  -- Report FIELD 6
  rqf_name_old    := null;
  rqf_name        := 'GROUP_CODE';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'group.code';
  loc_rename      := true;
  i18n_msg        := 'Group code';
  repf_pos_id_old := null;
  repf_pos_id     := null;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );

  -- Report FIELD 7
  rqf_name_old    := null;
  rqf_name        := 'ENTITLEMENT_NAME';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'entitlement.name';
  loc_rename      := true;
  i18n_msg        := 'Entitlement Name';
  repf_pos_id_old := null;
  repf_pos_id     := null;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );

  -- Report FIELD 8
  rqf_name_old    := null;
  rqf_name        := 'ENTITLEMENT_CODE';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'entitlement.code';
  loc_rename      := true;
  i18n_msg        := 'Entitlement Code';
  repf_pos_id_old := null;
  repf_pos_id     := null;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );

  -- Report FIELD 9
  rqf_name_old    := null;
  rqf_name        := 'ENTITLEMENT_DESC';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'entitlement.desc';
  loc_rename      := true;
  i18n_msg        := 'Entitlement Descr.';
  repf_pos_id_old := null;
  repf_pos_id     := null;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );

  -- Report FIELD 10
  rqf_name_old    := null;
  rqf_name        := 'APPLICATION_NAME';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'application.name';
  loc_rename      := true;
  i18n_msg        := 'Application';
  repf_pos_id_old := null;
  repf_pos_id     := null;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );

  -- Report FIELD 11
  rqf_name_old    := null;
  rqf_name        := 'STATUS';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'status';
  loc_rename      := true;
  i18n_msg        := 'Sync Status';
  repf_pos_id_old := null;
  repf_pos_id     := null;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );

  -- Report FIELD 12
  rqf_name_old    := null;
  rqf_name        := 'VERIFY_DATE';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'verify.date';
  loc_rename      := true;
  i18n_msg        := 'Verified';
  repf_pos_id_old := null;
  repf_pos_id     := null;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );


  -- QUERY AND REPORT VISIBILITY

  rv_name := 'AG-Core Application';
  repv_vis_type := 1;

  v_ret := inst_rep_add_vis ( r_id, rq_id, rv_name, repv_vis_type );

  rv_name := 'AG-Core Org. Unit';
  repv_vis_type := 3;

  v_ret := inst_rep_add_vis ( r_id, rq_id, rv_name, repv_vis_type );

  -- REPORT FILTERS

  repfr_name_old     := null;
  repfr_name         := 'fulfillment_status';
  repfr_value        := null;
  repfr_l_code_old   := null;
  repfr_l_code       := 'fulfillment.status';
  repfr_i18n_msg     := 'Fullfillment Status';
  repfr_vis          := 0;
  repfr_mand         := 0;
  repfr_type         := 0;
  repfr_cust_id      := null;
  repfr_cust_name    := null;
  repfr_posit_id_old := null;
  repfr_posit_id     := null;

  v_ret := inst_rep_add_fil ( rq_id, repfr_name, repfr_value, repfr_l_code_old, repfr_l_code, repfr_i18n_msg, repfr_vis,
                              repfr_mand, repfr_type, repfr_cust_name, repfr_posit_id_old, repfr_posit_id );

end;
/
commit;
