declare
  counter              number(16);

  -- report parent
  rp_id                number(16);
  rp_name              varchar2(256) := 'Status';

  -- report
  r_id                 number(16);
  r_name               varchar2(256) := 'Fulfillment Status Summary';
  r_desc               varchar2(512) := 'Available to any user with an Admin Role that is associated to the dashboard. The dashboard shows the fulfillment status summary for all the assignments that are related to Automatic Account Configurations, only for matched accounts to identities (users). The scopes are set to view all the managed users and all the applications';
  r_code               varchar2(256) := null;
  r_i18n_mess          varchar2(256) := null;
  r_dashboard          number(1) := 1; -- 0: report, 1: dashboard

  -- localization
  r_loc_id             number(16);
  r_loc_code           varchar2(256);

  -- query
  rq_id                number(16);
  rq_name              varchar2(256) := 'Fulfillment Status DB';
  rq_desc              varchar2(512) := 'Fulfillment Status for Dashboards';
  rqd                  clob;

  rv_name              varchar2(256);
  repv_vis_type        number(2);

  rqf_type_def         varchar2(256) := 'java.lang.String';
  rqf_width_def        number(16) := 300;

  rqf_name_old         varchar2(256);
  rqf_name             varchar2(256);
  rqf_type             varchar2(256);
  rqf_width            number(16);
  rqf_ord_by           number(1);
  rqf_ord_by_clau      varchar2(256);
  loc_code_old         varchar2(256);
  loc_code             varchar2(256);
  loc_rename           boolean;
  i18n_msg             varchar2(256);
  repf_pos_id          number(16);
  repf_pos_id_old      number(16);

  repfr_id             number(16);
  repfr_name_old       varchar2(256);
  repfr_name           varchar2(256);
  repfr_value          varchar2(256);
  repfr_l_id           number(16);
  repfr_l_code_old     varchar2(256);
  repfr_l_code         varchar2(256);
  repfr_i18n_msg       varchar2(256);
  repfr_vis            number(16);
  repfr_mand           number(16);
  repfr_type           number(16);
  repfr_cust_id        number(16);
  repfr_cust_name      varchar2(256);
  repfr_posit_id       number(16);
  repfr_posit_id_old   number(16);

  cur_lan              sys_refcursor;
  lan_id               number(16);

  v_ret                number(16);

begin
  rqd := 'select t.fulfillment_status as fulfillment_status, count(1) as status_count
'||'  from (select case
'||'                 when pp.status = 0 then
'||'                  ''Pending''
'||'                 when pp.status = 1 then
'||'                  ''Assignment - Pending Fulfillment''
'||'                 when pp.status = 2 then
'||'                  ''Assignment - Aligned''
'||'                 when pp.status = 3 then
'||'                  ''Assignment - Failed Fulfillment''
'||'                 when pp.status = 4 then
'||'                  ''Assignment - Target Originated''
'||'                 when pp.status = 11 then
'||'                  ''Removal - Pending Fulfillment''
'||'                 when pp.status = 12 then
'||'                  ''Removal - Aligned''
'||'                 when pp.status = 13 then
'||'                  ''Removal - Failed Fulfillment''
'||'                 when pp.status = 14 then
'||'                  ''Removal - Target Originated''
'||'                 else
'||'                  ''Unknown''
'||'               end as fulfillment_status
'||'          from #pmschema#.person_profile pp
'||'          left join #pmschema#.entitlement e
'||'            on pp.profile = e.id
'||'          left join #pmschema#.application a
'||'            on e.application = a.id, 
'||'            #pmschema#.person p,
'||'            #pmschema#.organizational_unit ou, 
'||'            #pmschema#.Target t,
'||'            #pmschema#.Pwdcfg pc,
'||'            #schema_tmp#.tmp_rep_application tmpa,
'||'            #schema_tmp#.tmp_rep_organizational_unit tmpou
'||'         where pp.person = p.id
'||'           and p.organizational_unit = ou.id
'||'           and pp.target = t.value
'||'           and t.pwdcfg = pc.id
'||'           and pc.sync = 2
'||'           and a.id = tmpa.id
'||'           and ou.id = tmpou.id) t
'||' group by t.fulfillment_status
';

  select count(1) into counter from r_query t where lower ( t.name ) = lower ( rq_name ) and t.product = 1;
  if ( counter = 0 ) then
    select max(id) + 1 into rq_id from r_query t;

    insert into r_query ( id, name, description, product )
    values ( rq_id, rq_name, rq_desc, 1 );

    insert into r_query_data ( r_query, query )
    values ( rq_id, rqd );
  else
    select t.id into rq_id from r_query t where lower ( t.name ) = lower ( rq_name ) and t.product = 1;

    update r_query set description = rq_desc where id = rq_id;

    update r_query_data set query = rqd where r_query = rq_id;
  end if;

  select count(1) into counter from report t where lower ( t.name ) = lower ( r_name ) and t.dashboard = r_dashboard and t.product = 1;
  if ( counter = 0 ) then
    if ( r_loc_code is null ) then
      /*DBALT-BEGIN*/
      select dbms_random.random into r_loc_code from dual;
      /*PG*select trunc(random()*1000) into r_loc_code from generate_series(1,1000) limit 1;*PG*/
      /*DB2*select int((rand()-0.5) * 32768) into r_loc_code from dual;*DB2*/
      /*DBALT-END*/

      select count(1) into counter from localization t where lower ( t.code ) = lower ( r_loc_code );
      if ( counter = 0 ) then
        select localization_seq.nextval into r_loc_id from dual;
        insert into localization ( id, code, code_type )
        values ( r_loc_id, r_loc_code, 0 );
      end if;

    else
      select count(1) into counter from localization t where lower ( t.code ) = lower ( r_loc_code );
      if ( counter = 1 ) then
        select t.id into r_loc_id from localization t where lower ( t.code ) = lower ( r_loc_code );
      end if;
    end if;

    if ( r_loc_id is null ) then
      select t.id into r_loc_id from localization t where lower ( t.code ) = lower ( r_loc_code );
    end if;

    select max(id) + 1 into r_id from report t;

    insert into report ( id, name, description, localization, r_query, status, report_type, code, product, parent, dashboard )
    values ( r_id, r_name, r_desc, r_loc_id, rq_id, 0, null, r_code, 1, 1, r_dashboard );

    insert into report_attribute ( id, report, name, value )
    values ( report_attribute_seq.nextval, r_id, 'CHART', '2' );
    insert into report_attribute ( id, report, name, value )
    values ( report_attribute_seq.nextval, r_id, 'LEGEND', 'false' );
  
  else
    select t.id, t.name into r_id, r_name from report t where lower ( t.name ) = lower ( r_name ) and t.dashboard = r_dashboard and t.product = 1;
    select t.localization into r_loc_id from report t where t.id = r_id;
    update report set r_query = rq_id where id = r_id;
  end if;

  if ( r_i18n_mess is null or length ( r_i18n_mess ) = 0 ) then
    r_i18n_mess := r_name;
  end if;

  open cur_lan for select t.id from language t where t.language_status > 0;
  loop
    fetch cur_lan into lan_id;
    exit when cur_lan%NOTFOUND;

    select count(1) into counter from i18n_message t where t.language = lan_id and t.localization = r_loc_id;
    if ( counter = 0 ) then
      insert into i18n_message ( id, localization, language, message )
      values ( i18n_message_seq.nextval, r_loc_id, lan_id, r_i18n_mess );
    else
      update i18n_message set message = r_i18n_mess where language = lan_id and localization = r_loc_id;
    end if;
  end loop;
  close cur_lan;

  -- Report FIELD 1
  rqf_name_old    := null;
  rqf_name        := 'FULFILLMENT_STATUS';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'fulfillment.status';
  loc_rename      := true;
  i18n_msg        := 'Fullfillment Status';
  repf_pos_id_old := null;
  repf_pos_id     := null;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );

  -- Report FIELD 2
  rqf_name_old    := null;
  rqf_name        := 'STATUS_COUNT';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'status.count';
  loc_rename      := true;
  i18n_msg        := 'Status Count';
  repf_pos_id_old := null;
  repf_pos_id     := null;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );

  -- QUERY AND REPORT VISIBILITY

  rv_name := 'AG-Core Application';
  repv_vis_type := 1;

  v_ret := inst_rep_add_vis ( r_id, rq_id, rv_name, repv_vis_type );

  rv_name := 'AG-Core Org. Unit';
  repv_vis_type := 3;

  v_ret := inst_rep_add_vis ( r_id, rq_id, rv_name, repv_vis_type );

  -- REPORT FILTERS

  repfr_name_old     := null;
  repfr_name         := 'fulfillment_status';
  repfr_value        := null;
  repfr_l_code_old   := null;
  repfr_l_code       := 'fulfillment.status';
  repfr_i18n_msg     := 'Fullfillment Status';
  repfr_vis          := 0;
  repfr_mand         := 0;
  repfr_type         := 0;
  repfr_cust_id      := null;
  repfr_cust_name    := null;
  repfr_posit_id_old := null;
  repfr_posit_id     := null;

  v_ret := inst_rep_add_fil ( rq_id, repfr_name, repfr_value, repfr_l_code_old, repfr_l_code, repfr_i18n_msg, repfr_vis,
                              repfr_mand, repfr_type, repfr_cust_name, repfr_posit_id_old, repfr_posit_id );

end;
/
commit;
