declare
  counter              numeric(16);

  -- report type
  rt_id                numeric(16);
  rt_name              varchar(256) := 'Status';
  rt_desc              varchar(512) := '';

  -- report parent
  rp_id                numeric(16);
  rp_name              varchar(256) := 'Status';

  -- report
  r_id                 numeric(16);
  r_name               varchar(256) := 'Fulfillment status for managed Applications';
  r_desc               varchar(512) := 'Fulfillment status for all the Assignments related to Automatic Account Configurations. The scopes are set to view all Users and all the managed Applications. The report contains also not yet existing entilements in the system coming from target (so not of a specific Application, so out of the scope)';
  r_code               varchar(256) := null;
  r_i18n_mess          varchar(256) := null;
  r_dashboard          numeric(1) := 0; -- 0: report, 1: dashboard

  -- localization
  r_loc_id             numeric(16);
  r_loc_code           varchar(256);

  -- query
  rq_id                numeric(16);
  rq_name              varchar(256) := 'Fulfillment status for managed Applications';
  rq_desc              varchar(512) := 'Fulfillment status for all the Assignments related to Automatic Account Configurations';
  rqd                  clob;

  rv_name              varchar(256);
  repv_vis_type        numeric(2);

  rqf_type_def         varchar(256) := 'java.lang.String';
  rqf_width_def        numeric(16) := 300;

  rqf_name_old         varchar(256);
  rqf_name             varchar(256);
  rqf_type             varchar(256);
  rqf_width            numeric(16);
  rqf_ord_by           numeric(1);
  rqf_ord_by_clau      varchar(256);
  loc_code_old         varchar(256);
  loc_code             varchar(256);
  loc_rename           boolean;
  i18n_msg             varchar(256);
  repf_pos_id          numeric(16);
  repf_pos_id_old      numeric(16);

  repfr_id             numeric(16);
  repfr_name_old       varchar(256);
  repfr_name           varchar(256);
  repfr_value          varchar(256);
  repfr_l_id           numeric(16);
  repfr_l_code_old     varchar(256);
  repfr_l_code         varchar(256);
  repfr_i18n_msg       varchar(256);
  repfr_vis            numeric(16);
  repfr_mand           numeric(16);
  repfr_type           numeric(16);
  repfr_cust_id        numeric(16);
  repfr_cust_name      varchar(256);
  repfr_posit_id       numeric(16);
  repfr_posit_id_old   numeric(16);

  cur_lan              sys_refcursor;
  lan_id               numeric(16);

  v_ret                numeric(16);

begin
  rqd := '--Matched Accounts for managed Applications
'||'select distinct pp.account_code as ACCOUNT_CODE,
'||'                p.name as USER_NAME,
'||'                p.surname as USER_SURNAME,
'||'                p.code as USER_CODE,
'||'                p.email as USER_EMAIL,
'||'                p.dn as USER_DN,
'||'                p.cod_fisc as USER_SSN,
'||'                ou.name as GROUP_NAME,
'||'                ou.code as GROUP_CODE,
'||'                ou.description as GROUP_DESC,
'||'                pp.target as TARGET,
'||'                pp.permission_code as EXTERNAL_REF,
'||'                pp.permission_type as PERMISSION_TYPE,
'||'                e.name as ENTITLEMENT_NAME,
'||'                e.code as ENTITLEMENT_CODE,
'||'                e.description as ENTITLEMENT_DESC,
'||'                a.name as APPLICATION_NAME,
'||'                case
'||'                  when pp.status = 0 then
'||'                   ''Pending''
'||'                  when pp.status = 1 then
'||'                   ''Assignment - Pending Fulfillment''
'||'                  when pp.status = 2 then
'||'                   ''Assignment - Aligned''
'||'                  when pp.status = 3 then
'||'                   ''Assignment - Failed Fulfillment''
'||'                  when pp.status = 4 then
'||'                   ''Assignment - Target Originated''
'||'                  when pp.status = 11 then
'||'                   ''Removal - Pending Fulfillment''
'||'                  when pp.status = 12 then
'||'                   ''Removal - Aligned''
'||'                  when pp.status = 13 then
'||'                   ''Removal - Failed Fulfillment''
'||'                  when pp.status = 14 then
'||'                   ''Removal - Target Originated''
'||'                  else
'||'                   ''Unknown''
'||'                end as STATUS,
'||'                pp.verify_date as VERIFY_DATE
'||'  from #pmschema#.person_profile pp
'||'  left join #pmschema#.entitlement e
'||'    on pp.profile = e.id
'||'  left join #pmschema#.application a
'||'    on e.application = a.id,
'||'       #pmschema#.person p,
'||'       #pmschema#.organizational_unit ou,
'||'       #pmschema#.Target t,
'||'       #pmschema#.Pwdcfg pc,
'||'       #schema_tmp#.tmp_rep_application tmpa,
'||'       #schema_tmp#.tmp_rep_organizational_unit tmpou
'||' where pp.person = p.id
'||'   and p.organizational_unit = ou.id
'||'   and pp.target = t.value
'||'   and t.pwdcfg = pc.id
'||'   and pc.sync = 2
'||'   and a.id = tmpa.id
'||'   and ou.id = tmpou.id
'||'   and pp.status = #fulfillment_status#
'||'
'||'union
'||'
'||'--Matched Accounts for unmanaged Applications (without scope, visible by all the managers)
'||'select distinct pp.account_code as ACCOUNT_CODE,
'||'                p.name as USER_NAME,
'||'                p.surname as USER_SURNAME,
'||'                p.code as USER_CODE,
'||'                p.email as USER_EMAIL,
'||'                p.dn as USER_DN,
'||'                p.cod_fisc as USER_SSN,
'||'                ou.name as GROUP_NAME,
'||'                ou.code as GROUP_CODE,
'||'                ou.description as GROUP_DESC,
'||'                pp.target as TARGET,
'||'                pp.permission_code as EXTERNAL_REF,
'||'                pp.permission_type as PERMISSION_TYPE,
'||'                e.name as ENTITLEMENT_NAME,
'||'                e.code as ENTITLEMENT_CODE,
'||'                e.description as ENTITLEMENT_DESC,
'||'                a.name as APPLICATION_NAME,
'||'                case
'||'                  when pp.status = 0 then
'||'                   ''Pending''
'||'                  when pp.status = 1 then
'||'                   ''Assignment - Pending Fulfillment''
'||'                  when pp.status = 2 then
'||'                   ''Assignment - Aligned''
'||'                  when pp.status = 3 then
'||'                   ''Assignment - Failed Fulfillment''
'||'                  when pp.status = 4 then
'||'                   ''Assignment - Target Originated''
'||'                  when pp.status = 11 then
'||'                   ''Removal - Pending Fulfillment''
'||'                  when pp.status = 12 then
'||'                   ''Removal - Aligned''
'||'                  when pp.status = 13 then
'||'                   ''Removal - Failed Fulfillment''
'||'                  when pp.status = 14 then
'||'                   ''Removal - Target Originated''
'||'                  else
'||'                   ''Unknown''
'||'                end as STATUS,
'||'                pp.verify_date as VERIFY_DATE
'||'  from #pmschema#.person_profile pp
'||'  left join #pmschema#.entitlement e
'||'    on pp.profile = e.id
'||'  left join #pmschema#.application a
'||'    on e.application = a.id,
'||'       #pmschema#.person p,
'||'       #pmschema#.organizational_unit ou,
'||'       #pmschema#.Target t,
'||'       #pmschema#.Pwdcfg pc,
'||'       #schema_tmp#.tmp_rep_organizational_unit tmpou
'||' where e.id is null
'||'   and pp.person = p.id
'||'   and p.organizational_unit = ou.id
'||'   and pp.target = t.value
'||'   and t.pwdcfg = pc.id
'||'   and pc.sync = 2
'||'   and ou.id = tmpou.id
'||'   and pp.status = #fulfillment_status#
'||'
'||'union
'||'
'||'--Unmatched Accounts for managed Applications
'||'select distinct pp.account_code as ACCOUNT_CODE,
'||'                p.name as USER_NAME,
'||'                p.surname as USER_SURNAME,
'||'                p.code as USER_CODE,
'||'                p.email as USER_EMAIL,
'||'                p.dn as USER_DN,
'||'                p.cod_fisc as USER_SSN,
'||'                ou.name as GROUP_NAME,
'||'                ou.code as GROUP_CODE,
'||'                ou.description as GROUP_DESC,
'||'                pp.target as TARGET,
'||'                pp.permission_code as EXTERNAL_REF,
'||'                pp.permission_type as PERMISSION_TYPE,
'||'                e.name as ENTITLEMENT_NAME,
'||'                e.code as ENTITLEMENT_CODE,
'||'                e.description as ENTITLEMENT_DESC,
'||'                a.name as APPLICATION_NAME,
'||'                case
'||'                  when pp.status = 0 then
'||'                   ''Pending''
'||'                  when pp.status = 1 then
'||'                   ''Assignment - Pending Fulfillment''
'||'                  when pp.status = 2 then
'||'                   ''Assignment - Aligned''
'||'                  when pp.status = 3 then
'||'                   ''Assignment - Failed Fulfillment''
'||'                  when pp.status = 4 then
'||'                   ''Assignment - Target Originated''
'||'                  when pp.status = 11 then
'||'                   ''Removal - Pending Fulfillment''
'||'                  when pp.status = 12 then
'||'                   ''Removal - Aligned''
'||'                  when pp.status = 13 then
'||'                   ''Removal - Failed Fulfillment''
'||'                  when pp.status = 14 then
'||'                   ''Removal - Target Originated''
'||'                  else
'||'                   ''Unknown''
'||'                end as STATUS,
'||'                pp.verify_date as VERIFY_DATE
'||'  from #pmschema#.person_profile pp
'||'  left join #pmschema#.person p
'||'    on pp.person = p.id
'||'  left join #pmschema#.entitlement e
'||'    on pp.profile = e.id
'||'  left join #pmschema#.organizational_unit ou
'||'    on p.organizational_unit = ou.id
'||'  left join #pmschema#.application a
'||'    on e.application = a.id,
'||'       #pmschema#.Target t,
'||'       #pmschema#.Pwdcfg pc,
'||'       #schema_tmp#.tmp_rep_application tmpa
'||' where p.id is null
'||'   and pp.target = t.value
'||'   and t.pwdcfg = pc.id
'||'   and pc.sync = 2
'||'   and a.id = tmpa.id
'||'   and pp.status = #fulfillment_status#
'||'
'||'union
'||'
'||'--Unmatched Accounts for unmanaged Applications (without scope, visible by all the managers)
'||'select distinct pp.account_code as ACCOUNT_CODE,
'||'                p.name as USER_NAME,
'||'                p.surname as USER_SURNAME,
'||'                p.code as USER_CODE,
'||'                p.email as USER_EMAIL,
'||'                p.dn as USER_DN,
'||'                p.cod_fisc as USER_SSN,
'||'                ou.name as GROUP_NAME,
'||'                ou.code as GROUP_CODE,
'||'                ou.description as GROUP_DESC,
'||'                pp.target as TARGET,
'||'                pp.permission_code as EXTERNAL_REF,
'||'                pp.permission_type as PERMISSION_TYPE,
'||'                e.name as ENTITLEMENT_NAME,
'||'                e.code as ENTITLEMENT_CODE,
'||'                e.description as ENTITLEMENT_DESC,
'||'                a.name as APPLICATION_NAME,
'||'                case
'||'                  when pp.status = 0 then
'||'                   ''Pending''
'||'                  when pp.status = 1 then
'||'                   ''Assignment - Pending Fulfillment''
'||'                  when pp.status = 2 then
'||'                   ''Assignment - Aligned''
'||'                  when pp.status = 3 then
'||'                   ''Assignment - Failed Fulfillment''
'||'                  when pp.status = 4 then
'||'                   ''Assignment - Target Originated''
'||'                  when pp.status = 11 then
'||'                   ''Removal - Pending Fulfillment''
'||'                  when pp.status = 12 then
'||'                   ''Removal - Aligned''
'||'                  when pp.status = 13 then
'||'                   ''Removal - Failed Fulfillment''
'||'                  when pp.status = 14 then
'||'                   ''Removal - Target Originated''
'||'                  else
'||'                   ''Unknown''
'||'                end as STATUS,
'||'                pp.verify_date as VERIFY_DATE
'||'  from #pmschema#.person_profile pp
'||'  left join #pmschema#.person p
'||'    on pp.person = p.id
'||'  left join #pmschema#.entitlement e
'||'    on pp.profile = e.id
'||'  left join #pmschema#.organizational_unit ou
'||'    on p.organizational_unit = ou.id
'||'  left join #pmschema#.application a
'||'    on e.application = a.id,
'||'       #pmschema#.Target t,
'||'       #pmschema#.Pwdcfg pc
'||' where p.id is null
'||'   and e.id is null
'||'   and pp.target = t.value
'||'   and t.pwdcfg = pc.id
'||'   and pc.sync = 2
'||'   and pp.status = #fulfillment_status#
';

  select count(1) into counter from r_query t where lower ( t.name ) = lower ( rq_name ) and t.product = 1;
  if ( counter = 0 ) then
    select max(id) + 1 into rq_id from r_query t;

    insert into r_query ( id, name, description, product )
    values ( rq_id, rq_name, rq_desc, 1 );

    insert into r_query_data ( r_query, query )
    values ( rq_id, rqd );
  else
    select t.id into rq_id from r_query t where lower ( t.name ) = lower ( rq_name ) and t.product = 1;

    update r_query set description = rq_desc where id = rq_id;

    update r_query_data set query = rqd where r_query = rq_id;
  end if;

  select count(1) into counter from report t where lower ( t.name ) = lower ( r_name ) and t.dashboard = r_dashboard and t.product = 1;
  if ( counter = 0 ) then
    if ( r_loc_code is null ) then
      /*DBALT-BEGIN*/
      /*select dbms_random.random into r_loc_code from dual;*/
      /*PG*select trunc(random()*1000) into r_loc_code from generate_series(1,1000) limit 1;*PG*/
      select int((rand()-0.5) * 32768) into r_loc_code from dual;
      /*DBALT-END*/

      select count(1) into counter from localization t where lower ( t.code ) = lower ( r_loc_code );
      if ( counter = 0 ) then
        select localization_seq.nextval into r_loc_id from dual;
        insert into localization ( id, code, code_type )
        values ( r_loc_id, r_loc_code, 0 );
      end if;

    else
      select count(1) into counter from localization t where lower ( t.code ) = lower ( r_loc_code );
      if ( counter = 1 ) then
        select t.id into r_loc_id from localization t where lower ( t.code ) = lower ( r_loc_code );
      end if;
    end if;

    if ( r_loc_id is null ) then
      select t.id into r_loc_id from localization t where lower ( t.code ) = lower ( r_loc_code );
    end if;

    select max(id) + 1 into r_id from report t;

    if ( rt_name is not null or length ( rt_name ) > 0 ) then
      select count(1) into counter from report_type t where lower ( t.name ) = lower ( rt_name );
      if ( counter = 0 ) then
        select ( max(id) +1 ) into rt_id from report_type t;

        insert into report_type ( id, name, description )
        values ( rt_id, rt_name, rt_desc );
      else
        select t.id into rt_id from report_type t where lower ( t.name ) = lower ( rt_name );
      end if;
    end if;

    insert into report ( id, name, description, localization, r_query, status, report_type, code, product, parent, dashboard )
    values ( r_id, r_name, r_desc, r_loc_id, rq_id, 0, rt_id, r_code, 1, 1, r_dashboard );

    insert into report_attribute ( id, report, name, value )
    values ( report_attribute_seq.nextval, r_id, 'PRIORITY', '0' );
    if ( r_dashboard = 0 ) then
      insert into report_attribute ( id, report, name, value )
      values ( report_attribute_seq.nextval, r_id, 'ORIENTATION', '1' );
      insert into report_attribute ( id, report, name, value )
      values ( report_attribute_seq.nextval, r_id, 'MAX_ROW', null );
      insert into report_attribute ( id, report, name, value )
      values ( report_attribute_seq.nextval, r_id, 'FORMAT', 'xlsx' );
    end if;
  
  else
    select t.id, t.name into r_id, r_name from report t where lower ( t.name ) = lower ( r_name ) and t.dashboard = r_dashboard and t.product = 1;
    select t.localization into r_loc_id from report t where t.id = r_id;
    update report set r_query = rq_id where id = r_id;
  end if;

  if ( r_i18n_mess is null or length ( r_i18n_mess ) = 0 ) then
    r_i18n_mess := r_name;
  end if;

  open cur_lan for select t.id from language t where t.language_status > 0;
  loop
    fetch cur_lan into lan_id;
    exit when cur_lan%NOTFOUND;

    select count(1) into counter from i18n_message t where t.language = lan_id and t.localization = r_loc_id;
    if ( counter = 0 ) then
      insert into i18n_message ( id, localization, language, message )
      values ( i18n_message_seq.nextval, r_loc_id, lan_id, r_i18n_mess );
    else
      update i18n_message set message = r_i18n_mess where language = lan_id and localization = r_loc_id;
    end if;
  end loop;
  close cur_lan;

  -- Report PARENT
  select count(1) into counter from (
    select distinct r.id from report r, localization l, i18n_message i18
    where r.localization = l.id and r.leaf = 0 and l.id = i18.localization
    and i18.message = rp_name and r.dashboard = r_dashboard ) t;
  if ( counter = 1 ) then
    select distinct r.id into rp_id from report r, localization l, i18n_message i18
    where r.localization = l.id and r.leaf = 0 and l.id = i18.localization
    and i18.message = rp_name and r.dashboard = r_dashboard;

    update report set parent = rp_id where id = r_id;
  end if;

  -- Report FIELD 1
  rqf_name_old    := null;
  rqf_name        := 'ACCOUNT_CODE';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'account.code';
  loc_rename      := true;
  i18n_msg        := 'Account Code';
  repf_pos_id_old := null;
  repf_pos_id     := null;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );

  -- Report FIELD 2
  rqf_name_old    := null;
  rqf_name        := 'USER_NAME';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'user.name';
  loc_rename      := true;
  i18n_msg        := 'First Name';
  repf_pos_id_old := null;
  repf_pos_id     := null;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );

  -- Report FIELD 3
  rqf_name_old    := null;
  rqf_name        := 'USER_SURNAME';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'user.surname';
  loc_rename      := true;
  i18n_msg        := 'Last Name';
  repf_pos_id_old := null;
  repf_pos_id     := null;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );

  -- Report FIELD 4
  rqf_name_old    := null;
  rqf_name        := 'USER_CODE';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'user.code';
  loc_rename      := true;
  i18n_msg        := 'UserID';
  repf_pos_id_old := null;
  repf_pos_id     := null;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );

  -- Report FIELD 5
  rqf_name_old    := null;
  rqf_name        := 'USER_EMAIL';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'user.email';
  loc_rename      := true;
  i18n_msg        := 'Email';
  repf_pos_id_old := null;
  repf_pos_id     := null;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );

  -- Report FIELD 6
  rqf_name_old    := null;
  rqf_name        := 'USER_DN';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'user.dn';
  loc_rename      := true;
  i18n_msg        := 'User DN';
  repf_pos_id_old := null;
  repf_pos_id     := null;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );

  -- Report FIELD 7
  rqf_name_old    := null;
  rqf_name        := 'USER_SSN';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'user.ssn';
  loc_rename      := true;
  i18n_msg        := 'SSN Code';
  repf_pos_id_old := null;
  repf_pos_id     := null;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );

  -- Report FIELD 8
  rqf_name_old    := null;
  rqf_name        := 'GROUP_NAME';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'group.name';
  loc_rename      := true;
  i18n_msg        := 'Group';
  repf_pos_id_old := null;
  repf_pos_id     := null;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );

  -- Report FIELD 9
  rqf_name_old    := null;
  rqf_name        := 'GROUP_CODE';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'group.code';
  loc_rename      := true;
  i18n_msg        := 'Group code';
  repf_pos_id_old := null;
  repf_pos_id     := null;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );

  -- Report FIELD 10
  rqf_name_old    := null;
  rqf_name        := 'GROUP_DESC';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'group.desc';
  loc_rename      := true;
  i18n_msg        := 'Group descr.';
  repf_pos_id_old := null;
  repf_pos_id     := null;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );

  -- Report FIELD 11
  rqf_name_old    := null;
  rqf_name        := 'TARGET';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'target';
  loc_rename      := true;
  i18n_msg        := 'Target';
  repf_pos_id_old := null;
  repf_pos_id     := null;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );

  -- Report FIELD 12
  rqf_name_old    := null;
  rqf_name        := 'EXTERNAL_REF';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'external.ref';
  loc_rename      := true;
  i18n_msg        := 'External Ref';
  repf_pos_id_old := null;
  repf_pos_id     := null;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );

  -- Report FIELD 13
  rqf_name_old    := null;
  rqf_name        := 'PERMISSION_TYPE';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'permission.type';
  loc_rename      := true;
  i18n_msg        := 'Permission Type';
  repf_pos_id_old := null;
  repf_pos_id     := null;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );

  -- Report FIELD 14
  rqf_name_old    := null;
  rqf_name        := 'ENTITLEMENT_NAME';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'entitlement.name';
  loc_rename      := true;
  i18n_msg        := 'Entitlement Name';
  repf_pos_id_old := null;
  repf_pos_id     := null;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );

  -- Report FIELD 15
  rqf_name_old    := null;
  rqf_name        := 'ENTITLEMENT_CODE';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'entitlement.code';
  loc_rename      := true;
  i18n_msg        := 'Entitlement Code';
  repf_pos_id_old := null;
  repf_pos_id     := null;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );

  -- Report FIELD 16
  rqf_name_old    := null;
  rqf_name        := 'ENTITLEMENT_DESC';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'entitlement.desc';
  loc_rename      := true;
  i18n_msg        := 'Entitlement Descr.';
  repf_pos_id_old := null;
  repf_pos_id     := null;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );

  -- Report FIELD 17
  rqf_name_old    := null;
  rqf_name        := 'APPLICATION_NAME';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'application.name';
  loc_rename      := true;
  i18n_msg        := 'Application';
  repf_pos_id_old := null;
  repf_pos_id     := null;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );

  -- Report FIELD 18
  rqf_name_old    := null;
  rqf_name        := 'STATUS';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'status';
  loc_rename      := true;
  i18n_msg        := 'Sync Status';
  repf_pos_id_old := null;
  repf_pos_id     := null;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );

  -- Report FIELD 19
  rqf_name_old    := null;
  rqf_name        := 'VERIFY_DATE';
  rqf_type        := rqf_type_def;
  rqf_width       := rqf_width_def;
  rqf_ord_by      := 0;
  rqf_ord_by_clau := null;
  loc_code_old    := null;
  loc_code        := 'verify.date';
  loc_rename      := true;
  i18n_msg        := 'Verified';
  repf_pos_id_old := null;
  repf_pos_id     := null;

  v_ret := inst_rep_add_col ( rq_id, rqf_name_old, rqf_name, rqf_type, rqf_width, rqf_ord_by, rqf_ord_by_clau,
                              loc_code_old, loc_code, loc_rename, i18n_msg, repf_pos_id_old, repf_pos_id );


  -- QUERY AND REPORT VISIBILITY

  rv_name := 'AG-Core Application';
  repv_vis_type := 3;

  v_ret := inst_rep_add_vis ( r_id, rq_id, rv_name, repv_vis_type );

  rv_name := 'AG-Core Org. Unit';
  repv_vis_type := 1;

  v_ret := inst_rep_add_vis ( r_id, rq_id, rv_name, repv_vis_type );

  -- REPORT FILTERS

  repfr_name_old     := null;
  repfr_name         := 'fulfillment_status';
  repfr_value        := null;
  repfr_l_code_old   := null;
  repfr_l_code       := 'fulfillment.status';
  repfr_i18n_msg     := 'Fullfillment Status';
  repfr_vis          := 0;
  repfr_mand         := 0;
  repfr_type         := 0;
  repfr_cust_id      := null;
  repfr_cust_name    := null;
  repfr_posit_id_old := null;
  repfr_posit_id     := null;

  v_ret := inst_rep_add_fil ( rq_id, repfr_name, repfr_value, repfr_l_code_old, repfr_l_code, repfr_i18n_msg, repfr_vis,
                              repfr_mand, repfr_type, repfr_cust_name, repfr_posit_id_old, repfr_posit_id );

end;
/
commit;
